/*$selected_bg_color: #00e8c6;06d6a0*/
/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/* widget text/foreground color */
@define-color theme_fg_color #C3C7D1;
/* text color for entries, views and content in general */
@define-color theme_text_color #C3C7D1;
/* widget base background color */
@define-color theme_bg_color #161925;
/* text widgets and the like base background color */
@define-color theme_base_color #181b28;
/* base background color of selections */
@define-color theme_selected_bg_color #c50ed2;
/* text/foreground color of selections */
@define-color theme_selected_fg_color #fefefe;
/* base background color of disabled widgets */
@define-color insensitive_bg_color #171a26;
/* text foreground color of disabled widgets */
@define-color insensitive_fg_color #6d707b;
/* disabled text widgets and the like base background color */
@define-color insensitive_base_color #181b28;
/* widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #6d707b;
/* text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color #C3C7D1;
/* widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #161925;
/* text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #1a1d2b;
/* base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #c50ed2;
/* text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #fefefe;
/* widgets main borders color */
@define-color borders #090a0f;
/* widgets main borders color on backdrop windows */
@define-color unfocused_borders #0a0c11;
/* these are pretty self explicative */
@define-color warning_color #cc5500;
@define-color error_color #e6133e;
@define-color success_color #0096b1;
@define-color fg_color #C3C7D1;
@define-color text_color #C3C7D1;
@define-color bg_color #161925;
@define-color base_color #181b28;
@define-color selected_bg_color #c50ed2;
@define-color selected_fg_color #fefefe;
@define-color unfocused_fg_color #6d707b;
@define-color unfocused_text_color #C3C7D1;
@define-color unfocused_bg_color #161925;
@define-color unfocused_base_color #1a1d2b;
@define-color unfocused_selected_bg_color #c50ed2;
@define-color unfocused_selected_fg_color #fefefe;
/* these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title shade(#C3C7D1, 1.8);
@define-color wm_unfocused_title #6d707b;
@define-color wm_highlight rgba(0, 0, 0, 0);
@define-color wm_borders_edge rgba(255, 255, 255, 0.1);
@define-color wm_bg_a shade(#161925, 1.2);
@define-color wm_bg_b #161925;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.18);
@define-color wm_button_hover_color_a shade(#161925, 1.3);
@define-color wm_button_hover_color_b #161925;
@define-color wm_button_active_color_a shade(#161925, 0.85);
@define-color wm_button_active_color_b shade(#161925, 0.89);
@define-color wm_button_active_color_c shade(#161925, 0.9);
@define-color content_view_bg #181b28;
@define-color text_view_bg #181b28;
@define-color budgie_tasklist_indicator_color #c50ed2;
@define-color budgie_tasklist_indicator_color_active #c50ed2;
@define-color placeholder_text_color #a1a5b0;
@define-color STRAWBERRY_100 #ff8c82;
@define-color STRAWBERRY_300 #ed5353;
@define-color STRAWBERRY_500 #c6262e;
@define-color STRAWBERRY_700 #a10705;
@define-color STRAWBERRY_900 #7a0000;
@define-color ORANGE_100 #ffc27d;
@define-color ORANGE_300 #ffa154;
@define-color ORANGE_500 #f37329;
@define-color ORANGE_700 #cc3b02;
@define-color ORANGE_900 #a62100;
@define-color BANANA_100 #fff394;
@define-color BANANA_300 #ffe16b;
@define-color BANANA_500 #f9c440;
@define-color BANANA_700 #d48e15;
@define-color BANANA_900 #ad5f00;
@define-color LIME_100 #d1ff82;
@define-color LIME_300 #9bdb4d;
@define-color LIME_500 #68b723;
@define-color LIME_700 #3a9104;
@define-color LIME_900 #206b00;
@define-color MINT_100 #89ffdd;
@define-color MINT_300 #43d6b5;
@define-color MINT_500 #28bca3;
@define-color MINT_700 #0e9a83;
@define-color MINT_900 #007367;
@define-color BLUEBERRY_100 #8cd5ff;
@define-color BLUEBERRY_300 #64baff;
@define-color BLUEBERRY_500 #3689e6;
@define-color BLUEBERRY_700 #0d52bf;
@define-color BLUEBERRY_900 #002e99;
@define-color BUBBLEGUM_100 #fe9ab8;
@define-color BUBBLEGUM_300 #f4679d;
@define-color BUBBLEGUM_500 #de3e80;
@define-color BUBBLEGUM_700 #bc245d;
@define-color BUBBLEGUM_900 #910e38;
@define-color GRAPE_100 #e4c6fa;
@define-color GRAPE_300 #cd9ef7;
@define-color GRAPE_500 #a56de2;
@define-color GRAPE_700 #7239b3;
@define-color GRAPE_900 #452981;
@define-color COCOA_100 #a3907c;
@define-color COCOA_300 #8a715e;
@define-color COCOA_500 #715344;
@define-color COCOA_700 #57392d;
@define-color COCOA_900 #3d211b;
@define-color SILVER_100 #fafafa;
@define-color SILVER_300 #d4d4d4;
@define-color SILVER_500 #abacae;
@define-color SILVER_700 #7e8087;
@define-color SILVER_900 #555761;
@define-color SLATE_100 #95a3ab;
@define-color SLATE_300 #667885;
@define-color SLATE_500 #485a6c;
@define-color SLATE_700 #273445;
@define-color SLATE_900 #0e141f;
@define-color BLACK_100 #666;
@define-color BLACK_300 #4d4d4d;
@define-color BLACK_500 #333;
@define-color BLACK_700 #1a1a1a;
@define-color BLACK_900 #000;
/*****************
* Drawing mixins *
*****************/
/*********
* Common *
*********/
* {
  padding: 0;
  outline-color: rgba(195, 199, 209, 0.3);
  outline-style: dashed;
  outline-offset: -3px;
  outline-width: 0px;
  -gtk-secondary-caret-color: #c50ed2; }

/***********
 * Widgets *
 ***********/
/***************
* Action bars *
***************/
.action-bar {
  background-color: #030305;
  border: solid #090a0f;
  border-width: 1px 0 0 0;
  color: #C3C7D1;
  box-shadow: none; }
  .action-bar:backdrop {
    background-color: #030305;
    box-shadow: none; }
  .action-bar:first-child {
    border-radius: 6px 6px 0px 0px;
    border-width: 1px 1px 0px 1px; }
  .action-bar:last-child {
    border-radius: 0 0 6px 6px;
    border-width: 0px 1px 1px 1px; }

/*********************
 * App Notifications *
 *********************/
.app-notification,
.app-notification.frame {
  padding: 10px;
  border-radius: 0 0 5px 5px;
  background-color: rgba(16, 19, 27, 0.98);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px);
  background-clip: padding-box; }
  .app-notification:backdrop,
  .app-notification.frame:backdrop {
    background-image: none;
    transition: 200ms ease-out; }
  .app-notification border,
  .app-notification.frame border {
    border: none; }

/***************
 * Base States *
 ***************/
.background {
  color: #C3C7D1;
  background-color: #161925; }
  .background:backdrop {
    color: #6d707b;
    background-color: #161925;
    text-shadow: none;
    -gtk-icon-shadow: none; }

/*
   These wildcard seems unavoidable, need to investigate.
   Wildcards are bad and troublesome, use them with care,
   or better, just don't.
   Everytime a wildcard is used a kitten dies, painfully.
*/
.gtkstyle-fallback {
  color: #C3C7D1;
  background-color: #161925; }
  .gtkstyle-fallback:hover {
    color: #C3C7D1;
    background-color: #292f45; }
  .gtkstyle-fallback:active {
    color: #C3C7D1;
    background-color: #030305; }
  .gtkstyle-fallback:disabled {
    color: #6d707b;
    background-color: #171a26; }
  .gtkstyle-fallback:selected {
    color: #fefefe;
    background-color: #c50ed2; }

.view, iconview,
.view text,
iconview text,
textview text {
  color: #C3C7D1;
  background-color: #181b28; }
  .view:backdrop, iconview:backdrop,
  .view text:backdrop,
  iconview text:backdrop,
  textview text:backdrop {
    color: #a1a5b0;
    background-color: #1a1d2b; }
  .view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected,
  .view text:selected:focus,
  iconview text:selected:focus,
  textview text:selected:focus,
  .view text:selected,
  iconview text:selected,
  textview text:selected {
    border-radius: 3px; }

textview border {
  background-color: #171a27; }

.rubberband,
rubberband,
flowbox rubberband,
.content-view rubberband,
treeview.view rubberband {
  border: 1px solid #980ba2;
  background-color: rgba(152, 11, 162, 0.2); }

flowbox flowboxchild {
  padding: 3px;
  border-radius: 3px; }
  flowbox flowboxchild:selected {
    outline-offset: -2px; }

label {
  caret-color: currentColor; }
  label.separator {
    color: #C3C7D1; }
    label.separator:backdrop {
      color: #6d707b; }
  label selection {
    background-color: #c50ed2;
    color: #fefefe; }
  label:disabled {
    color: #6d707b; }
    label:disabled:backdrop {
      color: #333955; }
  label:backdrop {
    color: #6d707b; }

.dim-label, label.separator, .titlebar .subtitle,
headerbar .subtitle {
  opacity: 0.55;
  text-shadow: none; }

assistant .sidebar {
  background-color: #181b28;
  border-top: 1px solid #090a0f; }
  assistant .sidebar:backdrop {
    background-color: #1a1d2b;
    border-color: #0a0c11; }
assistant.csd .sidebar {
  border-top-style: none; }
assistant .sidebar label {
  padding: 6px 12px; }
assistant .sidebar label.highlight {
  background-color: #393c47; }

.app-notification,
.app-notification.frame, .osd .scale-popup, .osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents, .osd {
  color: #fefefe;
  border: 1px solid #171e27;
  background-color: rgba(16, 19, 27, 0.98);
  background-clip: padding-box;
  outline-color: rgba(254, 254, 254, 0.3);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black; }
  .app-notification:backdrop, .osd .scale-popup:backdrop, .osd popover.background > arrow:backdrop,
  .osd popover.background > contents:backdrop, popover.background.touch-selection > arrow:backdrop,
  popover.background.touch-selection > contents:backdrop, popover.background.magnifier > arrow:backdrop,
  popover.background.magnifier > contents:backdrop, .osd:backdrop {
    text-shadow: none;
    -gtk-icon-shadow: none; }

*:selected {
  background: #c50ed2;
  color: #fefefe; }

/***********
 * Buttons *
 ***********/
@keyframes needs_attention {
  from {
    background-image: radial-gradient(farthest-side, #e63bf2 0%, rgba(230, 59, 242, 0) 0%); }
  to {
    background-image: radial-gradient(farthest-side, #e63bf2 95%, rgba(230, 59, 242, 0)); } }
notebook > header > tabs > arrow,
button {
  min-height: 20px;
  min-width: 16px;
  padding: 2px 6px;
  border: 1px solid #090a0f;
  border-radius: 4px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  font-weight: normal;
  color: #C3C7D1;
  background-color: #202435;
  text-shadow: none; }
  notebook > header > tabs > arrow,
  button.flat {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    transition: none; }
    notebook > header > tabs > arrow:hover,
    button.flat:hover {
      transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
      transition-duration: 500ms;
      color: #fefefe;
      outline-color: rgba(254, 254, 254, 0.3);
      background-color: #c50ed2;
      text-shadow: none; }
      notebook > header > tabs > arrow:hover:active,
      button.flat:hover:active {
        transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }
  notebook > header > tabs > arrow:hover,
  button:hover {
    color: #fefefe;
    outline-color: rgba(254, 254, 254, 0.3);
    background-color: #c50ed2;
    text-shadow: none;
    -gtk-icon-filter: brightness(1.2); }
  notebook > header > tabs > arrow:active, notebook > header > tabs > arrow:checked,
  button:active,
  button:checked {
    color: #fefefe;
    outline-color: rgba(254, 254, 254, 0.3);
    background-color: #af0cba;
    text-shadow: none;
    transition-duration: 50ms; }
  notebook > header > tabs > arrow:backdrop, notebook > header > tabs > arrow:backdrop,
  button:backdrop.flat,
  button:backdrop {
    color: #a1a5b0;
    outline-color: rgba(195, 199, 209, 0.3);
    background-color: #1a1d2b;
    text-shadow: none;
    transition: 200ms ease-out;
    -gtk-icon-filter: none; }
    notebook > header > tabs > arrow:backdrop:active, notebook > header > tabs > arrow:backdrop:checked, notebook > header > tabs > arrow:backdrop:active, notebook > header > tabs > arrow:backdrop:checked,
    button:backdrop.flat:active,
    button:backdrop.flat:checked,
    button:backdrop:active,
    button:backdrop:checked {
      color: rgba(254, 254, 254, 0.7);
      outline-color: rgba(195, 199, 209, 0.3);
      background-color: #c50ed2;
      text-shadow: none; }
      notebook > header > tabs > arrow:backdrop:active label, notebook > header > tabs > arrow:backdrop:checked label, notebook > header > tabs > arrow:backdrop:active label, notebook > header > tabs > arrow:backdrop:checked label,
      button:backdrop.flat:active label,
      button:backdrop.flat:checked label,
      button:backdrop:active label,
      button:backdrop:checked label {
        color: rgba(254, 254, 254, 0.7); }
    notebook > header > tabs > arrow:backdrop:disabled, notebook > header > tabs > arrow:backdrop:disabled,
    button:backdrop.flat:disabled,
    button:backdrop:disabled {
      color: #a1a5b0;
      outline-color: rgba(195, 199, 209, 0.3);
      background-color: #171a26;
      text-shadow: none; }
      notebook > header > tabs > arrow:backdrop:disabled:active, notebook > header > tabs > arrow:backdrop:disabled:checked, notebook > header > tabs > arrow:backdrop:disabled:active, notebook > header > tabs > arrow:backdrop:disabled:checked,
      button:backdrop.flat:disabled:active,
      button:backdrop.flat:disabled:checked,
      button:backdrop:disabled:active,
      button:backdrop:disabled:checked {
        color: rgba(254, 254, 254, 0.7);
        outline-color: rgba(195, 199, 209, 0.3);
        background-color: #c50ed2;
        text-shadow: none; }
  notebook > header > tabs > arrow:backdrop, notebook > header > tabs > arrow:disabled, notebook > header > tabs > arrow:backdrop:disabled,
  button.flat:backdrop,
  button.flat:disabled,
  button.flat:backdrop:disabled {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none; }
  notebook > header > tabs > arrow:disabled,
  button:disabled {
    color: #a1a5b0;
    outline-color: rgba(195, 199, 209, 0.3);
    background-color: #171a26;
    text-shadow: none; }
    notebook > header > tabs > arrow:disabled:active, notebook > header > tabs > arrow:disabled:checked,
    button:disabled:active,
    button:disabled:checked {
      color: rgba(254, 254, 254, 0.7);
      outline-color: rgba(195, 199, 209, 0.3);
      background-color: #c50ed2;
      text-shadow: none; }
      notebook > header > tabs > arrow:disabled:active label, notebook > header > tabs > arrow:disabled:checked label,
      button:disabled:active label,
      button:disabled:checked label {
        color: rgba(254, 254, 254, 0.7); }
  notebook > header > tabs > arrow.image-button,
  button.image-button {
    min-width: 24px;
    padding-left: 4px;
    padding-right: 4px; }
    notebook > header > tabs > arrow.image-button.circular, notebook > header > tabs > arrow.image-button.sidebar-button,
    button.image-button.circular,
    button.image-button.sidebar-button {
      padding: 6px 4px;
      border-radius: 50px;
      box-shadow: none; }
    notebook > header > tabs > arrow.image-button.sidebar-button,
    button.image-button.sidebar-button {
      background-color: #252a3e;
      color: #fff; }
      notebook > header > tabs > arrow.image-button.sidebar-button:hover,
      button.image-button.sidebar-button:hover {
        background-color: #c50ed2; }
  notebook > header > tabs > arrow.text-button,
  button.text-button {
    padding-left: 16px;
    padding-right: 16px; }
  notebook > header > tabs > arrow.text-button.image-button,
  button.text-button.image-button {
    padding-left: 8px;
    padding-right: 8px;
    border-radius: 2px; }
    notebook > header > tabs > arrow.text-button.image-button label,
    button.text-button.image-button label {
      padding-left: 8px;
      padding-right: 8px; }
  combobox:drop(active) button.combo, notebook > header > tabs > arrow:drop(active),
  button:drop(active) {
    color: #71f79f;
    border-color: #71f79f;
    box-shadow: inset 0 0 0 1px #71f79f; }
row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled) {
  color: #fefefe;
  border-color: transparent; }
  row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop {
    color: #6d707b; }
button.osd {
  min-width: 24px;
  min-height: 20px;
  color: #fefefe;
  border-radius: 5px;
  outline-color: rgba(254, 254, 254, 0.3);
  color: #fefefe;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(16, 19, 27, 0.98);
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(254, 254, 254, 0.3);
  border: none;
  box-shadow: none; }
  button.osd.image-button {
    min-width: 32px; }
  button.osd:hover {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(39, 44, 66, 0.98), rgba(39, 44, 66, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    outline-color: rgba(254, 254, 254, 0.3);
    border: none;
    box-shadow: none; }
  button.osd:active,
  button.osd:checked {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(28, 31, 47, 0.98), rgba(28, 31, 47, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: none;
    -gtk-icon-shadow: none;
    outline-color: rgba(254, 254, 254, 0.3);
    border: none;
    box-shadow: none; }
  button.osd:disabled:backdrop,
  button.osd:disabled {
    color: #87898d;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    border: none; }
  button.osd:backdrop {
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(16, 19, 27, 0.98), rgba(16, 19, 27, 0.98));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    border: none; }
.app-notification button,
.app-notification.frame button, popover.background.touch-selection button, popover.background.magnifier button,
.osd button {
  color: #fefefe;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(16, 19, 27, 0.98);
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(254, 254, 254, 0.3); }
  .app-notification button:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover,
  .osd button:hover {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(39, 44, 66, 0.98), rgba(39, 44, 66, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    outline-color: rgba(254, 254, 254, 0.3); }
  .app-notification button:active:backdrop, popover.background.touch-selection button:active:backdrop, popover.background.magnifier button:active:backdrop, .app-notification button:active, popover.background.touch-selection button:active, popover.background.magnifier button:active, .app-notification button:checked:backdrop, popover.background.touch-selection button:checked:backdrop, popover.background.magnifier button:checked:backdrop, .app-notification button:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked,
  .osd button:active:backdrop,
  .osd button:active,
  .osd button:checked:backdrop,
  .osd button:checked {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(28, 31, 47, 0.98), rgba(28, 31, 47, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: none;
    -gtk-icon-shadow: none;
    outline-color: rgba(254, 254, 254, 0.3); }
  .app-notification button:disabled:backdrop, popover.background.touch-selection button:disabled:backdrop, popover.background.magnifier button:disabled:backdrop, .app-notification button:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled,
  .osd button:disabled:backdrop,
  .osd button:disabled {
    color: #87898d;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
  .app-notification button:backdrop, popover.background.touch-selection button:backdrop, popover.background.magnifier button:backdrop,
  .osd button:backdrop {
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(16, 19, 27, 0.98), rgba(16, 19, 27, 0.98));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
  .app-notification button.flat, popover.background.touch-selection button.flat, popover.background.magnifier button.flat,
  .osd button.flat {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    box-shadow: none;
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .app-notification button.flat:hover, popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover,
    .osd button.flat:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(39, 44, 66, 0.98), rgba(39, 44, 66, 0.98));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black;
      outline-color: rgba(254, 254, 254, 0.3); }
    .app-notification button.flat:disabled, popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled,
    .osd button.flat:disabled {
      color: #87898d;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none;
      background-image: none;
      border-color: transparent;
      box-shadow: none; }
    .app-notification button.flat:backdrop, popover.background.touch-selection button.flat:backdrop, popover.background.magnifier button.flat:backdrop,
    .osd button.flat:backdrop {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .app-notification button.flat:active, popover.background.touch-selection button.flat:active, popover.background.magnifier button.flat:active, .app-notification button.flat:checked, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked,
    .osd button.flat:active,
    .osd button.flat:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(28, 31, 47, 0.98), rgba(28, 31, 47, 0.98));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: none;
      -gtk-icon-shadow: none;
      outline-color: rgba(254, 254, 254, 0.3); }
button.suggested-action {
  border: none;
  box-shadow: none;
  color: white;
  border-radius: 100px;
  background: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
  .selection-mode windowcontrols button, button.suggested-action.flat {
    box-shadow: none;
    color: white;
    border-radius: 100px;
    background: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
  button.suggested-action:hover {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #00c1e4;
    text-shadow: none; }
  button.suggested-action:active, button.suggested-action:checked {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #00c1e4;
    text-shadow: none; }
  .selection-mode windowcontrols button:backdrop, button.suggested-action:backdrop, button.suggested-action.flat:backdrop {
    color: rgba(255, 255, 255, 0.4);
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #00c1e4;
    text-shadow: none; }
    .selection-mode windowcontrols button:backdrop label, button.suggested-action:backdrop label, button.suggested-action.flat:backdrop label {
      color: rgba(255, 255, 255, 0.5); }
    .selection-mode windowcontrols button:backdrop:active, .selection-mode windowcontrols button:backdrop:checked, button.suggested-action:backdrop:active, button.suggested-action:backdrop:checked, button.suggested-action.flat:backdrop:active, button.suggested-action.flat:backdrop:checked {
      color: rgba(254, 254, 254, 0.7);
      outline-color: rgba(255, 255, 255, 0.3);
      background-color: #c50ed2;
      text-shadow: none; }
      .selection-mode windowcontrols button:backdrop:active label, .selection-mode windowcontrols button:backdrop:checked label, button.suggested-action:backdrop:active label, button.suggested-action:backdrop:checked label, button.suggested-action.flat:backdrop:active label, button.suggested-action.flat:backdrop:checked label {
        color: rgba(254, 254, 254, 0.7); }
    .selection-mode windowcontrols button:backdrop:disabled, button.suggested-action:backdrop:disabled, button.suggested-action.flat:backdrop:disabled {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      background-color: #00c1e4;
      text-shadow: none; }
      .selection-mode windowcontrols button:backdrop:disabled label, button.suggested-action:backdrop:disabled label, button.suggested-action.flat:backdrop:disabled label {
        color: rgba(255, 255, 255, 0.5); }
      .selection-mode windowcontrols button:backdrop:disabled:active, .selection-mode windowcontrols button:backdrop:disabled:checked, button.suggested-action:backdrop:disabled:active, button.suggested-action:backdrop:disabled:checked, button.suggested-action.flat:backdrop:disabled:active, button.suggested-action.flat:backdrop:disabled:checked {
        color: rgba(254, 254, 254, 0.7);
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #c50ed2;
        text-shadow: none; }
  .selection-mode windowcontrols button:backdrop, .selection-mode windowcontrols button:disabled, .selection-mode windowcontrols button:backdrop:disabled, button.suggested-action.flat:backdrop, button.suggested-action.flat:disabled, button.suggested-action.flat:backdrop:disabled {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(0, 193, 228, 0.8); }
  button.suggested-action:disabled {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #00c1e4;
    text-shadow: none; }
    button.suggested-action:disabled:active, button.suggested-action:disabled:checked {
      color: rgba(254, 254, 254, 0.7);
      outline-color: rgba(255, 255, 255, 0.3);
      background-color: #00c1e4;
      text-shadow: none; }
      button.suggested-action:disabled:active label, button.suggested-action:disabled:checked label {
        color: rgba(254, 254, 254, 0.7); }
  .osd button.suggested-action {
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: rgba(0, 193, 228, 0.5);
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    outline-color: rgba(254, 254, 254, 0.3); }
    .osd button.suggested-action:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(0, 193, 228, 0.7), rgba(0, 193, 228, 0.7));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black;
      outline-color: rgba(254, 254, 254, 0.3); }
    .osd button.suggested-action:active:backdrop, .osd button.suggested-action:active, .osd button.suggested-action:checked:backdrop, .osd button.suggested-action:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, #00c1e4, #00c1e4);
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: none;
      -gtk-icon-shadow: none;
      outline-color: rgba(254, 254, 254, 0.3); }
    .osd button.suggested-action:disabled:backdrop, .osd button.suggested-action:disabled {
      color: #87898d;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd button.suggested-action:backdrop {
      color: #fefefe;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(0, 193, 228, 0.5), rgba(0, 193, 228, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
button.destructive-action {
  border: none;
  box-shadow: none;
  color: white;
  border-radius: 100px;
  background: linear-gradient(to right, #FF416C, #FF4B2B); }
  button.destructive-action.flat {
    box-shadow: none;
    color: white;
    border-radius: 100px;
    background: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
  button.destructive-action:hover {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ce1138;
    text-shadow: none; }
  button.destructive-action:active, button.destructive-action:checked {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ce1138;
    text-shadow: none; }
  button.destructive-action:backdrop, button.destructive-action.flat:backdrop {
    color: rgba(255, 255, 255, 0.4);
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ce1138;
    text-shadow: none; }
    button.destructive-action:backdrop label, button.destructive-action.flat:backdrop label {
      color: rgba(255, 255, 255, 0.5); }
    button.destructive-action:backdrop:active, button.destructive-action:backdrop:checked, button.destructive-action.flat:backdrop:active, button.destructive-action.flat:backdrop:checked {
      color: rgba(254, 254, 254, 0.7);
      outline-color: rgba(255, 255, 255, 0.3);
      background-color: #c50ed2;
      text-shadow: none; }
      button.destructive-action:backdrop:active label, button.destructive-action:backdrop:checked label, button.destructive-action.flat:backdrop:active label, button.destructive-action.flat:backdrop:checked label {
        color: rgba(254, 254, 254, 0.7); }
    button.destructive-action:backdrop:disabled, button.destructive-action.flat:backdrop:disabled {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      background-color: #ce1138;
      text-shadow: none; }
      button.destructive-action:backdrop:disabled label, button.destructive-action.flat:backdrop:disabled label {
        color: rgba(255, 255, 255, 0.5); }
      button.destructive-action:backdrop:disabled:active, button.destructive-action:backdrop:disabled:checked, button.destructive-action.flat:backdrop:disabled:active, button.destructive-action.flat:backdrop:disabled:checked {
        color: rgba(254, 254, 254, 0.7);
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #c50ed2;
        text-shadow: none; }
  button.destructive-action.flat:backdrop, button.destructive-action.flat:disabled, button.destructive-action.flat:backdrop:disabled {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(206, 17, 56, 0.8); }
  button.destructive-action:disabled {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ce1138;
    text-shadow: none; }
    button.destructive-action:disabled:active, button.destructive-action:disabled:checked {
      color: rgba(254, 254, 254, 0.7);
      outline-color: rgba(255, 255, 255, 0.3);
      background-color: #ce1138;
      text-shadow: none; }
      button.destructive-action:disabled:active label, button.destructive-action:disabled:checked label {
        color: rgba(254, 254, 254, 0.7); }
  .osd button.destructive-action {
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: rgba(206, 17, 56, 0.5);
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    outline-color: rgba(254, 254, 254, 0.3); }
    .osd button.destructive-action:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(206, 17, 56, 0.7), rgba(206, 17, 56, 0.7));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black;
      outline-color: rgba(254, 254, 254, 0.3); }
    .osd button.destructive-action:active:backdrop, .osd button.destructive-action:active, .osd button.destructive-action:checked:backdrop, .osd button.destructive-action:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, #ce1138, #ce1138);
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: none;
      -gtk-icon-shadow: none;
      outline-color: rgba(254, 254, 254, 0.3); }
    .osd button.destructive-action:disabled:backdrop, .osd button.destructive-action:disabled {
      color: #87898d;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd button.destructive-action:backdrop {
      color: #fefefe;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(206, 17, 56, 0.5), rgba(206, 17, 56, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
.stack-switcher > button {
  outline-offset: -3px; }
  .stack-switcher > button > label {
    padding-left: 6px;
    padding-right: 6px; }
  .stack-switcher > button > image {
    padding-left: 6px;
    padding-right: 6px;
    padding-top: 3px;
    padding-bottom: 3px; }
  .stack-switcher > button.text-button {
    padding-left: 10px;
    padding-right: 10px; }
  .stack-switcher > button.image-button {
    padding-left: 2px;
    padding-right: 2px; }
  .stack-switcher > button.needs-attention:active > label,
  .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label,
  .stack-switcher > button.needs-attention:checked > image {
    animation: none;
    background-image: none; }
.inline-toolbar button, .inline-toolbar button:backdrop {
  border-radius: 2px;
  border-width: 1px; }
.primary-toolbar button, .primary-toolbar .raised button {
  -gtk-icon-shadow: none; }
  .primary-toolbar button:hover, .primary-toolbar button:focus, .primary-toolbar .raised button:hover, .primary-toolbar .raised button:focus {
    color: #fefefe;
    outline-color: rgba(254, 254, 254, 0.3);
    background-color: #c50ed2;
    text-shadow: none; }

.stack-switcher > button.needs-attention > label,
.stack-switcher > button.needs-attention > image, stacksidebar row.needs-attention > label {
  animation: needs_attention 150ms ease-in;
  background-image: radial-gradient(farthest-side, #e63bf2 96%, rgba(230, 59, 242, 0));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 2px; }
  .stack-switcher > button.needs-attention > label:backdrop,
  .stack-switcher > button.needs-attention > image:backdrop, stacksidebar row.needs-attention > label:backdrop {
    background-size: 6px 6px, 0 0; }
  .stack-switcher > button.needs-attention > label:dir(rtl),
  .stack-switcher > button.needs-attention > image:dir(rtl), stacksidebar row.needs-attention > label:dir(rtl) {
    background-position: left 3px, left 2px; }

toolbar button:hover {
  font-weight: normal;
  color: #C3C7D1;
  background-color: #202435;
  text-shadow: none; }
toolbar button:active {
  font-weight: normal;
  color: #C3C7D1;
  background-color: #202435;
  text-shadow: none; }

.inline-toolbar toolbutton > button {
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none; }
  .inline-toolbar toolbutton > button:hover {
    color: #fefefe; }
  .inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked {
    color: #af0cba; }
  .inline-toolbar toolbutton > button:disabled {
    color: #a1a5b0; }
    .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked {
      color: rgba(175, 12, 186, 0.3); }
  .inline-toolbar toolbutton > button:backdrop {
    color: #a1a5b0; }
    .inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked {
      color: #af0cba; }
    .inline-toolbar toolbutton > button:backdrop:disabled {
      color: #a1a5b0; }
      .inline-toolbar toolbutton > button:backdrop:disabled:active, .inline-toolbar toolbutton > button:backdrop:disabled:checked {
        color: rgba(175, 12, 186, 0.3); }

toolbar.inline-toolbar toolbutton > button.flat:backdrop,
toolbar.inline-toolbar toolbutton:backdrop > button.flat:backdrop {
  border-color: transparent;
  box-shadow: none; }

.inline-toolbar button, .inline-toolbar button:backdrop, .linked > button, .linked > button:hover, .linked > button:active, .linked > button:checked, .linked > button:backdrop, .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) >
entry, .linked > combobox > box > button.combo:dir(ltr), .linked > combobox > box > button.combo:dir(rtl) {
  border: 1px solid #090a0f;
  border-radius: 0;
  border-right-style: none;
  box-shadow: inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1); }

.inline-toolbar button:first-child, .linked > button:first-child, combobox.linked button:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo, .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) >
entry:first-child {
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px; }
.inline-toolbar button:last-child, .linked > button:last-child, combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.combo, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) >
entry:last-child {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  border-right-style: solid; }
.inline-toolbar button:only-child, .linked > button:only-child, .linked:not(.vertical) > combobox:only-child > box > button.combo, .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) >
entry:only-child {
  border-radius: 3px;
  border-style: solid; }

.linked.vertical > button, .linked.vertical > button:hover, .linked.vertical > button:active, .linked.vertical > button:checked, .linked.vertical > button:backdrop, .linked.vertical > spinbutton:not(.vertical), .linked.vertical >
entry, .linked.vertical > combobox > box > button.combo {
  border-style: solid solid none solid;
  border-radius: 0; }

.linked.vertical > button:first-child, .linked.vertical > combobox:first-child > box > button.combo, .linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical >
entry:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px; }
.linked.vertical > button:last-child, .linked.vertical > combobox:last-child > box > button.combo, .linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical >
entry:last-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border-style: solid; }
.linked.vertical > button:only-child, .linked.vertical > combobox:only-child > box > button.combo, .linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical >
entry:only-child {
  border-radius: 3px;
  border-style: solid; }

modelbutton.flat,
.menuitem.button.flat, modelbutton.flat:backdrop, modelbutton.flat:backdrop:hover,
.menuitem.button.flat:backdrop,
.menuitem.button.flat:backdrop:hover, calendar.button, calendar.button:hover, calendar.button:backdrop, calendar.button:disabled, button:link,
button:visited, button:link:hover, button:link:active, button:link:checked,
button:visited:hover,
button:visited:active,
button:visited:checked, .scale-popup button:hover, .scale-popup button:backdrop:hover, .scale-popup button:backdrop:disabled, .scale-popup button:backdrop {
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none; }

/* menu buttons */
modelbutton.flat,
.menuitem.button.flat {
  min-height: 26px;
  padding-left: 5px;
  padding-right: 5px;
  border-radius: 3px;
  outline-offset: -2px; }
  modelbutton.flat:hover,
  .menuitem.button.flat:hover {
    background-color: #202435; }
  modelbutton.flat check:last-child,
  modelbutton.flat radio:last-child,
  .menuitem.button.flat check:last-child,
  .menuitem.button.flat radio:last-child {
    margin-left: 8px; }
  modelbutton.flat check:first-child,
  modelbutton.flat radio:first-child,
  .menuitem.button.flat check:first-child,
  .menuitem.button.flat radio:first-child {
    margin-right: 8px; }

modelbutton.flat arrow {
  background: none; }
  modelbutton.flat arrow:hover {
    background: none; }
  modelbutton.flat arrow.left {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
  modelbutton.flat arrow.right {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

button.color {
  padding: 4px; }
  button.color colorswatch:only-child, button.color colorswatch:only-child overlay {
    border-radius: 0; }

notebook button, list button, .view button, iconview button, popover button {
  box-shadow: none; }
  notebook button:backdrop, list button:backdrop, .view button:backdrop, iconview button:backdrop, popover button:backdrop {
    box-shadow: none; }
notebook .linked > button, list .linked > button, .view .linked > button, iconview .linked > button, popover .linked > button {
  box-shadow: none; }

/************
 * Calendar *
 ***********/
calendar {
  color: #C3C7D1;
  border: 1px solid #090a0f; }
  calendar:selected {
    border-radius: 3px; }
  calendar.header {
    border-bottom: 1px solid rgba(0, 0, 0, 0.1);
    border-radius: 0; }
    calendar.header:backdrop {
      border-color: rgba(0, 0, 0, 0.1); }
  calendar.button {
    color: rgba(195, 199, 209, 0.45); }
    calendar.button:hover {
      color: #C3C7D1; }
    calendar.button:backdrop {
      color: rgba(109, 112, 123, 0.45); }
    calendar.button:disabled {
      color: rgba(109, 112, 123, 0.45); }
  calendar:indeterminate, calendar:indeterminate:backdrop {
    color: alpha(currentColor,0.55); }
  calendar.highlight, calendar.highlight:backdrop {
    font-size: smaller;
    color: #C3C7D1; }
  calendar:backdrop {
    color: #a1a5b0;
    border-color: #0a0c11; }

/*************************
 * Check and Radio Items *
 *************************/
check {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-dark.png"), url("../assets/radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-hover-dark.png"), url("../assets/checkbox-unchecked-hover@2.png"));
  -gtk-icon-shadow: none; }

radio:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-hover-dark.png"), url("../assets/radio-unchecked-hover@2.png"));
  -gtk-icon-shadow: none; }

check:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-active-dark.png"), url("../assets/checkbox-unchecked-active@2.png"));
  -gtk-icon-shadow: none; }

radio:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-active-dark.png"), url("../assets/radio-unchecked-active@2.png"));
  -gtk-icon-shadow: none; }

check:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-backdrop-dark.png"), url("../assets/checkbox-unchecked-backdrop@2.png"));
  -gtk-icon-shadow: none; }

radio:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-backdrop-dark.png"), url("../assets/radio-unchecked-backdrop@2.png"));
  -gtk-icon-shadow: none; }

check:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-insensitive-dark.png"), url("../assets/checkbox-unchecked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-insensitive-dark.png"), url("../assets/radio-unchecked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

check:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-insensitive-dark.png"), url("../assets/checkbox-unchecked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

radio:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-insensitive-dark.png"), url("../assets/radio-unchecked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

check:checked {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-dark.png"), url("../assets/radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-hover-dark.png"), url("../assets/checkbox-checked-hover@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-hover-dark.png"), url("../assets/radio-checked-hover@2.png"));
  -gtk-icon-shadow: none; }

check:checked:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-active-dark.png"), url("../assets/checkbox-checked-active@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active-dark.png"), url("../assets/radio-checked-active@2.png"));
  -gtk-icon-shadow: none; }

check:checked:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-backdrop-dark.png"), url("../assets/checkbox-checked-backdrop@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-backdrop-dark.png"), url("../assets/radio-checked-backdrop@2.png"));
  -gtk-icon-shadow: none; }

check:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-insensitive-dark.png"), url("../assets/checkbox-checked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-insensitive-dark.png"), url("../assets/radio-checked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

check:checked:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-insensitive-dark.png"), url("../assets/checkbox-checked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-insensitive-dark.png"), url("../assets/radio-checked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-mixed.png"), url("../assets/checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed.png"), url("../assets/radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-mixed-hover.png"), url("../assets/checkbox-mixed-hover@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-hover.png"), url("../assets/radio-mixed-hover@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-mixed-active.png"), url("../assets/checkbox-mixed-active@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-mixed-backdrop.png"), url("../assets/checkbox-mixed-backdrop@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-backdrop.png"), url("../assets/radio-mixed-backdrop@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-mixed-insensitive.png"), url("../assets/checkbox-mixed-insensitive@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-insensitive.png"), url("../assets/radio-mixed-insensitive@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-mixed-insensitive.png"), url("../assets/checkbox-mixed-insensitive@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-insensitive.png"), url("../assets/radio-mixed-insensitive@2.png"));
  -gtk-icon-shadow: none; }

check:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-unchecked-dark.png"), url("../assets/selected-radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:hover:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio:hover:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-unchecked-dark.png"), url("../assets/selected-radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:active:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio:active:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-unchecked-dark.png"), url("../assets/selected-radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-unchecked-dark.png"), url("../assets/selected-radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:disabled:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio:disabled:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-unchecked-dark.png"), url("../assets/selected-radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:disabled:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-unchecked-dark.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

radio:disabled:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-unchecked-dark.png"), url("../assets/selected-radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-checked-dark.png"), url("../assets/selected-radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:hover:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:hover:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-checked-dark.png"), url("../assets/selected-radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:active:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:active:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-checked-dark.png"), url("../assets/selected-radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-checked-dark.png"), url("../assets/selected-radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:disabled:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:disabled:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-checked-dark.png"), url("../assets/selected-radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:checked:disabled:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/checkbox-checked-dark.png"), url("../assets/checkbox-checked@2.png"));
  -gtk-icon-shadow: none; }

radio:checked:disabled:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-checked-dark.png"), url("../assets/selected-radio-checked@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-checkbox-mixed.png"), url("../assets/selected-checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-mixed.png"), url("../assets/selected-radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:hover:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-checkbox-mixed.png"), url("../assets/selected-checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:hover:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-mixed.png"), url("../assets/selected-radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:active:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-checkbox-mixed.png"), url("../assets/selected-checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:active:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-mixed.png"), url("../assets/selected-radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-checkbox-mixed.png"), url("../assets/selected-checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-mixed.png"), url("../assets/selected-radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:disabled:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-checkbox-mixed.png"), url("../assets/selected-checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:disabled:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-mixed.png"), url("../assets/selected-radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

check:indeterminate:disabled:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-checkbox-mixed.png"), url("../assets/selected-checkbox-mixed@2.png"));
  -gtk-icon-shadow: none; }

radio:indeterminate:disabled:backdrop:selected {
  -gtk-icon-source: -gtk-scaled(url("../assets/selected-radio-mixed.png"), url("../assets/selected-radio-mixed@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view check, iconview.content-view check,
.view.content-view.check,
iconview.content-view.check {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-checkbox-unchecked.png"), url("../assets/checkbox-unchecked@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view radio, iconview.content-view radio,
.view.content-view.radio,
iconview.content-view.radio {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-radio-unchecked.png"), url("../assets/radio-unchecked@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view check:hover, iconview.content-view check:hover,
.view.content-view.check:hover,
iconview.content-view.check:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-checkbox-unchecked-hover.png"), url("../assets/checkbox-unchecked-hover@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view radio:hover, iconview.content-view radio:hover,
.view.content-view.radio:hover,
iconview.content-view.radio:hover {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-radio-unchecked-hover.png"), url("../assets/radio-unchecked-hover@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view check:active, iconview.content-view check:active,
.view.content-view.check:active,
iconview.content-view.check:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-checkbox-unchecked-active.png"), url("../assets/checkbox-unchecked-active@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view radio:active, iconview.content-view radio:active,
.view.content-view.radio:active,
iconview.content-view.radio:active {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-radio-unchecked-active.png"), url("../assets/radio-unchecked-active@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view check:backdrop, iconview.content-view check:backdrop,
.view.content-view.check:backdrop,
iconview.content-view.check:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-checkbox-unchecked-backdrop.png"), url("../assets/checkbox-unchecked-backdrop@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view radio:backdrop, iconview.content-view radio:backdrop,
.view.content-view.radio:backdrop,
iconview.content-view.radio:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-radio-unchecked-backdrop.png"), url("../assets/radio-unchecked-backdrop@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view check:disabled, iconview.content-view check:disabled,
.view.content-view.check:disabled,
iconview.content-view.check:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-checkbox-unchecked-insensitive.png"), url("../assets/checkbox-unchecked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view radio:disabled, iconview.content-view radio:disabled,
.view.content-view.radio:disabled,
iconview.content-view.radio:disabled {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-radio-unchecked-insensitive.png"), url("../assets/radio-unchecked-insensitive@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view check:disabled:backdrop, iconview.content-view check:disabled:backdrop,
.view.content-view.check:disabled:backdrop,
iconview.content-view.check:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-checkbox-unchecked-backdrop-insensitive.png"), url("../assets/checkbox-unchecked-backdrop-insensitive@2.png"));
  -gtk-icon-shadow: none; }

.view.content-view radio:disabled:backdrop, iconview.content-view radio:disabled:backdrop,
.view.content-view.radio:disabled:backdrop,
iconview.content-view.radio:disabled:backdrop {
  -gtk-icon-source: -gtk-scaled(url("../assets/selection-mode-radio-unchecked-backdrop-insensitive.png"), url("../assets/radio-unchecked-backdrop-insensitive@2.png"));
  -gtk-icon-shadow: none; }

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0; }
  checkbutton.text-button label:not(:only-child):first-child, radiobutton.text-button label:not(:only-child):first-child {
    margin-left: 4px; }
  checkbutton.text-button label:not(:only-child):last-child, radiobutton.text-button label:not(:only-child):last-child {
    margin-right: 4px; }

check,
radio {
  margin: 0 4px;
  min-height: 16px;
  min-width: 16px;
  border: none; }
  menu menuitem check, menu menuitem
  radio {
    margin: 0; }
    menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem
    radio, menu menuitem
    radio:hover, menu menuitem
    radio:disabled {
      min-height: 14px;
      min-width: 14px;
      background-image: none;
      background-color: transparent;
      box-shadow: none;
      -gtk-icon-shadow: none;
      color: inherit;
      border-color: currentColor;
      animation: none; }

/*****************
 * Color Chooser *
 *****************/
colorswatch, colorswatch:drop(active) {
  border-style: none; }
colorswatch.top {
  border-top-left-radius: 5.5px;
  border-top-right-radius: 5.5px; }
  colorswatch.top overlay {
    border-top-left-radius: 5px;
    border-top-right-radius: 5px; }
colorswatch.bottom {
  border-bottom-left-radius: 5.5px;
  border-bottom-right-radius: 5.5px; }
  colorswatch.bottom overlay {
    border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px; }
colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 5.5px;
  border-bottom-left-radius: 5.5px; }
  colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px; }
colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 5.5px;
  border-bottom-right-radius: 5.5px; }
  colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px; }
colorswatch.dark overlay {
  color: #fefefe; }
  colorswatch.dark overlay:hover {
    border-color: #090a0f; }
  colorswatch.dark overlay:backdrop {
    color: rgba(254, 254, 254, 0.5); }
colorswatch.light overlay {
  color: #C3C7D1; }
  colorswatch.light overlay:hover {
    border-color: #090a0f; }
  colorswatch.light overlay:backdrop {
    color: #a1a5b0; }
colorswatch:drop(active) {
  box-shadow: none; }
  colorswatch:drop(active).light overlay {
    border-color: #71f79f;
    box-shadow: inset 0 0 0 2px #090a0f, inset 0 0 0 1px #71f79f; }
  colorswatch:drop(active).dark overlay {
    border-color: #71f79f;
    box-shadow: inset 0 0 0 2px #090a0f, inset 0 0 0 1px #71f79f; }
colorswatch overlay {
  box-shadow: inset 0 3px 2px -2px rgba(0, 0, 0, 0.5);
  border: 1px solid #090a0f; }
  colorswatch overlay:hover {
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.3); }
  colorswatch overlay:backdrop, colorswatch overlay:backdrop:hover {
    border-color: #090a0f;
    box-shadow: none; }
colorswatch#add-color-button {
  border-radius: 5px 5px 0 0; }
  colorswatch#add-color-button:only-child {
    border-radius: 5px; }
  colorswatch#add-color-button overlay {
    font-weight: normal;
    color: #C3C7D1;
    background-color: #202435;
    text-shadow: none; }
    colorswatch#add-color-button overlay:hover {
      color: #C3C7D1;
      outline-color: rgba(195, 199, 209, 0.3);
      background-color: #181b28;
      text-shadow: none; }
    colorswatch#add-color-button overlay:backdrop {
      color: #a1a5b0;
      outline-color: rgba(195, 199, 209, 0.3);
      background-color: #1a1d2b;
      text-shadow: none; }
colorswatch:disabled {
  opacity: 0.5; }
  colorswatch:disabled overlay {
    border-color: rgba(0, 0, 0, 0.6);
    box-shadow: none; }
row:selected colorswatch {
  box-shadow: 0 0 0 2px #fefefe; }
colorswatch#editor-color-sample {
  border-radius: 4px; }
  colorswatch#editor-color-sample overlay {
    border-radius: 4.5px; }

colorchooser .popover.osd {
  border-radius: 5px; }

/**************
 * ComboBoxes *
 **************/
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px; }
combobox:drop(active) {
  box-shadow: none; }

/***********
 * Dialogs *
 ***********/
messagedialog .titlebar:not(headerbar) {
  background-color: rgba(22, 25, 37, 0.95); }
messagedialog .titlebar {
  min-height: 20px;
  background-image: none;
  background-color: rgba(22, 25, 37, 0.95);
  border-style: none;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px; }
messagedialog.csd.background {
  background-color: rgba(22, 25, 37, 0.95);
  color: #C3C7D1;
  border-bottom-left-radius: 5px;
  border-bottom-right-radius: 5px; }
messagedialog.csd .dialog-action-area button {
  padding: 10px 14px;
  border-radius: 0;
  border-left-style: solid;
  border-right-style: none;
  border-bottom-style: none;
  background-color: transparent;
  color: #C3C7D1;
  box-shadow: none; }
  messagedialog.csd .dialog-action-area button:hover {
    background-color: rgba(197, 14, 210, 0.9);
    color: white; }
  messagedialog.csd .dialog-action-area button:first-child {
    border-left-style: none;
    border-bottom-left-radius: 4px; }
  messagedialog.csd .dialog-action-area button:last-child {
    border-bottom-right-radius: 4px; }
  messagedialog.csd .dialog-action-area button.destructive-action, messagedialog.csd .dialog-action-area button.suggested-action {
    color: white; }

filechooser .dialog-action-box {
  border-top: 1px solid #090a0f; }
  filechooser .dialog-action-box:backdrop {
    border-top-color: #0a0c11; }
filechooser #pathbarbox {
  border-bottom: 1px solid #161925; }

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent; }

/****************
 * Text Entries *
 ****************/
spinbutton:not(.vertical), entry {
  min-height: 28px;
  padding-left: 8px;
  padding-right: 8px;
  border: 1px solid;
  border-radius: 3px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #C3C7D1;
  border-color: #090a0f;
  background-color: #202435; }
  spinbutton:not(.vertical) image.left,
  entry image.left {
    padding-left: 0;
    padding-right: 6px; }
  spinbutton:not(.vertical) image.right,
  entry image.right {
    padding-left: 6px;
    padding-right: 0; }
  spinbutton:not(.vertical) undershoot.left,
  entry undershoot.left {
    background-color: transparent;
    background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
    padding-left: 1px;
    background-size: 1px 10px;
    background-repeat: repeat-y;
    background-origin: content-box;
    background-position: left center;
    border: none;
    box-shadow: none; }
  spinbutton:not(.vertical) undershoot.right,
  entry undershoot.right {
    background-color: transparent;
    background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
    padding-right: 1px;
    background-size: 1px 10px;
    background-repeat: repeat-y;
    background-origin: content-box;
    background-position: right center;
    border: none;
    box-shadow: none; }
  spinbutton.flat:focus-within:not(.vertical), spinbutton.flat:not(.vertical),
  entry.flat:focus-within,
  entry.flat {
    min-height: 0;
    padding: 2px;
    background-image: none;
    border-color: transparent;
    box-shadow: none;
    border-radius: 0; }
  spinbutton:focus-within:not(.vertical),
  entry:focus-within {
    border-color: #980ba2; }
  spinbutton:disabled:not(.vertical),
  entry:disabled {
    color: #6d707b;
    border-color: #090a0f;
    background-color: #171a26;
    box-shadow: none; }
  spinbutton:backdrop:not(.vertical),
  entry:backdrop {
    color: #a1a5b0;
    border-color: #0a0c11;
    background-color: #1a1d2b;
    box-shadow: none;
    transition: 200ms ease-out; }
  spinbutton:backdrop:disabled:not(.vertical),
  entry:backdrop:disabled {
    color: #333955;
    border-color: #0a0c11;
    background-color: #171a26;
    box-shadow: none; }
  spinbutton.error:not(.vertical),
  entry.error {
    color: #C3C7D1;
    border-color: #090a0f;
    background-color: #202435;
    color: #e6133e;
    border-color: #410512; }
    spinbutton.error:focus-within:not(.vertical),
    entry.error:focus-within {
      border-color: #410512; }
    spinbutton.error:selected:focus:not(.vertical), spinbutton.error:selected:not(.vertical),
    entry.error:selected:focus,
    entry.error:selected {
      background-color: #e6133e; }
  spinbutton.warning:not(.vertical),
  entry.warning {
    color: #C3C7D1;
    border-color: #090a0f;
    background-color: #202435;
    color: #cc5500;
    border-color: #1a0b00; }
    spinbutton.warning:focus-within:not(.vertical),
    entry.warning:focus-within {
      border-color: #1a0b00; }
    spinbutton.warning:selected:focus:not(.vertical), spinbutton.warning:selected:not(.vertical),
    entry.warning:selected:focus,
    entry.warning:selected {
      background-color: #cc5500; }
  spinbutton:not(.vertical) image,
  entry image {
    color: #a1a5af; }
    spinbutton:not(.vertical) image:hover,
    entry image:hover {
      color: #C3C7D1; }
    spinbutton:not(.vertical) image:active,
    entry image:active {
      color: #c50ed2; }
    spinbutton:not(.vertical) image:backdrop,
    entry image:backdrop {
      color: #5c5f6b; }
  spinbutton:drop(active):focus-within:not(.vertical), spinbutton:drop(active):not(.vertical),
  entry:drop(active):focus-within,
  entry:drop(active) {
    border-color: #71f79f;
    box-shadow: inset 0 0 0 1px #71f79f; }
  .osd spinbutton:not(.vertical),
  .osd entry {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: rgba(0, 0, 0, 0.5);
    box-shadow: none;
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton:focus-within:not(.vertical),
    .osd entry:focus-within {
      color: white;
      border-color: #c50ed2;
      background-color: rgba(0, 0, 0, 0.5);
      background-clip: padding-box;
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton:backdrop:not(.vertical),
    .osd entry:backdrop {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: rgba(0, 0, 0, 0.5);
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd spinbutton:disabled:not(.vertical),
    .osd entry:disabled {
      color: #87898d;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: rgba(40, 43, 50, 0.5);
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
spinbutton:not(.vertical) progress,
entry progress {
  margin: 2px -6px;
  background-color: transparent;
  background-image: none;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #c50ed2;
  border-style: solid;
  box-shadow: none; }
  spinbutton:not(.vertical) progress:backdrop,
  entry progress:backdrop {
    background-color: transparent; }
.linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) >
entry:focus-within + spinbutton:not(.vertical), .linked:not(.vertical) >
entry:focus-within + button, .linked:not(.vertical) >
entry:focus-within + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus-within:not(.vertical) +
entry, .linked:not(.vertical) >
entry:focus-within +
entry {
  border-left-color: #980ba2; }
.linked:not(.vertical) > spinbutton:focus-within:not(.vertical), .linked:not(.vertical) >
entry:focus-within {
  border-color: #980ba2; }
.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) >
entry:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) >
entry:drop(active) + button, .linked:not(.vertical) >
entry:drop(active) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) +
entry, .linked:not(.vertical) >
entry:drop(active) +
entry {
  border-left-color: #71f79f; }
.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical >
entry:not(:disabled) + entry:not(:disabled), .linked.vertical >
entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) {
  border-top-color: #141621;
  background-image: linear-gradient(to bottom, #181b28, #181b28); }
  .linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled):backdrop, .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):backdrop:not(.vertical), .linked.vertical >
  entry:not(:disabled) + entry:not(:disabled):backdrop, .linked.vertical >
  entry:not(:disabled) + spinbutton:not(:disabled):backdrop:not(.vertical) {
    border-top-color: #151823;
    background-image: linear-gradient(to bottom, #1a1d2b, #1a1d2b); }
.linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical), .linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, .linked.vertical >
entry:disabled + spinbutton:disabled:not(.vertical), .linked.vertical >
entry:disabled + entry:disabled {
  border-top-color: #141621; }
.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus:not(:only-child):not(.vertical),
.linked.vertical > spinbutton:not(.vertical) + entry:focus:not(:only-child), .linked.vertical >
entry + spinbutton:focus:not(:only-child):not(.vertical),
.linked.vertical >
entry + entry:focus:not(:only-child) {
  border-top-color: #980ba2; }
.linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical),
.linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), .linked.vertical >
entry + spinbutton:drop(active):not(:only-child):not(.vertical),
.linked.vertical >
entry + entry:drop(active):not(:only-child) {
  border-top-color: #71f79f; }
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + spinbutton:not(.vertical),
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + entry,
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + button,
.linked.vertical > spinbutton:focus:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical >
entry:focus:not(:only-child) + spinbutton:not(.vertical),
.linked.vertical >
entry:focus:not(:only-child) + entry,
.linked.vertical >
entry:focus:not(:only-child) + button,
.linked.vertical >
entry:focus:not(:only-child) + combobox > box > button.combo {
  border-top-color: #980ba2; }
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical),
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical >
entry:drop(active):not(:only-child) + spinbutton:not(.vertical),
.linked.vertical >
entry:drop(active):not(:only-child) + entry,
.linked.vertical >
entry:drop(active):not(:only-child) + button,
.linked.vertical >
entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #71f79f; }

treeview entry:focus-within:dir(rtl), treeview entry:focus-within:dir(ltr) {
  background-color: #181b28;
  transition-property: color, background; }
treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #181b28; }
  treeview entry.flat:focus-within, treeview entry:focus-within {
    border-color: #c50ed2; }

/*************
 * Expanders *
 *************/
expander arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  expander arrow:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
  expander arrow:hover {
    color: white; }
  expander arrow:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

/****************
 * Floating Bar *
 ****************/
.floating-bar {
  background-color: #161925;
  border-width: 1px;
  border-style: solid solid none;
  border-color: #090a0f;
  border-radius: 3px 3px 0 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  .floating-bar.bottom.left {
    border-left-style: none;
    border-top-left-radius: 0; }
  .floating-bar.bottom.right {
    border-right-style: none;
    border-top-right-radius: 0; }
  .floating-bar > button {
    padding: 4px; }
  .floating-bar:backdrop {
    background-color: #161925;
    border-color: #0a0c11; }

/**********
 * Frames *
 **********/
frame > border,
.frame {
  box-shadow: none;
  margin: 0;
  padding: 0;
  border-radius: 0;
  border: 1px solid #090a0f; }
  frame > border.flat,
  .frame.flat {
    border-style: none; }
  frame > border:backdrop,
  .frame:backdrop {
    border-color: #0a0c11; }

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid #090a0f; }
  actionbar > revealer > box:backdrop {
    border-color: #0a0c11; }

scrolledwindow viewport.frame {
  border-style: none; }
scrolledwindow overshoot.top {
  background-image: radial-gradient(farthest-side at top, #212638 85%, rgba(33, 38, 56, 0)), radial-gradient(farthest-side at top, #212638, rgba(33, 38, 56, 0));
  background-size: 100% 5%, 100% 100%;
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.top:backdrop {
    background-image: radial-gradient(farthest-side at top, #212638 85%, rgba(33, 38, 56, 0));
    background-size: 100% 5%;
    background-repeat: no-repeat;
    background-position: center top;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, #212638 85%, rgba(33, 38, 56, 0)), radial-gradient(farthest-side at bottom, #212638, rgba(33, 38, 56, 0));
  background-size: 100% 5%, 100% 100%;
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.bottom:backdrop {
    background-image: radial-gradient(farthest-side at bottom, #212638 85%, rgba(33, 38, 56, 0));
    background-size: 100% 5%;
    background-repeat: no-repeat;
    background-position: center bottom;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow overshoot.left {
  background-image: radial-gradient(farthest-side at left, #212638 85%, rgba(33, 38, 56, 0)), radial-gradient(farthest-side at left, #212638, rgba(33, 38, 56, 0));
  background-size: 5% 100%, 100% 100%;
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.left:backdrop {
    background-image: radial-gradient(farthest-side at left, #212638 85%, rgba(33, 38, 56, 0));
    background-size: 5% 100%;
    background-repeat: no-repeat;
    background-position: left center;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow overshoot.right {
  background-image: radial-gradient(farthest-side at right, #212638 85%, rgba(33, 38, 56, 0)), radial-gradient(farthest-side at right, #212638, rgba(33, 38, 56, 0));
  background-size: 5% 100%, 100% 100%;
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.right:backdrop {
    background-image: radial-gradient(farthest-side at right, #212638 85%, rgba(33, 38, 56, 0));
    background-size: 5% 100%;
    background-repeat: no-repeat;
    background-position: right center;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow undershoot.top {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-top: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center top;
  border: none;
  box-shadow: none; }
scrolledwindow undershoot.bottom {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-bottom: 1px;
  background-size: 10px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: center bottom;
  border: none;
  box-shadow: none; }
scrolledwindow undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-left: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left center;
  border: none;
  box-shadow: none; }
scrolledwindow undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
  padding-right: 1px;
  background-size: 1px 10px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right center;
  border: none;
  box-shadow: none; }
scrolledwindow junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, #090a0f 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: #171a27; }
  scrolledwindow junction:dir(rtl) {
    border-image-slice: 0 1 0 0; }
  scrolledwindow junction:backdrop {
    border-image-source: linear-gradient(to bottom, #0a0c11 1px, transparent 1px);
    background-color: #10131b;
    transition: 200ms ease-out; }

separator {
  background: rgba(0, 0, 0, 0.1); }

/************
 * Popovers *
 ************/
GraniteWidgetsPopOver {
  border: 1px solid #181b28;
  background: #181b28;
  color: #C3C7D1; }
  GraniteWidgetsPopOver .button {
    background-image: none;
    background: none;
    border: none; }
    GraniteWidgetsPopOver .button:active, GraniteWidgetsPopOver .button:active:hover {
      color: #c50ed2; }
  GraniteWidgetsPopOver > .frame {
    border: none; }
  GraniteWidgetsPopOver .sidebar.view, GraniteWidgetsPopOver iconview.sidebar {
    border: none;
    background: none; }

GraniteWidgetsStaticNotebook .frame {
  border: none; }

.popover_bg {
  background-color: #181b28;
  background-image: none;
  border: 1px solid #181b28;
  color: #C3C7D1; }

/***********
 * Welcome *
 **********/
GraniteWidgetsWelcome {
  background-color: #181b28; }
  GraniteWidgetsWelcome GtkLabel {
    color: #C3C7D1; }
  GraniteWidgetsWelcome .h1, GraniteWidgetsWelcome .h3 {
    color: rgba(195, 199, 209, 0.8); }

/**************
* Source List *
***************/
.source-list {
  background-color: #161925;
  border: solid #090a0f;
  color: #C3C7D1;
  border-right-width: 1px; }
  .source-list .category-expander {
    color: transparent; }
  .source-list .badge {
    background-image: none;
    background-color: rgba(0, 0, 0, 0.4);
    color: #161925;
    border-radius: 10px;
    padding: 0 6px;
    margin: 0 3px;
    border-width: 0; }
    .source-list .badge:selected:backdrop, .source-list .badge:selected:hover:backdrop {
      background-color: rgba(0, 0, 0, 0.2);
      color: #0c0e15; }
  .source-list row,
  .source-list .list-row {
    border: none;
    padding: 0; }
    .source-list row > GtkLabel,
    .source-list row > label,
    .source-list .list-row > GtkLabel,
    .source-list .list-row > label {
      padding-left: 6px;
      padding-right: 6px; }

/**************
* Text Styles *
**************/
.h1 {
  font-size: 24px; }

.h2 {
  font-weight: 300;
  font-size: 18px; }

.h3 {
  font-size: 11px; }

.h4,
.category-label {
  font-size: 12px;
  padding: 6px;
  color: rgba(195, 199, 209, 0.3);
  font-weight: bold;
  text-shadow: 0 1px rgba(255, 255, 255, 0.2); }

/**************
* Storage Bar *
**************/
.storage-bar .trough {
  border: none;
  box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.1);
  background-image: none;
  background-color: transparent;
  padding: 8px 6px; }
.storage-bar .fill-block {
  background-color: #f9dc5c;
  border: none;
  box-shadow: inset 0 1px 0 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 0 rgba(0, 0, 0, 0.1);
  transition: all 200ms ease-in-out;
  padding: 8px 6px; }
  .storage-bar .fill-block:first-child {
    border-top-left-radius: 4px;
    border-bottom-left-radius: 4px;
    border-left-width: 1px;
    box-shadow: inset 0 1px 0 0 rgba(0, 0, 0, 0.1), inset 1px 0 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 0 rgba(0, 0, 0, 0.1); }
  .storage-bar .fill-block:last-child {
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px;
    box-shadow: inset 0 1px 0 0 rgba(0, 0, 0, 0.1), inset -1px 0 0 rgba(0, 0, 0, 0.1), inset 0 -1px 0 0 rgba(0, 0, 0, 0.1); }
  .storage-bar .fill-block.empty-block {
    background-color: #181b28; }
  .storage-bar .fill-block.app {
    background-color: #7cb7ff; }
  .storage-bar .fill-block.audio {
    background-color: #ff6a00; }
  .storage-bar .fill-block.photo {
    background-color: #ed254e; }
  .storage-bar .fill-block.video {
    background-color: #c74ded; }
  .storage-bar .fill-block .legend {
    padding: 12px;
    border-radius: 4px; }

/***************
 * Header bars *
 ***************/
.titlebar:not(headerbar), .titlebar, headerbar {
  padding: 0px 13px;
  min-height: 34px;
  background: #0c0e14;
  color: #C3C7D1;
  border-radius: 0; }
  .titlebar:backdrop,
  headerbar:backdrop {
    border-color: #0a0c11;
    transition: 200ms ease-out; }
  .titlebar .title,
  headerbar .title {
    font-weight: bold;
    padding-left: 12px;
    padding-right: 12px; }
  .titlebar .subtitle,
  headerbar .subtitle {
    font-size: smaller;
    padding-left: 12px;
    padding-right: 12px; }
  .titlebar entry,
  headerbar entry {
    min-height: 24px; }
  .titlebar button,
  headerbar button {
    color: #8b8b8b;
    text-shadow: none;
    box-shadow: none;
    background: transparent;
    border: none;
    min-height: 14px;
    margin-top: 5px;
    margin-bottom: 5px;
    box-shadow: none; }
    .titlebar button.image-button,
    headerbar button.image-button {
      padding: 3px 4px; }
    .titlebar button.suggested-action,
    headerbar button.suggested-action {
      box-shadow: none;
      border: none;
      background-image: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
      .titlebar button.suggested-action:disabled, .titlebar button.suggested-action:disabled:backdrop, .titlebar button.suggested-action:backdrop,
      headerbar button.suggested-action:disabled,
      headerbar button.suggested-action:disabled:backdrop,
      headerbar button.suggested-action:backdrop {
        border: none;
        background-image: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
        .titlebar button.suggested-action:disabled:hover, .titlebar button.suggested-action:disabled:active, .titlebar button.suggested-action:disabled:checked, .titlebar button.suggested-action:disabled:backdrop:hover, .titlebar button.suggested-action:disabled:backdrop:active, .titlebar button.suggested-action:disabled:backdrop:checked, .titlebar button.suggested-action:backdrop:hover, .titlebar button.suggested-action:backdrop:active, .titlebar button.suggested-action:backdrop:checked,
        headerbar button.suggested-action:disabled:hover,
        headerbar button.suggested-action:disabled:active,
        headerbar button.suggested-action:disabled:checked,
        headerbar button.suggested-action:disabled:backdrop:hover,
        headerbar button.suggested-action:disabled:backdrop:active,
        headerbar button.suggested-action:disabled:backdrop:checked,
        headerbar button.suggested-action:backdrop:hover,
        headerbar button.suggested-action:backdrop:active,
        headerbar button.suggested-action:backdrop:checked {
          border: none;
          background-image: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
    .titlebar button.appmenu,
    headerbar button.appmenu {
      background: transparent; }
      .titlebar button.appmenu:backdrop,
      headerbar button.appmenu:backdrop {
        background: transparent; }
    .titlebar button:hover, .titlebar button:active, .titlebar button:checked,
    headerbar button:hover,
    headerbar button:active,
    headerbar button:checked {
      background-color: transparent;
      color: #c50ed2;
      box-shadow: none;
      border: none; }
    .titlebar button:backdrop, .titlebar button:disabled, .titlebar button:backdrop:disabled,
    headerbar button:backdrop,
    headerbar button:disabled,
    headerbar button:backdrop:disabled {
      color: rgba(195, 199, 209, 0.2);
      background-color: transparent;
      border-radius: 0;
      text-shadow: none;
      box-shadow: none;
      border: none; }
    .titlebar button:backdrop:hover, .titlebar button:backdrop:active, .titlebar button:backdrop:checked,
    headerbar button:backdrop:hover,
    headerbar button:backdrop:active,
    headerbar button:backdrop:checked {
      background-color: transparent;
      color: #c50ed2;
      box-shadow: none; }
      .titlebar button:backdrop:hover label, .titlebar button:backdrop:active label, .titlebar button:backdrop:checked label,
      headerbar button:backdrop:hover label,
      headerbar button:backdrop:active label,
      headerbar button:backdrop:checked label {
        color: #c50ed2; }
    .titlebar button.suggested-action,
    headerbar button.suggested-action {
      font-weight: bold;
      min-height: 24px;
      margin-top: 5px;
      margin-bottom: 5px;
      border-radius: 4px;
      font-weight: normal;
      color: white;
      background-color: #202435;
      text-shadow: none;
      box-shadow: none; }
      .titlebar button.suggested-action:hover,
      headerbar button.suggested-action:hover {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #00c1e4;
        text-shadow: none; }
      .titlebar button.suggested-action:active,
      headerbar button.suggested-action:active {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #00c1e4;
        text-shadow: none; }
      .titlebar button.suggested-action:disabled,
      headerbar button.suggested-action:disabled {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #00c1e4;
        text-shadow: none; }
        .titlebar button.suggested-action:disabled label,
        headerbar button.suggested-action:disabled label {
          color: rgba(255, 255, 255, 0.5); }
      .titlebar button.suggested-action:backdrop,
      headerbar button.suggested-action:backdrop {
        color: rgba(255, 255, 255, 0.4);
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #00c1e4;
        text-shadow: none;
        border-radius: 3px; }
      .titlebar button.suggested-action:backdrop:disabled,
      headerbar button.suggested-action:backdrop:disabled {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #00c1e4;
        text-shadow: none; }
    .titlebar button.destructive-action,
    headerbar button.destructive-action {
      font-weight: bold;
      min-height: 24px;
      margin-top: 5px;
      margin-bottom: 5px;
      border-radius: 4px;
      font-weight: normal;
      color: white;
      background-color: #202435;
      text-shadow: none;
      box-shadow: none; }
      .titlebar button.destructive-action:hover,
      headerbar button.destructive-action:hover {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #ce1138;
        text-shadow: none; }
      .titlebar button.destructive-action:active,
      headerbar button.destructive-action:active {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #ce1138;
        text-shadow: none; }
      .titlebar button.destructive-action:disabled,
      headerbar button.destructive-action:disabled {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #ce1138;
        text-shadow: none; }
        .titlebar button.destructive-action:disabled label,
        headerbar button.destructive-action:disabled label {
          color: rgba(255, 255, 255, 0.5); }
      .titlebar button.destructive-action:backdrop,
      headerbar button.destructive-action:backdrop {
        color: rgba(255, 255, 255, 0.4);
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #ce1138;
        text-shadow: none;
        border-radius: 3px; }
      .titlebar button.destructive-action:backdrop:disabled,
      headerbar button.destructive-action:backdrop:disabled {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        background-color: #ce1138;
        text-shadow: none; }
    .titlebar button.titlebutton,
    headerbar button.titlebutton {
      color: transparent;
      box-shadow: none;
      border: none;
      background-color: transparent;
      background-image: none;
      background-repeat: no-repeat; }
      .titlebar button.titlebutton:hover, .titlebar button.titlebutton:active, .titlebar button.titlebutton:checked, .titlebar button.titlebutton:backdrop, .titlebar button.titlebutton:backdrop:hover, .titlebar button.titlebutton *,
      headerbar button.titlebutton:hover,
      headerbar button.titlebutton:active,
      headerbar button.titlebutton:checked,
      headerbar button.titlebutton:backdrop,
      headerbar button.titlebutton:backdrop:hover,
      headerbar button.titlebutton * {
        color: transparent;
        box-shadow: none;
        background-color: transparent; }
  .titlebar .linked > button,
  .titlebar headerbar .linked > button, .titlebar .linked > button:active, .titlebar .linked > button:checked, .titlebar .linked > button:hover,
  .titlebar .linked > button:backdrop,
  headerbar .titlebar .linked > button,
  .titlebar headerbar .linked > button,
  headerbar .linked > button,
  headerbar .titlebar .linked > button:active,
  .titlebar headerbar .linked > button:active,
  headerbar .linked > button:active,
  headerbar .titlebar .linked > button:checked,
  .titlebar headerbar .linked > button:checked,
  headerbar .linked > button:checked,
  headerbar .titlebar .linked > button:hover,
  .titlebar headerbar .linked > button:hover,
  headerbar .titlebar .linked > button:backdrop,
  .titlebar headerbar .linked > button:backdrop,
  headerbar .linked > button:hover,
  headerbar .linked > button:backdrop {
    border-radius: 23px;
    border-right-style: none;
    border: none;
    box-shadow: none;
    margin: 10px 0px;
    min-height: 20px;
    transition: all .1s ease-in; }
    .titlebar .linked > button:only-child,
    .titlebar headerbar .linked > button:only-child,
    headerbar .titlebar .linked > button:only-child,
    headerbar .linked > button:only-child {
      border-radius: 13px;
      border-style: none; }
  .titlebar .linked > button:active,
  headerbar .linked > button:active {
    background: linear-gradient(to right, #c50ed2, #8500f7);
    color: snow; }
  .titlebar .linked > button:checked,
  headerbar .linked > button:checked {
    border-radius: 23px;
    background: linear-gradient(to right, #c50ed2, #8500f7);
    box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
    color: snow; }
    .titlebar .linked > button:checked:backdrop,
    headerbar .linked > button:checked:backdrop {
      color: #ffe6e6; }
      .titlebar .linked > button:checked:backdrop label,
      headerbar .linked > button:checked:backdrop label {
        color: #ffe6e6; }
  .selection-mode.titlebar button:backdrop.flat:active, .selection-mode.titlebar button:backdrop.flat:checked, .selection-mode.titlebar button:backdrop:active, .selection-mode.titlebar button:backdrop:checked,
  headerbar.selection-mode button:backdrop.flat:active,
  headerbar.selection-mode button:backdrop.flat:checked,
  headerbar.selection-mode button:backdrop:active,
  headerbar.selection-mode button:backdrop:checked {
    border-color: #980ba2; }
    .selection-mode.titlebar button:backdrop.flat:active label, .selection-mode.titlebar button:backdrop.flat:checked label, .selection-mode.titlebar button:backdrop:active label, .selection-mode.titlebar button:backdrop:checked label,
    headerbar.selection-mode button:backdrop.flat:active label,
    headerbar.selection-mode button:backdrop.flat:checked label,
    headerbar.selection-mode button:backdrop:active label,
    headerbar.selection-mode button:backdrop:checked label {
      color: rgba(197, 14, 210, 0.6); }
  .tiled .titlebar, .maximized .titlebar,
  .tiled headerbar.titlebar, .maximized headerbar.titlebar {
    box-shadow: inset 0 -1px rgba(0, 0, 0, 0.1); }
  .tiled .titlebar:backdrop, .tiled .titlebar, .maximized .titlebar:backdrop, .maximized .titlebar,
  .tiled headerbar:backdrop,
  .tiled headerbar, .maximized headerbar:backdrop, .maximized headerbar {
    border-radius: 0; }
  .default-decoration.titlebar, headerbar.default-decoration {
    padding: 5px 4px;
    min-height: 20px; }
    .default-decoration.titlebar button.titlebutton, headerbar.default-decoration button.titlebutton {
      min-height: 20px;
      min-width: 20px;
      margin: 0;
      padding: 0; }

headerbar entry,
headerbar spinbutton,
headerbar separator {
  margin-top: 5px;
  margin-bottom: 5px; }
headerbar switch {
  margin-top: 10px;
  margin-bottom: 10px; }
headerbar separator {
  background: transparent; }

.background:not(.tiled):not(.maximized) .titlebar {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), inset 0 -1px rgba(0, 0, 0, 0.1); }
  .background:not(.tiled):not(.maximized) .titlebar:backdrop, .background:not(.tiled):not(.maximized) .titlebar {
    border-top-left-radius: 4px;
    border-top-right-radius: 4px; }

window:not(.tiled):not(.maximized) separator:first-child + headerbar:backdrop, window:not(.tiled):not(.maximized) separator:first-child + headerbar, window:not(.tiled):not(.maximized) headerbar:first-child:backdrop, window:not(.tiled):not(.maximized) headerbar:first-child {
  border-top-left-radius: 4px; }
window:not(.tiled):not(.maximized) headerbar:last-child:backdrop, window:not(.tiled):not(.maximized) headerbar:last-child {
  border-top-right-radius: 4px; }

window {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px; }

window.csd > .titlebar:not(headerbar) {
  padding: 0;
  background-color: transparent;
  background-image: none;
  border-style: none;
  border-color: transparent;
  box-shadow: none; }
.titlebar:not(headerbar) > separator, .titlebar:not(headerbar) > separator:backdrop {
  background: #0c0e14; }

/**************
 * GtkInfoBar *
 **************/
.info, .warning, .question, .error,
infobar {
  text-shadow: none;
  color: #C3C7D1;
  background-color: #161925;
  border-bottom: 1px solid #030305;
  box-shadow: none; }

.info, .warning, .question, .error {
  text-shadow: none;
  color: #fefefe;
  border: none; }
  .info .label, .warning .label, .question .label, .error .label {
    color: #fefefe; }
    .info .label:backdrop, .warning .label:backdrop, .question .label:backdrop, .error .label:backdrop {
      color: rgba(254, 254, 254, 0.5); }
  .info button, .warning button, .question button, .error button {
    border-radius: 2px;
    border: none;
    background: rgba(24, 27, 40, 0.98);
    color: #C3C7D1;
    box-shadow: 0 1px 0 0 rgba(0, 0, 0, 0.2); }
    .info button .label, .warning button .label, .question button .label, .error button .label {
      color: #C3C7D1; }
    .info button:active, .warning button:active, .question button:active, .error button:active {
      background: #181b28;
      color: #C3C7D1;
      box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.4); }
      .info button:active:backdrop, .warning button:active:backdrop, .question button:active:backdrop, .error button:active:backdrop {
        background: rgba(24, 27, 40, 0.8);
        color: rgba(195, 199, 209, 0.5);
        box-shadow: none; }
    .info button:hover, .warning button:hover, .question button:hover, .error button:hover, .info button:focus, .warning button:focus, .question button:focus, .error button:focus {
      box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.4); }
    .info button:disabled, .warning button:disabled, .question button:disabled, .error button:disabled {
      background: rgba(24, 27, 40, 0.6);
      color: rgba(195, 199, 209, 0.5);
      box-shadow: none; }
      .info button:disabled:backdrop, .warning button:disabled:backdrop, .question button:disabled:backdrop, .error button:disabled:backdrop {
        background: rgba(24, 27, 40, 0.5);
        color: rgba(195, 199, 209, 0.5);
        box-shadow: none; }
    .info button:backdrop, .warning button:backdrop, .question button:backdrop, .error button:backdrop {
      background: rgba(24, 27, 40, 0.8);
      color: rgba(195, 199, 209, 0.5);
      box-shadow: none; }

.info, .info:backdrop {
  color: #71f79f;
  background-color: transparent; }

.warning, .warning:backdrop {
  color: #cc5500;
  background-color: transparent; }

.question, .question:backdrop {
  color: #00c1e4;
  background-color: transparent; }

.error, .error:backdrop {
  color: #e6133e;
  background-color: transparent; }

/*************
 * Level Bar *
 *************/
levelbar block {
  min-width: 32px;
  min-height: 6px; }
levelbar.vertical block {
  min-width: 6px;
  min-height: 32px; }
levelbar:backdrop {
  transition: 200ms ease-out; }
levelbar trough {
  padding: 3px;
  border-radius: 3px;
  background-color: rgba(255, 255, 255, 0.2);
  box-shadow: 0px 0px 1px 1px rgba(0, 0, 0, 0.1); }
  levelbar trough:backdrop {
    background-color: rgba(255, 255, 255, 0.06);
    box-shadow: 0px 0px 1px 1px rgba(0, 0, 0, 0.1); }
levelbar.horizontal.discrete block {
  margin: 0 1px; }
levelbar.vertical.discrete block {
  margin: 1px 0; }
levelbar block {
  border-radius: 2px; }
  levelbar block:backdrop {
    box-shadow: none; }
  levelbar block.low {
    background-color: #cc5500; }
    levelbar block.low:backdrop {
      border-color: #cc5500; }
  levelbar block.high, levelbar block:not(.empty) {
    background-color: #00c1e4; }
    levelbar block.high:backdrop, levelbar block:not(.empty):backdrop {
      border-color: #00c1e4; }
  levelbar block.full {
    background-color: #0096b1; }
    levelbar block.full:backdrop {
      border-color: #0096b1; }
  levelbar block.empty {
    background-color: rgba(0, 0, 0, 0.35);
    box-shadow: none; }

/*********
 * Links *
 *********/
*:link, button:link,
button:visited {
  color: #7cb7ff; }
  *:link:visited,
  button:visited {
    color: rgba(124, 183, 255, 0.5); }
    *:selected *:link:visited, *:selected button:visited:link,
    *:selected button:visited {
      color: #e79eec; }
  *:link:hover, button:hover:link,
  button:hover:visited {
    color: #afd3ff; }
    *:selected *:link:hover, *:selected button:hover:link,
    *:selected button:hover:visited {
      color: #f8e6fa; }
  *:link:active, button:active:link,
  button:active:visited {
    color: #7cb7ff; }
    *:selected *:link:active, *:selected button:active:link,
    *:selected button:active:visited {
      color: #f3cef5; }
  *:link:backdrop:backdrop:hover, button:backdrop:backdrop:hover:link,
  button:backdrop:backdrop:hover:visited, *:link:backdrop:backdrop:hover:selected, button:backdrop:backdrop:hover:selected:link,
  button:backdrop:backdrop:hover:selected:visited, *:link:backdrop, button:backdrop:link,
  button:backdrop:visited {
    color: #c50ed2; }
  *:link:selected, button:selected:link,
  button:selected:visited, *:selected *:link, *:selected button:link,
  *:selected button:visited {
    color: #f3cef5; }

button:link,
button:visited {
  text-shadow: none; }
  button:link:hover, button:link:active, button:link:checked,
  button:visited:hover,
  button:visited:active,
  button:visited:checked {
    text-shadow: none; }
  button:link > label,
  button:visited > label {
    text-decoration-line: underline; }

/*********
 * Lists *
 *********/
list, listview {
  color: #C3C7D1;
  background-color: #181b28;
  border-color: #090a0f; }
  list:backdrop, listview:backdrop {
    background-color: #1a1d2b;
    border-color: #0a0c11; }
  list.horizontal row.separator, list.separators.horizontal > row:not(.separator), listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator) {
    border-left: 1px solid #090a0f; }
  list:not(.horizontal) row.separator, list.separators:not(.horizontal) > row:not(.separator), listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator) {
    border-bottom: 1px solid #090a0f; }

row {
  padding: 5px 11px;
  transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }
  row label {
    padding-left: 8px; }
  row:hover {
    transition: none; }
  row:backdrop {
    transition: 200ms ease-out; }
  row.activatable.has-open-popup, row.activatable:hover {
    background-color: rgba(195, 199, 209, 0.05); }
  row.activatable:active {
    box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }
  row.activatable:backdrop:hover {
    background-color: transparent; }
  row.activatable:selected:active {
    box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }
  row.activatable:selected.has-open-popup, row.activatable:selected:hover {
    background-color: rgba(197, 14, 210, 0.5); }
  row.activatable:selected:backdrop {
    background-color: rgba(197, 14, 210, 0.6); }
  row.activatable button.flat {
    background-color: transparent; }

/*********
 * Menus *
 *********/
menubar,
.menubar {
  background-color: #0c0e14;
  color: #C3C7D1;
  padding: 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.1); }
  menubar > item,
  .menubar > item {
    min-height: 16px;
    padding: 4px 8px; }
    menubar > item:hover,
    .menubar > item:hover {
      box-shadow: inset 0 -3px #c50ed2; }
    menubar > item:disabled,
    .menubar > item:disabled {
      color: #6d707b;
      box-shadow: none; }

menu, .menu, .context-menu {
  font: initial;
  margin: 4px;
  padding: 2px 0px;
  background: linear-gradient(to bottom, #1a1d2b, #12151f);
  border: 1px solid #090a0f;
  border-radius: 5px; }
  .csd menu,
  .csd .menu,
  .csd .context-menu {
    border: none; }
  menu:backdrop, .menu:backdrop, .context-menu:backdrop {
    background-color: #191c2a; }
  menu menuitem, .menu menuitem, .context-menu menuitem {
    min-height: 17px;
    min-width: 40px;
    padding: 4px 6px;
    text-shadow: none; }
    menu menuitem:hover, .menu menuitem:hover, .context-menu menuitem:hover {
      color: #fefefe;
      background-color: #c50ed2; }
    menu menuitem:disabled, .menu menuitem:disabled, .context-menu menuitem:disabled {
      color: #6d707b; }
      menu menuitem:disabled:backdrop, .menu menuitem:disabled:backdrop, .context-menu menuitem:disabled:backdrop {
        color: #333955; }
    menu menuitem:backdrop, menu menuitem:backdrop:hover, .menu menuitem:backdrop, .menu menuitem:backdrop:hover, .context-menu menuitem:backdrop, .context-menu menuitem:backdrop:hover {
      color: #6d707b;
      background-color: transparent; }
    menu menuitem arrow, .menu menuitem arrow, .context-menu menuitem arrow {
      min-height: 16px;
      min-width: 16px; }
      menu menuitem arrow:dir(ltr), .menu menuitem arrow:dir(ltr), .context-menu menuitem arrow:dir(ltr) {
        -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
        margin-left: 10px; }
      menu menuitem arrow:dir(rtl), .menu menuitem arrow:dir(rtl), .context-menu menuitem arrow:dir(rtl) {
        -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
        margin-right: 10px; }
    menu menuitem label:dir(rtl), menu menuitem label:dir(ltr), .menu menuitem label:dir(rtl), .menu menuitem label:dir(ltr), .context-menu menuitem label:dir(rtl), .context-menu menuitem label:dir(ltr) {
      color: inherit; }
  menu > arrow, .menu > arrow, .context-menu > arrow {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    min-height: 16px;
    min-width: 16px;
    padding: 4px;
    background-color: #181b27;
    border-radius: 0; }
    menu > arrow.top, .menu > arrow.top, .context-menu > arrow.top {
      margin-top: -6px;
      border-bottom: 1px solid #292c39;
      -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
    menu > arrow.bottom, .menu > arrow.bottom, .context-menu > arrow.bottom {
      margin-bottom: -6px;
      border-top: 1px solid #292c39;
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    menu > arrow:hover, .menu > arrow:hover, .context-menu > arrow:hover {
      background-color: #292c39; }
    menu > arrow:backdrop, .menu > arrow:backdrop, .context-menu > arrow:backdrop {
      background-color: #191c2a; }
    menu > arrow:disabled, .menu > arrow:disabled, .context-menu > arrow:disabled {
      color: transparent;
      background-color: transparent;
      border-color: transparent; }

menuitem accelerator {
  color: alpha(currentColor,0.55); }
menuitem check,
menuitem radio {
  min-height: 16px;
  min-width: 16px; }
  menuitem check:dir(ltr),
  menuitem radio:dir(ltr) {
    margin-right: 7px; }
  menuitem check:dir(rtl),
  menuitem radio:dir(rtl) {
    margin-left: 7px; }

.csd.popup {
  background: transparent; }

/********
 * Misc *
 ********/
.content-view {
  background-color: #090a0f; }
  .content-view:hover {
    -gtk-icon-filter: brightness(1.2); }
  .content-view:backdrop {
    background-color: #090a0f; }

.osd .scale-popup button.flat {
  border-style: none;
  border-radius: 5px; }
.scale-popup button:hover {
  background-color: rgba(195, 199, 209, 0.1);
  border-radius: 5px; }

/************
* Assistant *
*************/
assistant {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px; }
  assistant .sidebar {
    background-color: #181b28;
    border-top: 1px solid #090a0f;
    border-bottom-left-radius: 4px; }
    assistant .sidebar:backdrop {
      background-color: #1a1d2b;
      border-color: #0a0c11; }
  assistant.csd .sidebar {
    border-top-style: none; }
  assistant .sidebar GtkLabel,
  assistant .sidebar label {
    padding: 6px 12px; }
  assistant .sidebar GtkLabel.highlight,
  assistant .sidebar label.highlight {
    background-color: #393c47; }

/*************
 * Notebooks *
 *************/
notebook > header {
  padding: 1px;
  border-color: transparent;
  border-width: 1px;
  background-color: #10121a; }
  notebook > header:backdrop {
    border-color: #0a0c11;
    background-color: #161925; }
  notebook > header tabs {
    margin: 0px; }
  notebook > header.top {
    border-bottom-style: solid; }
    notebook > header.top > tabs {
      margin-bottom: -2px; }
      notebook > header.top > tabs > tab:backdrop {
        box-shadow: none; }
      notebook > header.top > tabs > tab:checked {
        background: linear-gradient(to right, #5800E2, #FF00E6) left bottom #141620 no-repeat;
        background-size: 100% 2px;
        border: 0; }
  notebook > header.bottom {
    border-top-style: solid; }
    notebook > header.bottom > tabs {
      margin-top: -2px; }
      notebook > header.bottom > tabs > tab:backdrop {
        box-shadow: none; }
      notebook > header.bottom > tabs > tab:checked {
        background: linear-gradient(to right, #5800E2, #FF00E6) left bottom #141620 no-repeat;
        background-size: 100% 2px;
        border: 0; }
  notebook > header.left {
    border-right-style: solid; }
    notebook > header.left > tabs {
      margin-right: -2px; }
      notebook > header.left > tabs > tab:backdrop {
        box-shadow: none; }
      notebook > header.left > tabs > tab:checked {
        background: linear-gradient(to bottom, #5800E2, #FF00E6) left bottom #141620 no-repeat;
        background-size: 2px 100%;
        border: 0; }
  notebook > header.right {
    border-left-style: solid; }
    notebook > header.right > tabs {
      margin-left: -2px; }
      notebook > header.right > tabs > tab:backdrop {
        box-shadow: none; }
      notebook > header.right > tabs > tab:checked {
        background: linear-gradient(to bottom, #5800E2, #FF00E6) left bottom #141620 no-repeat;
        background-size: 2px 100%;
        border: 0; }
  notebook > header.top > tabs > arrow {
    border-top-style: none; }
  notebook > header.bottom > tabs > arrow {
    border-bottom-style: none; }
  notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
    margin-left: -5px;
    margin-right: -5px;
    padding-left: 4px;
    padding-right: 4px; }
    notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
      -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
    notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  notebook > header.left > tabs > arrow {
    border-left-style: none; }
  notebook > header.right > tabs > arrow {
    border-right-style: none; }
  notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
    margin-top: -5px;
    margin-bottom: -5px;
    padding-top: 4px;
    padding-bottom: 4px; }
    notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
      -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
    notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  notebook > header > tabs > arrow {
    min-height: 14px;
    min-width: 14px;
    border-radius: 0; }
    notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) {
      background-clip: padding-box;
      background-image: none;
      background-color: rgba(255, 255, 255, 0.3);
      border-color: transparent;
      box-shadow: none; }
    notebook > header > tabs > arrow:disabled {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      text-shadow: none;
      -gtk-icon-shadow: none; }
  notebook > header tab {
    min-height: 24px;
    min-width: 24px;
    padding: 1px 12px;
    outline-offset: -5px;
    color: #6d707b;
    font-weight: normal;
    border-width: 1px;
    border-color: transparent; }
    notebook > header tab:hover {
      color: #989ca6; }
      notebook > header tab:hover.reorderable-page {
        border-color: rgba(9, 10, 15, 0.3);
        background-color: rgba(22, 25, 37, 0.2); }
    notebook > header tab:backdrop {
      color: #4a4d59; }
      notebook > header tab:backdrop.reorderable-page {
        border-color: transparent;
        background-color: transparent; }
    notebook > header tab:checked {
      color: #C3C7D1; }
      notebook > header tab:checked.reorderable-page {
        border-color: rgba(9, 10, 15, 0.5);
        background-color: rgba(22, 25, 37, 0.5); }
        notebook > header tab:checked.reorderable-page:hover {
          background-color: rgba(22, 25, 37, 0.7); }
    notebook > header tab:backdrop:checked {
      color: #6d707b; }
      notebook > header tab:backdrop:checked.reorderable-page {
        border-color: #0a0c11;
        background-color: #1a1d2b; }
    notebook > header tab button.flat {
      padding: 0;
      margin-top: 4px;
      margin-bottom: 4px;
      min-width: 20px;
      min-height: 20px; }
      notebook > header tab button.flat:hover {
        background: transparent;
        box-shadow: none;
        color: #ed254e; }
      notebook > header tab button.flat, notebook > header tab button.flat:backdrop {
        color: alpha(currentColor,0.3); }
  notebook > header.top tabs, notebook > header.bottom tabs {
    padding-left: 0px;
    padding-right: 0px; }
    notebook > header.top tabs:not(:only-child), notebook > header.bottom tabs:not(:only-child) {
      margin-left: 0.5px;
      margin-right: 0.5px; }
      notebook > header.top tabs:not(:only-child):first-child, notebook > header.bottom tabs:not(:only-child):first-child {
        margin-left: -1px; }
      notebook > header.top tabs:not(:only-child):last-child, notebook > header.bottom tabs:not(:only-child):last-child {
        margin-right: -1px; }
    notebook > header.top tabs tab, notebook > header.bottom tabs tab {
      margin-left: 0.5px;
      margin-right: 0.5px; }
      notebook > header.top tabs tab.reorderable-page, notebook > header.bottom tabs tab.reorderable-page {
        border-style: none solid; }
  notebook > header.left tabs, notebook > header.right tabs {
    padding-top: 4px;
    padding-bottom: 4px; }
    notebook > header.left tabs:not(:only-child), notebook > header.right tabs:not(:only-child) {
      margin-top: 3px;
      margin-bottom: 3px; }
      notebook > header.left tabs:not(:only-child):first-child, notebook > header.right tabs:not(:only-child):first-child {
        margin-top: -1px; }
      notebook > header.left tabs:not(:only-child):last-child, notebook > header.right tabs:not(:only-child):last-child {
        margin-bottom: -1px; }
    notebook > header.left tabs tab, notebook > header.right tabs tab {
      margin-top: 4px;
      margin-bottom: 4px; }
      notebook > header.left tabs tab.reorderable-page, notebook > header.right tabs tab.reorderable-page {
        border-style: solid none; }
  notebook > header.top tab {
    padding-bottom: 3px; }
  notebook > header.bottom tab {
    padding-top: 3px; }
  notebook > header button {
    margin-top: 1px;
    margin-bottom: 1px;
    padding: 1px 1px; }
notebook > stack:not(:only-child) {
  background-color: #181b28; }
  notebook > stack:not(:only-child):backdrop {
    background-color: #1a1d2b; }

/*********
 * Paned *
 *********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(#090a0f);
  background-size: 1px 1px; }
  paned > separator:selected {
    background-image: image(#c50ed2); }
  paned > separator:backdrop {
    background-image: image(#0a0c11); }
  paned > separator.wide {
    min-width: 5px;
    min-height: 5px;
    background-color: #161925;
    background-image: image(#090a0f), image(#090a0f);
    background-size: 1px 1px, 1px 1px; }
    paned > separator.wide:backdrop {
      background-color: #161925;
      background-image: image(#0a0c11), image(#0a0c11); }
paned.horizontal > separator {
  background-repeat: repeat-y; }
  paned.horizontal > separator:dir(ltr) {
    margin: 0 -8px 0 0;
    padding: 0 8px 0 0;
    background-position: left; }
  paned.horizontal > separator:dir(rtl) {
    margin: 0 0 0 -8px;
    padding: 0 0 0 8px;
    background-position: right; }
  paned.horizontal > separator.wide {
    margin: 0;
    padding: 0;
    background-repeat: repeat-y, repeat-y;
    background-position: left, right; }
paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top; }
  paned.vertical > separator.wide {
    margin: 0;
    padding: 0;
    background-repeat: repeat-x, repeat-x;
    background-position: bottom, top; }

/************
 * Pathbars *
 ************/
.path-bar button.text-button, .path-bar button.image-button, .path-bar button {
  padding-left: 4px;
  padding-right: 4px; }
.path-bar button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0; }
.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child {
  padding-right: 8px; }
.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child {
  padding-left: 8px; }
.path-bar button image {
  padding-left: 4px;
  padding-right: 4px; }
.path-bar button.slider-button {
  padding-left: 0;
  padding-right: 0; }

/***************
 * Popovers   *
 ***************/
popover.background {
  background: transparent;
  font: initial; }
  popover.background > arrow,
  popover.background > contents {
    background: linear-gradient(to bottom, #1a1d2b, #12151f);
    background-clip: padding-box;
    border: 1px solid #090a0f;
    box-shadow: 0 4px 6px #090a0f; }
  popover.background:backdrop {
    background-color: transparent;
    box-shadow: none; }
  popover.background > contents {
    padding: 8px;
    border-radius: 5px; }
    popover.background > contents > list,
    popover.background > contents > .view,
    popover.background > contents > iconview,
    popover.background > contents > toolbar {
      border-style: none;
      background-color: transparent; }
    popover.background > contents separator {
      background-color: #0d0f16;
      margin: 3px; }
    popover.background > contents list separator {
      margin: 0; }
  .osd popover.background, popover.background.touch-selection, popover.background.magnifier {
    background-color: transparent; }
    .osd popover.background > arrow,
    .osd popover.background > contents, popover.background.touch-selection > arrow,
    popover.background.touch-selection > contents, popover.background.magnifier > arrow,
    popover.background.magnifier > contents {
      border: 1px solid rgba(255, 255, 255, 0.1);
      box-shadow: none; }

magnifier {
  background-color: #181b28; }

/*****************
 * Progress bars *
 *****************/
progressbar {
  font-size: smaller;
  color: rgba(195, 199, 209, 0.4); }
  progressbar.horizontal trough,
  progressbar.horizontal progress {
    min-height: 6px; }
  progressbar.vertical trough,
  progressbar.vertical progress {
    min-width: 6px; }
  progressbar.horizontal progress {
    margin: 0; }
  progressbar.vertical progress {
    margin: 0;
    background: linear-gradient(to bottom, #00f17d, #00f7d2); }
  progressbar:backdrop {
    box-shadow: none;
    transition: 200ms ease-out; }
  progressbar.osd {
    min-width: 3px;
    min-height: 3px;
    background-color: transparent; }
    progressbar.osd trough {
      border-style: none;
      border-radius: 0;
      background-color: transparent;
      box-shadow: none; }
    progressbar.osd progress {
      border-style: none;
      border-radius: 0; }

/************
 * GtkScale *
 ************/
progressbar trough, scale trough, scale fill {
  background-color: rgba(255, 255, 255, 0.14);
  border: none;
  border-radius: 3px;
  margin: 0; }
  progressbar trough:disabled, scale trough:disabled, scale fill:disabled {
    background-color: rgba(255, 255, 255, 0.06); }
  progressbar trough:backdrop, progressbar:backdrop trough, scale trough:backdrop, scale fill:backdrop {
    background-color: rgba(255, 255, 255, 0.06);
    transition: 200ms ease-out; }
    progressbar trough:backdrop:disabled, progressbar:backdrop trough:disabled, scale trough:backdrop:disabled, scale fill:backdrop:disabled {
      background-color: rgba(255, 255, 255, 0.06); }

progressbar progress, scale highlight {
  border: none;
  background: linear-gradient(to right, #00f17d, #00f7d2);
  border-radius: 3px;
  margin: 0; }
  progressbar progress:disabled, scale highlight:disabled {
    border: none;
    background-color: rgba(255, 255, 255, 0.14); }
  progressbar progress:backdrop, progressbar:backdrop progress, scale highlight:backdrop, progressbar progress:active:backdrop, progressbar:backdrop progress:active, scale highlight:active:backdrop {
    border-color: #db10ea;
    background-color: #db10ea; }
    progressbar progress:backdrop:disabled, progressbar:backdrop progress:disabled, scale highlight:backdrop:disabled, progressbar progress:active:backdrop:disabled, progressbar:backdrop progress:active:disabled, scale highlight:active:backdrop:disabled {
      background-color: rgba(255, 255, 255, 0.06); }

scale {
  min-height: 16px;
  min-width: 16px;
  padding: 8px; }
  scale.horizontal trough,
  scale.horizontal progress {
    min-height: 6px; }
  scale.vertical trough,
  scale.vertical progress {
    min-width: 6px; }
  scale.vertical highlight {
    background: linear-gradient(to bottom, #00f17d, #00f7d2); }
  scale slider {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    background-color: #181b28;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    border-radius: 12px;
    transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
    transition-property: background, border, box-shadow; }
    scale slider:active {
      background-color: #c50ed2; }
      scale slider:active:disabled {
        background-color: #171a26;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.fine-tune.horizontal {
    padding-top: 9px;
    padding-bottom: 9px;
    min-height: 16px; }
  scale.fine-tune.vertical {
    padding-left: 9px;
    padding-right: 9px;
    min-width: 16px; }
  scale.fine-tune slider {
    margin: -6px; }
  scale.fine-tune fill,
  scale.fine-tune highlight,
  scale.fine-tune trough {
    border-radius: 5px; }
  scale trough {
    outline-offset: 2px;
    outline-color: transparent; }
  scale fill:backdrop, scale fill {
    background-color: #090a0f; }
  scale fill:disabled:backdrop, scale fill:disabled {
    border-color: transparent;
    background-color: transparent; }
  .osd scale fill {
    background-color: rgba(97, 97, 97, 0.775); }
    .osd scale fill:disabled:backdrop, .osd scale fill:disabled {
      border-color: transparent;
      background-color: transparent; }
  scale slider {
    border-color: #181b28;
    border: 2px solid #00f17d;
    border-radius: 12px;
    background-color: #292f45; }
    scale slider:active {
      border-color: #980ba2; }
    scale slider:disabled {
      background-color: #0c0e15;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0px 0px 1px 1px rgba(0, 0, 0, 0.1); }
    scale slider:backdrop, scale slider:backdrop:disabled {
      transition: 200ms ease-out;
      background-color: #0c0e15;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0px 0px 1px 1px rgba(0, 0, 0, 0.1); }
    row:selected scale slider:disabled, row:selected scale slider {
      border-color: #980ba2; }
    .osd scale slider {
      color: #fefefe;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: rgba(16, 19, 27, 0.98);
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black;
      outline-color: rgba(254, 254, 254, 0.3);
      border-color: rgba(0, 0, 0, 0.7);
      background-color: #10131b; }
      .osd scale slider:hover {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(39, 44, 66, 0.98), rgba(39, 44, 66, 0.98));
        background-clip: padding-box;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: 0 1px black;
        -gtk-icon-shadow: 0 1px black;
        outline-color: rgba(254, 254, 254, 0.3);
        background-color: #10131b; }
      .osd scale slider:active {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(28, 31, 47, 0.98), rgba(28, 31, 47, 0.98));
        background-clip: padding-box;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: none;
        -gtk-icon-shadow: none;
        outline-color: rgba(254, 254, 254, 0.3);
        background-color: #10131b; }
      .osd scale slider:disabled {
        color: #87898d;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none;
        background-color: #10131b; }
      .osd scale slider:backdrop {
        color: #fefefe;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(16, 19, 27, 0.98), rgba(16, 19, 27, 0.98));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none;
        background-color: #10131b; }
        .osd scale slider:backdrop:disabled {
          background-color: #10131b; }
  scale value {
    color: alpha(currentColor,0.4); }
  scale marks {
    color: alpha(currentColor,0.4); }
    scale marks.top {
      margin-bottom: 6px;
      margin-top: -12px; }
    scale marks.bottom {
      margin-top: 6px;
      margin-bottom: -12px; }
    scale marks.top {
      margin-right: 6px;
      margin-left: -12px; }
    scale marks.bottom {
      margin-left: 6px;
      margin-right: -12px; }
  scale.fine-tune marks.top {
    margin-bottom: 6px;
    margin-top: -9px; }
  scale.fine-tune marks.bottom {
    margin-top: 6px;
    margin-bottom: -9px; }
  scale.fine-tune marks.top {
    margin-right: 6px;
    margin-left: -9px; }
  scale.fine-tune marks.bottom {
    margin-left: 6px;
    margin-right: -9px; }
  scale.horizontal indicator {
    min-height: 6px;
    min-width: 1px; }
  scale.horizontal.fine-tune indicator {
    min-height: 3px; }
  scale.vertical indicator {
    min-height: 1px;
    min-width: 6px; }
  scale.vertical.fine-tune indicator {
    min-width: 3px; }
  scale.horizontal.marks-before:not(.marks-after) slider {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-before:not(.marks-after) slider:hover {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-before:not(.marks-after) slider:active {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-before:not(.marks-after) slider:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-before:not(.marks-after) slider:backdrop {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-before:not(.marks-after) slider:backdrop:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-after:not(.marks-before) slider {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-after:not(.marks-before) slider:hover {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-after:not(.marks-before) slider:active {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-after:not(.marks-before) slider:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-after:not(.marks-before) slider:backdrop {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.horizontal.marks-after:not(.marks-before) slider:backdrop:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.horizontal.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-before:not(.marks-after) slider {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-before:not(.marks-after) slider:hover {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-before:not(.marks-after) slider:active {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-before:not(.marks-after) slider:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-before:not(.marks-after) slider:backdrop {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-before:not(.marks-after) slider:backdrop:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-before:not(.marks-after).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-after:not(.marks-before) slider {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-after:not(.marks-before) slider:hover {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-after:not(.marks-before) slider:active {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-after:not(.marks-before) slider:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-after:not(.marks-before) slider:backdrop {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.vertical.marks-after:not(.marks-before) slider:backdrop:disabled {
    min-height: 15px;
    min-width: 15px;
    margin: -7px;
    border: 2px solid #00f17d;
    border-radius: 50%;
    background-color: #292f45;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  scale.vertical.marks-after:not(.marks-before).fine-tune slider {
    margin: -7px; }
  scale.color {
    min-height: 0;
    min-width: 0; }
    scale.color trough {
      background-image: image(#090a0f);
      background-repeat: no-repeat; }
    scale.color.horizontal {
      padding: 0 0 15px 0; }
      scale.color.horizontal trough {
        padding-bottom: 4px;
        background-position: 0 -3px;
        border-top-left-radius: 0;
        border-top-right-radius: 0; }
      scale.color.horizontal slider:dir(ltr):hover, scale.color.horizontal slider:dir(ltr):backdrop, scale.color.horizontal slider:dir(ltr):disabled, scale.color.horizontal slider:dir(ltr):backdrop:disabled, scale.color.horizontal slider:dir(ltr), scale.color.horizontal slider:dir(rtl):hover, scale.color.horizontal slider:dir(rtl):backdrop, scale.color.horizontal slider:dir(rtl):disabled, scale.color.horizontal slider:dir(rtl):backdrop:disabled, scale.color.horizontal slider:dir(rtl) {
        margin-bottom: -15px;
        margin-top: 6px; }
    scale.color.vertical:dir(ltr) {
      padding: 0 0 0 15px; }
      scale.color.vertical:dir(ltr) trough {
        padding-left: 4px;
        background-position: 3px 0;
        border-bottom-right-radius: 0;
        border-top-right-radius: 0; }
      scale.color.vertical:dir(ltr) slider:hover, scale.color.vertical:dir(ltr) slider:backdrop, scale.color.vertical:dir(ltr) slider:disabled, scale.color.vertical:dir(ltr) slider:backdrop:disabled, scale.color.vertical:dir(ltr) slider {
        margin-left: -15px;
        margin-right: 6px; }
    scale.color.vertical:dir(rtl) {
      padding: 0 15px 0 0; }
      scale.color.vertical:dir(rtl) trough {
        padding-right: 4px;
        background-position: -3px 0;
        border-bottom-left-radius: 0;
        border-top-left-radius: 0; }
      scale.color.vertical:dir(rtl) slider:hover, scale.color.vertical:dir(rtl) slider:backdrop, scale.color.vertical:dir(rtl) slider:disabled, scale.color.vertical:dir(rtl) slider:backdrop:disabled, scale.color.vertical:dir(rtl) slider {
        margin-right: -15px;
        margin-left: 6px; }
    scale.color.fine-tune.horizontal:dir(ltr), scale.color.fine-tune.horizontal:dir(rtl) {
      padding: 0 0 12px 0; }
      scale.color.fine-tune.horizontal:dir(ltr) trough, scale.color.fine-tune.horizontal:dir(rtl) trough {
        padding-bottom: 7px;
        background-position: 0 -6px; }
      scale.color.fine-tune.horizontal:dir(ltr) slider, scale.color.fine-tune.horizontal:dir(rtl) slider {
        margin-bottom: -15px;
        margin-top: 6px; }
    scale.color.fine-tune.vertical:dir(ltr) {
      padding: 0 0 0 12px; }
      scale.color.fine-tune.vertical:dir(ltr) trough {
        padding-left: 7px;
        background-position: 6px 0; }
      scale.color.fine-tune.vertical:dir(ltr) slider {
        margin-left: -15px;
        margin-right: 6px; }
    scale.color.fine-tune.vertical:dir(rtl) {
      padding: 0 12px 0 0; }
      scale.color.fine-tune.vertical:dir(rtl) trough {
        padding-right: 7px;
        background-position: -6px 0; }
      scale.color.fine-tune.vertical:dir(rtl) slider {
        margin-right: -15px;
        margin-left: 6px; }

/**************
 * Scrollbars *
 **************/
scrollbar {
  background-color: #171a27;
  transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }
  scrollbar.top {
    border-bottom: 1px solid #090a0f; }
  scrollbar.bottom {
    border-top: 1px solid #090a0f; }
  scrollbar.left {
    border-right: 1px solid #090a0f; }
  scrollbar.right {
    border-left: 1px solid #090a0f; }
  scrollbar:backdrop {
    background-color: #10131b;
    border-color: #0a0c11;
    transition: 200ms ease-out; }
  scrollbar slider {
    min-width: 6px;
    min-height: 6px;
    margin: -1px;
    border: 4px solid transparent;
    border-radius: 8px;
    background-clip: padding-box;
    background-color: #7e818c; }
    scrollbar slider:hover {
      background-color: #a0a4af; }
    scrollbar slider:hover:active {
      background-color: #e323f0; }
    scrollbar slider:backdrop {
      background-color: #393c47; }
    scrollbar slider:disabled {
      background-color: transparent; }
  scrollbar.fine-tune slider {
    min-width: 4px;
    min-height: 4px; }
  scrollbar.fine-tune.horizontal slider {
    border-width: 5px 4px; }
  scrollbar.fine-tune.vertical slider {
    border-width: 4px 5px; }
  scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
    border-color: transparent;
    opacity: 0.4;
    background-color: transparent; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
      margin: 0;
      min-width: 3px;
      min-height: 3px;
      background-color: #C3C7D1;
      border: 1px solid black; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering) button {
      min-width: 5px;
      min-height: 5px;
      background-color: #C3C7D1;
      background-clip: padding-box;
      border-radius: 100%;
      border: 1px solid black;
      -gtk-icon-source: none; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
      margin: 0 2px;
      min-width: 40px; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button {
      margin: 1px 2px;
      min-width: 5px; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
      margin: 2px 0;
      min-height: 40px; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button {
      margin: 2px 1px;
      min-height: 5px; }
  scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
    opacity: 0.8; }
  scrollbar.horizontal slider {
    min-width: 40px; }
  scrollbar.vertical slider {
    min-height: 40px; }
  scrollbar button {
    padding: 0;
    min-width: 12px;
    min-height: 12px;
    border-style: none;
    border-radius: 0;
    transition-property: min-height, min-width, color;
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #7e818c; }
    scrollbar button:hover {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      text-shadow: none;
      -gtk-icon-shadow: none;
      color: #a0a4af; }
    scrollbar button:active, scrollbar button:checked {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      text-shadow: none;
      -gtk-icon-shadow: none;
      color: #e323f0; }
    scrollbar button:disabled {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      text-shadow: none;
      -gtk-icon-shadow: none;
      color: rgba(126, 129, 140, 0.2); }
    scrollbar button:backdrop {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      text-shadow: none;
      -gtk-icon-shadow: none;
      color: #393c47; }
      scrollbar button:backdrop:disabled {
        background-color: transparent;
        background-image: none;
        border-color: transparent;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0);
        text-shadow: none;
        -gtk-icon-shadow: none;
        color: rgba(57, 60, 71, 0.2); }
  scrollbar.vertical button.down {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  scrollbar.vertical button.up {
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
  scrollbar.horizontal button.down {
    -gtk-icon-source: -gtk-icontheme("pan-right-symbolic"); }
  scrollbar.horizontal button.up {
    -gtk-icon-source: -gtk-icontheme("pan-left-symbolic"); }

treeview ~ scrollbar.vertical {
  border-top: 1px solid #090a0f;
  margin-top: -1px; }

/***********
 * Sidebar *
 ***********/
.sidebar {
  border-style: none;
  border-width: 0;
  background-color: #171a27; }
  .sidebar .frame {
    border: none; }
  stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left, .sidebar.left:dir(rtl) {
    border-right: none;
    border-left-style: none; }
  stacksidebar.sidebar:dir(rtl) list
  .sidebar:dir(rtl), stacksidebar.sidebar.right list
  .sidebar:dir(rtl), .sidebar.right {
    border-left: 1px solid #090a0f;
    border-right-style: none; }
  .sidebar:backdrop {
    background-color: #181b28;
    border-color: #0a0c11; }
  .sidebar row {
    padding: 8px 12px;
    transition: all .12s ease-in; }
    .sidebar row label {
      color: #98abb2; }
    .sidebar row:selected {
      color: #fefefe; }
      .sidebar row:selected:backdrop {
        color: rgba(254, 254, 254, 0.5);
        background: rgba(197, 14, 210, 0.6); }
        .sidebar row:selected:backdrop label {
          color: #fefefe; }
      .sidebar row:selected label {
        color: #fefefe; }
  .sidebar.source-list {
    background: #161925;
    padding: 4px 0px; }
    .sidebar.source-list.view, iconview.sidebar.source-list {
      transition: all .12s ease-in; }
      .sidebar.source-list.view:selected, iconview.sidebar.source-list:selected {
        background-color: #c50ed2;
        color: #fefefe; }
        .sidebar.source-list.view:selected:active, iconview.sidebar.source-list:selected:active {
          box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }
        .sidebar.source-list.view:selected.has-open-popup, iconview.sidebar.source-list:selected.has-open-popup, .sidebar.source-list.view:selected:hover, iconview.sidebar.source-list:selected:hover {
          background-color: rgba(197, 14, 210, 0.9); }
        .sidebar.source-list.view:selected:backdrop, iconview.sidebar.source-list:selected:backdrop {
          background-color: rgba(197, 14, 210, 0.6); }
      .sidebar.source-list.view:hover, iconview.sidebar.source-list:hover, .sidebar.source-list.view iconview.source-list:hover, iconview.sidebar.source-list iconview.source-list:hover {
        background-color: rgba(0, 0, 0, 0.13); }
  paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
    border-style: none;
    border-color: #090a0f; }

stacksidebar row {
  padding: 10px 4px; }
  stacksidebar row > label {
    padding-left: 6px;
    padding-right: 6px; }
  stacksidebar row.needs-attention > label {
    background-size: 6px 6px, 0 0; }

/*******************************************************************/
/*                  PLACESSIDEBAR                                  */
/*******************************************************************/
/*--*/
placessidebar.sidebar {
  background-color: transparent;
  background-image: linear-gradient(to right, #171e27 40px, #161925 35px, #161925 36px, #161925 36px, #161925 99%, #161925 100%); }
  placessidebar.sidebar row.sidebar-row.sidebar-row .sidebar-icon {
    margin-left: -14px;
    margin-right: 12px;
    padding-left: 14px;
    padding-right: 12px;
    color: #9ecfa2; }
  placessidebar.sidebar row.sidebar-row:hover {
    transition: all 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
    color: rgba(0, 0, 0, 0.76);
    background-color: transparent;
    /*rgba(65,67,75,0.4); */
    background-image: linear-gradient(to right, rgba(65, 67, 75, 0) 40px, rgba(0, 0, 0, 0.12) 40px, rgba(0, 0, 0, 0.12) 97%); }
  placessidebar.sidebar row.sidebar-row:active:hover {
    color: rgba(0, 0, 0, 0.76);
    background-color: rgba(0, 0, 0, 0.23); }
  placessidebar.sidebar row.sidebar-row:selected {
    color: rgba(255, 255, 255, 0.938);
    background-color: transparent;
    background-image: linear-gradient(to right, #c50ed2 40px, rgba(65, 67, 75, 0) 36px, rgba(65, 67, 75, 0) 97%); }
    placessidebar.sidebar row.sidebar-row:selected:hover {
      color: #ffffff;
      background-color: rgba(0, 0, 0, 0.24); }
      placessidebar.sidebar row.sidebar-row:selected:hover .sidebar-icon {
        color: #ffffff; }
    placessidebar.sidebar row.sidebar-row:selected:backdrop {
      color: rgba(0, 0, 0, 0.54);
      background-color: transparent;
      background-image: linear-gradient(to right, #c50ed2 40px, rgba(65, 67, 75, 0) 36px, rgba(65, 67, 75, 0) 97%); }
      placessidebar.sidebar row.sidebar-row:selected:backdrop .sidebar-icon {
        color: rgba(254, 254, 254, 0.5);
        -gtk-icon-shadow: 0 1px rgba(254, 254, 254, 0.3); }
    placessidebar.sidebar row.sidebar-row:selected .sidebar-icon {
      -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.8);
      color: inherit; }
  placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row, placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row label, placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row .sidebar-icon {
    color: #f9dc5c; }
  placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) {
    box-shadow: inset 0 1px #71f79f, inset 0 -1px #71f79f; }
    placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled), placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) label, placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) image {
      color: #71f79f; }
    placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected {
      background: #71f79f; }
      placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected, placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected label, placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected image {
        color: #fefefe; }
placessidebar list {
  background-color: transparent; }
  placessidebar list:backdrop {
    background-color: transparent; }

/*****************
 * GtkSpinButton *
 *****************/
spinbutton:not(.vertical) {
  padding: 0; }
  spinbutton:not(.vertical) entry {
    min-width: 28px;
    margin: 0;
    background: none;
    background-color: transparent;
    border: none;
    border-radius: 0;
    box-shadow: none; }
  spinbutton:not(.vertical) button {
    min-height: 16px;
    margin: 0;
    padding-bottom: 0;
    padding-top: 0;
    color: #b2b6c0;
    background-image: none;
    border-style: none none none solid;
    border-color: rgba(9, 10, 15, 0.3);
    border-radius: 0;
    box-shadow: inset 1px 0px 0px 0px rgba(0, 0, 0, 0.07); }
    spinbutton:not(.vertical) button:dir(rtl) {
      border-style: none solid none none; }
    spinbutton:not(.vertical) button:hover {
      color: #C3C7D1;
      background-color: rgba(195, 199, 209, 0.05); }
    spinbutton:not(.vertical) button:disabled {
      color: rgba(109, 112, 123, 0.3); }
    spinbutton:not(.vertical) button:active {
      background-color: rgba(0, 0, 0, 0.1);
      box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.2); }
    spinbutton:not(.vertical) button:backdrop {
      color: #656873;
      background-color: transparent;
      border-color: rgba(10, 12, 17, 0.3);
      transition: 200ms ease-out; }
    spinbutton:not(.vertical) button:backdrop:disabled {
      color: rgba(51, 57, 85, 0.3);
      background-image: none;
      border-style: none none none solid;
      box-shadow: inset 1px 0px 0px 0px rgba(0, 0, 0, 0.07); }
      spinbutton:not(.vertical) button:backdrop:disabled:dir(rtl) {
        border-style: none solid none none; }
    spinbutton:not(.vertical) button:last-child {
      border-top-right-radius: 2px;
      border-bottom-right-radius: 2px; }
.osd spinbutton:not(.vertical) button {
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #fefefe;
  border-style: none none none solid;
  border-color: rgba(0, 0, 0, 0.4);
  border-radius: 0;
  box-shadow: none;
  -gtk-icon-shadow: 0 1px black; }
  .osd spinbutton:not(.vertical) button:dir(rtl) {
    border-style: none solid none none; }
  .osd spinbutton:not(.vertical) button:hover {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.5);
    background-color: rgba(254, 254, 254, 0.1);
    -gtk-icon-shadow: 0 1px black;
    box-shadow: none; }
  .osd spinbutton:not(.vertical) button:backdrop {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.5);
    -gtk-icon-shadow: none;
    box-shadow: none; }
  .osd spinbutton:not(.vertical) button:disabled {
    background-color: transparent;
    background-image: none;
    border-color: transparent;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #87898d;
    border-color: rgba(0, 0, 0, 0.5);
    -gtk-icon-shadow: none;
    box-shadow: none; }
  .osd spinbutton:not(.vertical) button:last-child {
    border-radius: 0 3px 3px 0; }
  .osd spinbutton:not(.vertical) button:dir(rtl):first-child {
    border-radius: 3px 0 0 3px; }
spinbutton.vertical:disabled {
  color: #6d707b; }
spinbutton.vertical:backdrop:disabled {
  color: #333955; }
spinbutton.vertical:drop(active) {
  border-color: transparent;
  box-shadow: none; }
spinbutton.vertical entry {
  min-height: 32px;
  min-width: 32px;
  padding: 0;
  border-radius: 0; }
spinbutton.vertical button {
  min-height: 32px;
  min-width: 32px;
  padding: 0;
  border-width: 1px;
  border-color: #090a0f;
  box-shadow: 0 1px rgba(255, 255, 255, 0.1); }
spinbutton.vertical button.up {
  border-radius: 3px 3px 0 0;
  border-style: solid solid none solid; }
spinbutton.vertical button.down {
  border-radius: 0 0 3px 3px;
  border-style: none solid solid solid; }
.osd spinbutton.vertical button:first-child {
  color: #fefefe;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(16, 19, 27, 0.98);
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(254, 254, 254, 0.3); }
  .osd spinbutton.vertical button:first-child:hover {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(39, 44, 66, 0.98), rgba(39, 44, 66, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    outline-color: rgba(254, 254, 254, 0.3); }
  .osd spinbutton.vertical button:first-child:active {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(28, 31, 47, 0.98), rgba(28, 31, 47, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: none;
    -gtk-icon-shadow: none;
    outline-color: rgba(254, 254, 254, 0.3); }
  .osd spinbutton.vertical button:first-child:disabled {
    color: #87898d;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
  .osd spinbutton.vertical button:first-child:backdrop {
    color: #fefefe;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(16, 19, 27, 0.98), rgba(16, 19, 27, 0.98));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0; }
  treeview spinbutton:not(.vertical) entry {
    min-height: 0;
    padding: 1px 2px; }

/***********
 * Spinner *
 ***********/
menu spinner {
  color: #c50ed2; }

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn); } }
spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
  spinner:checked {
    opacity: 1;
    animation: spin 1s linear infinite; }
    spinner:checked:disabled {
      opacity: 0.5; }

/**********
 * Switch *
 **********/
switch {
  font-size: 1px;
  font-weight: bold;
  outline-offset: -4px;
  transition: all 200ms ease-in;
  border: 1px solid #090a0f;
  border-radius: 14px;
  color: transparent;
  padding: 2.3px 0px;
  background: linear-gradient(to right, #1E2233, #1E2233); }
  switch:disabled {
    background-color: #171a26; }
  switch:backdrop {
    background-color: #161925;
    transition: 200ms ease-out; }
    switch:backdrop:disabled {
      background-color: #171a26; }
  switch:active, switch:checked {
    background: linear-gradient(to right, #f7005a, #fadd00); }
    switch:active slider, switch:checked slider {
      background: #fff; }
    switch:active:backdrop, switch:checked:backdrop {
      background: linear-gradient(to right, #de0051, #e1c600); }
      switch:active:backdrop slider:backdrop, switch:checked:backdrop slider:backdrop {
        box-shadow: none;
        background-color: rgba(24, 27, 40, 0.9);
        border: none; }
  switch slider {
    padding: 2px;
    margin: 0 2.3px;
    min-width: 12px;
    min-height: 12px;
    border-radius: 100%;
    transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
    background-color: #151723; }
    switch slider:backdrop {
      padding: 2px;
      box-shadow: none;
      background-color: #181b28; }
  switch trough:active, switch trough:checked {
    background-color: #c50ed2; }
    switch trough:active:backdrop, switch trough:checked:backdrop {
      background-color: rgba(197, 14, 210, 0.6); }

/************
 * Toolbars *
 ************/
toolbar, .inline-toolbar, searchbar > revealer > box {
  padding: 4px;
  background-color: #161925; }

toolbar {
  padding: 4px 3px 3px 4px; }
  .osd toolbar {
    background-color: transparent; }
  toolbar.osd {
    padding: 13px;
    border: none;
    border-radius: 5px;
    background-color: rgba(16, 19, 27, 0.98); }
    toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom {
      border-radius: 0; }
  toolbar.horizontal separator {
    margin: 0 7px 1px 6px; }
  toolbar.vertical separator {
    margin: 6px 1px 7px 0; }
  toolbar:not(.inline-toolbar):not(.osd) switch,
  toolbar:not(.inline-toolbar):not(.osd) scale,
  toolbar:not(.inline-toolbar):not(.osd) entry,
  toolbar:not(.inline-toolbar):not(.osd) spinbutton,
  toolbar:not(.inline-toolbar):not(.osd) button {
    margin-right: 1px;
    margin-bottom: 1px; }

.inline-toolbar {
  padding: 3px;
  border-width: 0 1px 1px;
  border-radius: 0  0 5px 5px; }

searchbar > revealer > box {
  border-width: 0 0 1px;
  padding: 5px; }

.inline-toolbar, searchbar > revealer > box {
  border-style: solid;
  border-color: #090a0f;
  background-color: #12151e; }
  .inline-toolbar:backdrop, searchbar > revealer > box:backdrop {
    border-color: #0a0c11;
    background-color: #12141e;
    box-shadow: none;
    transition: 200ms ease-out; }

searchbar {
  background: #181b28; }

/************
 * Tooltips *
 ************/
tooltip {
  padding: 4px;
  /* not working */
  border-radius: 4px;
  box-shadow: none;
  text-shadow: 0 1px black; }
  tooltip.background {
    background-color: #0c0e15;
    background-clip: padding-box;
    border: 1px solid rgba(255, 255, 255, 0.1); }
  tooltip decoration {
    background-color: transparent; }
  tooltip * {
    padding: 4px;
    background-color: transparent;
    color: white; }

/**************
 * Tree Views *
 **************/
treeview.view {
  border-left-color: #6e717d;
  border-top-color: #161925; }
  treeview.view:selected:focus, treeview.view:selected {
    border-radius: 0; }
  treeview.view:selected:backdrop, treeview.view:selected {
    border-left-color: #e286e8;
    border-top-color: rgba(195, 199, 209, 0.1); }
  treeview.view:disabled {
    color: #6d707b; }
    treeview.view:disabled:selected {
      color: #dc6ee4; }
      treeview.view:disabled:selected:backdrop {
        color: rgba(204, 44, 216, 0.85); }
    treeview.view:disabled:backdrop {
      color: #333955; }
  treeview.view.separator {
    min-height: 2px;
    color: #161925; }
    treeview.view.separator:backdrop {
      color: rgba(22, 25, 37, 0.1); }
  treeview.view:backdrop {
    border-left-color: #424550;
    border-top: #161925; }
  treeview.view:drop(active) {
    border-style: solid none;
    border-width: 1px;
    border-color: #980ba2; }
    treeview.view:drop(active).after {
      border-top-style: none; }
    treeview.view:drop(active).before {
      border-bottom-style: none; }
  treeview.view.expander {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    color: #90939e; }
    treeview.view.expander:dir(rtl) {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
    treeview.view.expander:hover {
      color: #C3C7D1; }
    treeview.view.expander:selected {
      color: #edb6f1; }
      treeview.view.expander:selected:hover {
        color: #fefefe; }
      treeview.view.expander:selected:backdrop {
        color: rgba(222, 119, 229, 0.65); }
    treeview.view.expander:checked {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    treeview.view.expander:backdrop {
      color: #545763; }
  treeview.view.progressbar {
    border: 1px solid #980ba2;
    border-radius: 4px;
    background-color: #c50ed2;
    background-image: linear-gradient(to bottom, #c50ed2, #980ba2);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), 0 1px rgba(0, 0, 0, 0.1); }
    treeview.view.progressbar:selected:focus, treeview.view.progressbar:selected {
      border-radius: 4px;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
      background-image: linear-gradient(to bottom, #181b28, #050608); }
      treeview.view.progressbar:selected:focus:backdrop, treeview.view.progressbar:selected:backdrop {
        border-color: #1a1d2b;
        background-color: #1a1d2b; }
    treeview.view.progressbar:backdrop {
      border-color: #1a1d2b;
      background-image: none;
      box-shadow: none; }
  treeview.view.trough {
    background-color: rgba(195, 199, 209, 0.1);
    border-radius: 4px; }
    treeview.view.trough:selected:focus, treeview.view.trough:selected {
      background-color: #980ba2;
      border-radius: 4px; }
  treeview.view header button {
    color: #6e717d;
    background-color: #181b28;
    font-weight: bold;
    text-shadow: none;
    box-shadow: none; }
    treeview.view header button:hover {
      color: #999ca7;
      box-shadow: none;
      transition: none; }
    treeview.view header button:active {
      color: #C3C7D1;
      transition: none; }
  treeview.view header button:last-child:backdrop, treeview.view header button:last-child {
    border-right-style: none; }
  treeview.view button.dnd:active, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd,
  treeview.view header.button.dnd:active,
  treeview.view header.button.dnd:selected,
  treeview.view header.button.dnd:hover,
  treeview.view header.button.dnd {
    padding: 0 6px;
    transition: none;
    background-image: none;
    background-color: #c50ed2;
    color: #181b28;
    border-radius: 0;
    border-style: none;
    box-shadow: inset 0 0 0 1px #181b28;
    text-shadow: none; }
  treeview.view acceleditor > label {
    background-color: #c50ed2; }

treeview.view header button, treeview.view header button:hover, treeview.view header button:active {
  padding: 0 6px;
  border-radius: 0;
  background-image: none;
  text-shadow: none;
  border-width: 1px;
  border-style: none solid solid none;
  border-color: #161925; }
  treeview.view header button:disabled {
    border-color: #161925;
    background-image: none; }
  treeview.view header button:backdrop {
    border-color: #161925;
    border-style: none solid solid none;
    color: #424550;
    background-image: none;
    background-color: #1a1d2b; }
    treeview.view header button:backdrop:disabled {
      border-color: #161925;
      background-image: none; }

/**********************
 * Window Decorations *
 *********************/
window {
  border-width: 0px; }
  window.csd {
    box-shadow: 0 4px 9px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(0, 0, 0, 0.75);
    margin: 0px;
    border-radius: 4px 4px 0 0; }
    window.csd:backdrop {
      box-shadow: 0 3px 9px 1px transparent, 0 2px 6px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.75);
      transition: 200ms ease-out; }
    window.csd.popup {
      border-radius: 7px;
      box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.65); }
    window.csd.dialog.message {
      border-radius: 4px;
      box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.65); }
  window.solid-csd {
    margin: 0;
    padding: 4px;
    border: solid 1px #090a0f;
    border-radius: 0;
    box-shadow: inset 0 0 0 4px #090a0f, inset 0 0 0 3px #0c0e14, inset 0 1px rgba(195, 199, 209, 0.07); }
    window.solid-csd:backdrop {
      box-shadow: inset 0 0 0 4px #090a0f, inset 0 0 0 3px #161925, inset 0 1px rgba(195, 199, 209, 0.07); }
  window.maximized, window.fullscreen {
    border-radius: 0;
    box-shadow: none; }
  window.tiled, window.tiled-top, window.tiled-left, window.tiled-right, window.tiled-bottom {
    border-radius: 0;
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75), 0 0 0 20px transparent; }
  window:backdrop {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75), 0 0 0 20px transparent; }
  window.popup {
    box-shadow: none; }
  window.ssd {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.75); }

windowcontrols button.close, windowcontrols button.maximize, windowcontrols button.minimize {
  min-width: 20px;
  min-height: 20px;
  margin: 0;
  padding: 0 1px;
  background-position: center;
  background-repeat: no-repeat;
  background-size: 16px 16px; }
  windowcontrols button.close, windowcontrols button.close:hover, windowcontrols button.close:focus, windowcontrols button.close:active, windowcontrols button.close:backdrop, windowcontrols button.close:backdrop:hover, windowcontrols button.maximize, windowcontrols button.maximize:hover, windowcontrols button.maximize:focus, windowcontrols button.maximize:active, windowcontrols button.maximize:backdrop, windowcontrols button.maximize:backdrop:hover, windowcontrols button.minimize, windowcontrols button.minimize:hover, windowcontrols button.minimize:focus, windowcontrols button.minimize:active, windowcontrols button.minimize:backdrop, windowcontrols button.minimize:backdrop:hover {
    background-color: transparent;
    border: none;
    box-shadow: none;
    color: transparent; }
windowcontrols button.close {
  background-image: -gtk-scaled(url("../assets/close.png"), url("../assets/close@2.png")); }
  windowcontrols button.close:hover, windowcontrols button.close:active {
    background-image: -gtk-scaled(url("../assets/close_prelight.png"), url("../assets/close_prelight@2.png")); }
windowcontrols button.maximize {
  background-image: -gtk-scaled(url("../assets/maximize.png"), url("../assets/maximize@2.png")); }
  windowcontrols button.maximize:hover, windowcontrols button.maximize:active {
    background-image: -gtk-scaled(url("../assets/maximize_prelight.png"), url("../assets/maximize_prelight@2.png")); }
windowcontrols button.minimize {
  background-image: -gtk-scaled(url("../assets/min.png"), url("../assets/min@2.png")); }
  windowcontrols button.minimize:hover, windowcontrols button.minimize:active {
    background-image: -gtk-scaled(url("../assets/min_prelight.png"), url("../assets/min_prelight@2.png")); }
windowcontrols button:backdrop {
  -gtk-icon-shadow: none;
  background-image: -gtk-scaled(url("../assets/close_unfocused.png"), url("../assets/close_unfocused@2.png")); }

headerbar.selection-mode button.titlebutton,
.titlebar.selection-mode button.titlebutton {
  text-shadow: 0 -1px rgba(0, 0, 0, 0.648627451);
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.648627451); }
  headerbar.selection-mode button.titlebutton:backdrop,
  .titlebar.selection-mode button.titlebutton:backdrop {
    -gtk-icon-shadow: none; }

.view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected,
.view text:selected:focus,
iconview text:selected:focus,
textview text:selected:focus,
.view text:selected,
iconview text:selected,
textview text:selected, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, modelbutton.flat:selected,
.menuitem.button.flat:selected, calendar:selected, spinbutton:not(.vertical) selection:focus, spinbutton:not(.vertical) selection,
entry selection:focus,
entry selection, row:selected, treeview.view:selected:focus, treeview.view:selected {
  background-color: #c50ed2; }
  row:selected label, label:selected, .selection-mode windowcontrols button, .view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected,
  .view text:selected:focus,
  iconview text:selected:focus,
  textview text:selected:focus,
  .view text:selected,
  iconview text:selected,
  textview text:selected, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection,
  textview text selection:focus,
  textview text selection, flowbox flowboxchild:selected, modelbutton.flat:selected,
  .menuitem.button.flat:selected, calendar:selected, spinbutton:not(.vertical) selection:focus, spinbutton:not(.vertical) selection,
  entry selection:focus,
  entry selection, row:selected, treeview.view:selected:focus, treeview.view:selected {
    color: #fefefe;
    font-weight: normal; }
    row:selected label:disabled, label:disabled:selected, .selection-mode windowcontrols button:disabled, iconview:disabled:selected:focus, .view:disabled:selected, iconview:disabled:selected,
    iconview text:disabled:selected:focus,
    textview text:disabled:selected:focus,
    .view text:disabled:selected,
    iconview text:disabled:selected,
    textview text:disabled:selected, iconview text selection:disabled:focus, .view text selection:disabled, iconview text selection:disabled,
    textview text selection:disabled, flowbox flowboxchild:disabled:selected, label:disabled selection, modelbutton.flat:disabled:selected,
    .menuitem.button.flat:disabled:selected, calendar:disabled:selected, spinbutton:not(.vertical) selection:disabled,
    entry selection:disabled, row:disabled:selected {
      color: #e286e8; }
    row:selected label:backdrop, label:backdrop:selected, .selection-mode windowcontrols button:backdrop, iconview:backdrop:selected:focus, .view:backdrop:selected, iconview:backdrop:selected,
    iconview text:backdrop:selected:focus,
    textview text:backdrop:selected:focus,
    .view text:backdrop:selected,
    iconview text:backdrop:selected,
    textview text:backdrop:selected, iconview text selection:backdrop:focus, .view text selection:backdrop, iconview text selection:backdrop,
    textview text selection:backdrop, flowbox flowboxchild:backdrop:selected, label:backdrop selection, modelbutton.flat:backdrop:selected,
    .menuitem.button.flat:backdrop:selected, calendar:backdrop:selected, spinbutton:not(.vertical) selection:backdrop,
    entry selection:backdrop, row:backdrop:selected {
      color: rgba(254, 254, 254, 0.5); }
      row:selected label:backdrop:disabled, label:backdrop:disabled:selected, .selection-mode windowcontrols button:backdrop:disabled, .view:backdrop:disabled:selected, iconview:backdrop:disabled:selected,
      .view text:backdrop:disabled:selected,
      iconview text:backdrop:disabled:selected,
      textview text:backdrop:disabled:selected, .view text selection:backdrop:disabled, iconview text selection:backdrop:disabled,
      textview text selection:backdrop:disabled, flowbox flowboxchild:backdrop:disabled:selected, label:disabled selection:backdrop, label:backdrop selection:disabled, modelbutton.flat:backdrop:disabled:selected,
      .menuitem.button.flat:backdrop:disabled:selected, calendar:backdrop:disabled:selected, spinbutton:not(.vertical) selection:backdrop:disabled,
      entry selection:backdrop:disabled, row:backdrop:disabled:selected {
        color: rgba(204, 44, 216, 0.85); }

.monospace {
  font-family: Monospace; }

/**********************
 * DE-Specific Styles *
 **********************/
/*********
* Budgie *
*********/
.budgie-container {
  background-color: transparent; }
  .budgie-container:backdrop {
    background-color: transparent; }
  .budgie-container popover list,
  .budgie-container popover row {
    border: none;
    background: none;
    padding: 0;
    margin: 0; }

.budgie-popover .container,
.budgie-popover border,
.budgie-popover list,
.budgie-popover row {
  padding: 0;
  margin: 0;
  background: none;
  border: none;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none;
  opacity: 1;
  min-width: 0;
  min-height: 0; }

.budgie-popover,
.budgie-popover.background {
  border-radius: 2px;
  padding: 0;
  background: #07080c;
  background-clip: border-box;
  box-shadow: 0 2px 3px 1px rgba(0, 0, 0, 0.35);
  border: 1px solid black; }
  .budgie-popover list:hover,
  .budgie-popover row:hover,
  .budgie-popover.background list:hover,
  .budgie-popover.background row:hover {
    background: none; }
  .budgie-popover > frame.container,
  .budgie-popover.background > frame.container {
    margin: 0 -1px -1px;
    padding: 2px 0 0; }
  .budgie-popover button,
  .budgie-popover.background button {
    color: #C3C7D1;
    border: none;
    background: transparent; }
    .budgie-popover button:hover,
    .budgie-popover.background button:hover {
      color: #c50ed2; }

.budgie-popover > .container {
  padding: 2px; }

.budgie-menu {
  color: #C3C7D1; }
  .budgie-menu .container {
    padding: 0; }
  .budgie-menu button:hover {
    -gtk-icon-filter: none; }
  .budgie-menu entry.search {
    border: none;
    background: none;
    padding: 5px 2px;
    border-bottom: 1px solid black;
    border-radius: 0;
    font-size: 120%;
    box-shadow: none;
    color: #C3C7D1; }
    .budgie-menu entry.search image:dir(ltr) {
      padding-left: 8px;
      padding-right: 12px; }
    .budgie-menu entry.search image:dir(rtl) {
      padding-left: 12px;
      padding-right: 8px; }
  .budgie-menu .categories {
    border-width: 0;
    margin-left: 3px;
    background: transparent; }
    .budgie-menu .categories:dir(ltr) {
      border-right: 1px solid black; }
    .budgie-menu .categories:dir(rtl) {
      border-left: 1px solid black; }
  .budgie-menu .category-button {
    padding: 7px;
    border-radius: 2px 0 0 2px; }
    .budgie-menu .category-button:hover {
      background-color: rgba(195, 199, 209, 0.05);
      color: #C3C7D1; }
    .budgie-menu .category-button:active {
      box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }
    .budgie-menu .category-button:checked {
      color: #fefefe;
      background: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
      .budgie-menu .category-button:checked:hover {
        color: rgba(254, 254, 254, 0.9); }
    .budgie-menu .category-button:checked:disabled {
      opacity: 0.5; }
      .budgie-menu .category-button:checked:disabled label {
        color: rgba(254, 254, 254, 0.7); }
  .budgie-menu scrollbar {
    background-color: transparent;
    border-color: black; }
  .budgie-menu button:not(.category-button) {
    padding-top: 5px;
    padding-bottom: 5px;
    border-radius: 0;
    box-shadow: none;
    background: yellow; }
  .budgie-menu button {
    border: none;
    background: transparent; }
  .budgie-menu undershoot, .budgie-menu overshoot {
    background: none; }
  .budgie-menu list {
    color: rgba(195, 199, 209, 0.7); }

button.budgie-menu-launcher {
  padding: 0 2px;
  color: white;
  box-shadow: none;
  background-color: transparent; }
  button.budgie-menu-launcher:hover {
    color: white; }
  button.budgie-menu-launcher:active, button.budgie-menu-launcher:checked {
    color: white; }
  button.budgie-menu-launcher:backdrop {
    color: white;
    background-color: transparent; }
    button.budgie-menu-launcher:backdrop:hover {
      color: white; }
    button.budgie-menu-launcher:backdrop:active, button.budgie-menu-launcher:backdrop:checked {
      color: #c50ed2;
      box-shadow: none;
      background-color: #181b27; }

.user-menu .content-box separator {
  margin-left: 6px;
  margin-right: 6px;
  background-color: rgba(195, 199, 209, 0.1); }
.user-menu button {
  margin: 5px; }
.user-menu > box.vertical row.activatable:first-child .indicator-item,
.user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.06), 0 1px 2px rgba(0, 0, 0, 0.2), inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1);
  background-color: #c50ed2;
  transition-duration: 0.2s; }
  .user-menu > box.vertical row.activatable:first-child .indicator-item:dir(ltr),
  .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item:dir(ltr) {
    padding-left: 7px;
    background-position: left center;
    background-repeat: no-repeat;
    background-size: 38px auto; }
  .user-menu > box.vertical row.activatable:first-child .indicator-item:dir(rtl),
  .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item:dir(rtl) {
    padding-right: 7px;
    background-position: right center;
    background-repeat: no-repeat;
    background-size: 38px auto; }
  .user-menu > box.vertical row.activatable:first-child .indicator-item label,
  .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item label {
    color: #fefefe; }
    .user-menu > box.vertical row.activatable:first-child .indicator-item label:dir(ltr),
    .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item label:dir(ltr) {
      padding-left: 5px; }
    .user-menu > box.vertical row.activatable:first-child .indicator-item label:dir(rtl),
    .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item label:dir(rtl) {
      padding-right: 5px; }
  .user-menu > box.vertical row.activatable:first-child .indicator-item image,
  .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item image {
    color: #fefefe; }
    .user-menu > box.vertical row.activatable:first-child .indicator-item image:first-child,
    .user-menu > frame.container > box.vertical row.activatable:first-child .indicator-item image:first-child {
      min-width: 24px;
      min-height: 20px; }

button.raven-trigger {
  padding-left: 2px;
  padding-right: 2px;
  color: white;
  box-shadow: none; }
  button.raven-trigger:hover {
    color: white;
    background-color: transparent; }
  button.raven-trigger:active, button.raven-trigger:checked {
    box-shadow: none;
    background-color: transparent;
    color: #c50ed2; }
  button.raven-trigger:backdrop {
    color: white; }
    button.raven-trigger:backdrop:hover {
      color: white; }
    button.raven-trigger:backdrop:active, button.raven-trigger:backdrop:checked {
      box-shadow: none;
      color: #c50ed2;
      background-color: transparent; }

.places-menu .container {
  padding: 0; }
.places-menu .message-bar {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px; }
.places-menu .name-button {
  border: 0;
  border-radius: 0;
  padding: 4px 6px; }
.places-menu .unmount-button {
  padding: 4px 4px;
  border: 0;
  border-radius: 0; }
.places-menu .places-section-header {
  padding: 0px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.95);
  box-shadow: 0px 1px 1px alpha(@theme_fg_color, 0.03); }
.places-menu .places-section-header > button {
  padding: 8px;
  border: none;
  border-bottom-left-radius: 0px;
  border-bottom-right-radius: 0px; }
.places-menu .places-list {
  background: rgba(195, 199, 209, 0.04);
  border-bottom: 1px solid rgba(0, 0, 0, 0.95); }
.places-menu .unlock-area {
  border-top: 1px solid rgba(0, 0, 0, 0.85);
  border-bottom: 1px solid rgba(0, 0, 0, 0.85); }
.places-menu .unlock-area entry {
  border-radius: 0;
  border: 0; }
.places-menu .unlock-area button {
  border-radius: 0;
  border: 0;
  border-left: 1px solid rgba(0, 0, 0, 0.85); }
.places-menu .alternative-label {
  font-size: 15px;
  padding: 3px; }
.places-menu .always-expand {
  background: transparent;
  border-bottom: none; }

.night-light-indicator .container {
  padding: 0; }
.night-light-indicator .view-header {
  font-size: 14px;
  padding: 10px;
  border-bottom: 1px solid mix(@theme_base_color, #000000, 0.35);
  box-shadow: 0px 1px 1px alpha(@theme_fg_color, 0.04); }
.night-light-indicator .display-settings-button {
  border-top-left-radius: 0px;
  border-top-right-radius: 0px;
  border: none;
  padding: 3px;
  border-top: 1px solid mix(@theme_base_color, #000000, 0.35);
  box-shadow: inset 0px 1px 1px alpha(@theme_fg_color, 0.04); }

.budgie-panel {
  color: white;
  background-color: rgba(0, 0, 0, 0.95);
  background-image: none;
  box-shadow: none;
  border: none;
  transition: all 150ms ease-in; }
  .budgie-panel .alert {
    color: #ed254e; }
  .budgie-panel:backdrop {
    color: white;
    background-color: rgba(0, 0, 0, 0.95); }
  .budgie-panel button {
    border-top-width: 0;
    border-bottom-width: 0;
    border-radius: 0; }
    .budgie-panel button.flat {
      background: transparent;
      border: none; }
      .budgie-panel button.flat:hover, .budgie-panel button.flat:active, .budgie-panel button.flat:checked {
        background: transparent;
        color: #c50ed2; }
  .budgie-panel popover list,
  .budgie-panel popover row {
    padding: 0;
    margin: 0; }
  .budgie-panel label {
    color: white;
    font-weight: 700; }
  .budgie-panel.transparent {
    background-color: rgba(0, 0, 0, 0.2); }
    .top .budgie-panel.transparent {
      border-bottom-color: transparent; }
    .bottom .budgie-panel.transparent {
      border-top-color: transparent; }
    .left .budgie-panel.transparent {
      border-right-color: transparent; }
    .right .budgie-panel.transparent {
      border-left-color: transparent; }
  .budgie-panel .end-region {
    border-radius: 0px; }
    .budgie-panel .end-region separator {
      background-color: rgba(195, 199, 209, 0.15); }
    .budgie-panel .end-region label {
      font-weight: 700;
      color: #C3C7D1; }

.budgie-panel #tasklist-button,
.budgie-panel #tasklist-button:backdrop {
  outline-color: transparent;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-color: rgba(0, 0, 0, 0);
  border-radius: 0;
  background-color: transparent;
  box-shadow: none;
  background-clip: padding-box; }

.budgie-panel button.flat.launcher {
  outline-color: transparent;
  transition: all 100ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  border-color: rgba(0, 0, 0, 0);
  border-radius: 0;
  padding: 0;
  background-clip: padding-box;
  background-color: transparent; }
  .budgie-panel button.flat.launcher {
    box-shadow: none; }

.budgie-panel #tasklist-button:hover, .budgie-panel .unpinned button.flat.launcher:hover,
.budgie-panel .pinned button.flat.launcher.running:hover {
  box-shadow: none; }
.budgie-panel #tasklist-button:active, .budgie-panel .unpinned button.flat.launcher:active,
.budgie-panel .pinned button.flat.launcher.running:active, .budgie-panel #tasklist-button:checked, .budgie-panel .unpinned button.flat.launcher:checked,
.budgie-panel .pinned button.flat.launcher.running:checked {
  box-shadow: none; }
.top .budgie-panel #tasklist-button, .budgie-panel .top #tasklist-button, .top .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .top button.flat.launcher,
.top .budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .top button.flat.launcher.running {
  padding-bottom: 2px;
  border-top: 2px solid transparent; }
  .top .budgie-panel .pinned button.flat.launcher:not(.running) {
    border-top: 2px solid transparent; }

  .top .budgie-panel .pinned button.flat.launcher:not(.running):hover {
    border-top: 2px solid rgba(255, 255, 255, 0.1); }

  .top .budgie-panel .unpinned button.flat.launcher,
  .top .budgie-panel .pinned button.flat.launcher.running {
    border-top: 2px solid rgba(255, 255, 255, 0.1); }
  .top .budgie-panel #tasklist-button:hover, .budgie-panel .top #tasklist-button:hover, .top .budgie-panel .unpinned button.flat.launcher:hover, .budgie-panel .unpinned .top button.flat.launcher:hover,
  .top .budgie-panel .pinned button.flat.launcher.running:hover,
  .budgie-panel .pinned .top button.flat.launcher.running:hover {
    border-top: 2px solid rgba(255, 255, 255, 0.25); }
  .top .budgie-panel #tasklist-button:active, .budgie-panel .top #tasklist-button:active, .top .budgie-panel .unpinned button.flat.launcher:active, .budgie-panel .unpinned .top button.flat.launcher:active,
  .top .budgie-panel .pinned button.flat.launcher.running:active,
  .budgie-panel .pinned .top button.flat.launcher.running:active, .top .budgie-panel #tasklist-button:checked, .budgie-panel .top #tasklist-button:checked, .top .budgie-panel .unpinned button.flat.launcher:checked, .budgie-panel .unpinned .top button.flat.launcher:checked,
  .top .budgie-panel .pinned button.flat.launcher.running:checked,
  .budgie-panel .pinned .top button.flat.launcher.running:checked {
    border-top: 2px solid #c50ed2; }
.bottom .budgie-panel #tasklist-button, .budgie-panel .bottom #tasklist-button, .bottom .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .bottom button.flat.launcher,
.bottom .budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .bottom button.flat.launcher.running {
  padding-top: 2px;
  border-bottom: 2px solid transparent; }
  .bottom .budgie-panel .pinned button.flat.launcher:not(.running) {
    border-bottom: 2px solid transparent; }

  .bottom .budgie-panel .pinned button.flat.launcher:not(.running):hover {
    border-bottom: 2px solid rgba(255, 255, 255, 0.1); }

  .bottom .budgie-panel .unpinned button.flat.launcher,
  .bottom .budgie-panel .pinned button.flat.launcher.running {
    border-bottom: 2px solid rgba(255, 255, 255, 0.1); }
  .bottom .budgie-panel #tasklist-button:hover, .budgie-panel .bottom #tasklist-button:hover, .bottom .budgie-panel .unpinned button.flat.launcher:hover, .budgie-panel .unpinned .bottom button.flat.launcher:hover,
  .bottom .budgie-panel .pinned button.flat.launcher.running:hover,
  .budgie-panel .pinned .bottom button.flat.launcher.running:hover {
    border-bottom: 2px solid rgba(255, 255, 255, 0.25); }
  .bottom .budgie-panel #tasklist-button:active, .budgie-panel .bottom #tasklist-button:active, .bottom .budgie-panel .unpinned button.flat.launcher:active, .budgie-panel .unpinned .bottom button.flat.launcher:active,
  .bottom .budgie-panel .pinned button.flat.launcher.running:active,
  .budgie-panel .pinned .bottom button.flat.launcher.running:active, .bottom .budgie-panel #tasklist-button:checked, .budgie-panel .bottom #tasklist-button:checked, .bottom .budgie-panel .unpinned button.flat.launcher:checked, .budgie-panel .unpinned .bottom button.flat.launcher:checked,
  .bottom .budgie-panel .pinned button.flat.launcher.running:checked,
  .budgie-panel .pinned .bottom button.flat.launcher.running:checked {
    border-bottom: 2px solid #c50ed2; }
.left .budgie-panel #tasklist-button, .budgie-panel .left #tasklist-button, .left .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .left button.flat.launcher,
.left .budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .left button.flat.launcher.running {
  padding-right: 2px;
  border-left: 2px solid transparent; }
  .left .budgie-panel .pinned button.flat.launcher:not(.running) {
    border-left: 2px solid transparent; }

  .left .budgie-panel .pinned button.flat.launcher:not(.running):hover {
    border-left: 2px solid rgba(255, 255, 255, 0.1); }

  .left .budgie-panel .unpinned button.flat.launcher,
  .left .budgie-panel .pinned button.flat.launcher.running {
    border-left: 2px solid rgba(255, 255, 255, 0.1); }
  .left .budgie-panel #tasklist-button:hover, .budgie-panel .left #tasklist-button:hover, .left .budgie-panel .unpinned button.flat.launcher:hover, .budgie-panel .unpinned .left button.flat.launcher:hover,
  .left .budgie-panel .pinned button.flat.launcher.running:hover,
  .budgie-panel .pinned .left button.flat.launcher.running:hover {
    border-left: 2px solid rgba(255, 255, 255, 0.25); }
  .left .budgie-panel #tasklist-button:active, .budgie-panel .left #tasklist-button:active, .left .budgie-panel .unpinned button.flat.launcher:active, .budgie-panel .unpinned .left button.flat.launcher:active,
  .left .budgie-panel .pinned button.flat.launcher.running:active,
  .budgie-panel .pinned .left button.flat.launcher.running:active, .left .budgie-panel #tasklist-button:checked, .budgie-panel .left #tasklist-button:checked, .left .budgie-panel .unpinned button.flat.launcher:checked, .budgie-panel .unpinned .left button.flat.launcher:checked,
  .left .budgie-panel .pinned button.flat.launcher.running:checked,
  .budgie-panel .pinned .left button.flat.launcher.running:checked {
    border-left: 2px solid #c50ed2; }
.right .budgie-panel #tasklist-button, .budgie-panel .right #tasklist-button, .right .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .right button.flat.launcher,
.right .budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .right button.flat.launcher.running {
  padding-left: 2px;
  border-right: 2px solid transparent; }
  .right .budgie-panel .pinned button.flat.launcher:not(.running) {
    border-right: 2px solid transparent; }

  .right .budgie-panel .pinned button.flat.launcher:not(.running):hover {
    border-right: 2px solid rgba(255, 255, 255, 0.1); }

  .right .budgie-panel .unpinned button.flat.launcher,
  .right .budgie-panel .pinned button.flat.launcher.running {
    border-right: 2px solid rgba(255, 255, 255, 0.1); }
  .right .budgie-panel #tasklist-button:hover, .budgie-panel .right #tasklist-button:hover, .right .budgie-panel .unpinned button.flat.launcher:hover, .budgie-panel .unpinned .right button.flat.launcher:hover,
  .right .budgie-panel .pinned button.flat.launcher.running:hover,
  .budgie-panel .pinned .right button.flat.launcher.running:hover {
    border-right: 2px solid rgba(255, 255, 255, 0.25); }
  .right .budgie-panel #tasklist-button:active, .budgie-panel .right #tasklist-button:active, .right .budgie-panel .unpinned button.flat.launcher:active, .budgie-panel .unpinned .right button.flat.launcher:active,
  .right .budgie-panel .pinned button.flat.launcher.running:active,
  .budgie-panel .pinned .right button.flat.launcher.running:active, .right .budgie-panel #tasklist-button:checked, .budgie-panel .right #tasklist-button:checked, .right .budgie-panel .unpinned button.flat.launcher:checked, .budgie-panel .unpinned .right button.flat.launcher:checked,
  .right .budgie-panel .pinned button.flat.launcher.running:checked,
  .budgie-panel .pinned .right button.flat.launcher.running:checked {
    border-right: 2px solid #c50ed2; }

.top .budgie-panel {
  border-bottom: 1px solid rgba(0, 0, 0, 0.92); }

.top .raven-frame {
  padding: 0;
  background: none; }
  .top .raven-frame border {
    border: none;
    border-bottom: 1px solid rgba(0, 0, 0, 0.92); }

.top .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.3), transparent); }

.bottom .budgie-panel {
  border-top: 1px solid rgba(0, 0, 0, 0.92); }

.bottom .raven-frame {
  padding: 0;
  background: none; }
  .bottom .raven-frame border {
    border: none;
    border-top: 1px solid rgba(0, 0, 0, 0.92); }

.bottom .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.3), transparent); }

.left .budgie-panel {
  border-right: 1px solid rgba(0, 0, 0, 0.92); }

.left .raven-frame {
  padding: 0;
  background: none; }
  .left .raven-frame border {
    border: none;
    border-right: 1px solid rgba(0, 0, 0, 0.92); }

.left .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.3), transparent); }

.right .budgie-panel {
  border-left: 1px solid rgba(0, 0, 0, 0.92); }

.right .raven-frame {
  padding: 0;
  background: none; }
  .right .raven-frame border {
    border: none;
    border-left: 1px solid rgba(0, 0, 0, 0.92); }

.right .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.3), transparent); }

.raven {
  padding: 0;
  color: #C3C7D1;
  background: #07080c;
  transition: 170ms ease-out; }
  .raven .raven-header {
    min-height: 32px;
    color: #C3C7D1;
    border: solid rgba(0, 0, 0, 0.95);
    border-width: 1px 0;
    background-color: rgba(6, 7, 10, 0.45); }
    .raven .raven-header * {
      padding-top: 0;
      padding-bottom: 0; }
    .raven .raven-header.top {
      border-top-style: none;
      border-color: transparent;
      margin-top: 3px;
      min-height: 32px; }
      .raven .raven-header.top button.image-button:hover {
        color: #af0cba;
        box-shadow: none; }
    .raven .raven-header > button.text-button {
      border-radius: 2px;
      color: #fefefe;
      background-color: rgba(230, 19, 62, 0.9);
      box-shadow: inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1), inset 0px -1px 0px 0px rgba(0, 0, 0, 0.1); }
      .raven .raven-header > button.text-button:hover {
        border-radius: 2px;
        color: #fefefe;
        background-color: rgba(237, 37, 78, 0.9);
        box-shadow: inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1), inset 0px -1px 0px 0px rgba(0, 0, 0, 0.1); }
      .raven .raven-header > button.text-button:active {
        color: #fefefe;
        background-color: rgba(239, 61, 97, 0.9);
        box-shadow: inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1), inset 0px -1px 0px 0px rgba(0, 0, 0, 0.1); }
    .raven .raven-header.bottom {
      border-bottom-style: none; }
    .raven .raven-header button {
      color: #8b8b8b;
      text-shadow: none;
      box-shadow: none;
      background: transparent;
      border: none;
      border-radius: 0; }
      .raven .raven-header button:hover {
        color: #c50ed2;
        border-radius: 0;
        text-shadow: none;
        border: none;
        border-radius: 0; }
      .raven .raven-header button:disabled {
        color: #6d707b; }
      .raven .raven-header button.text-button.radio {
        margin: 5px 0px;
        min-height: 20px;
        padding: 3px; }
        .raven .raven-header button.text-button.radio:active, .raven .raven-header button.text-button.radio:checked {
          border-radius: 23px;
          background: linear-gradient(to right, #c50ed2, #8500f7);
          box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
          color: white; }
  .raven list {
    color: #C3C7D1;
    background-color: transparent; }
    .raven list:selected {
      background-color: rgba(197, 14, 210, 0.9); }
    .raven list row,
    .raven list row.activatable {
      background-color: transparent; }
      .raven list row:hover,
      .raven list row.activatable:hover {
        background-color: rgba(29, 33, 48, 0.25); }
      .raven list row:selected,
      .raven list row.activatable:selected {
        background-color: rgba(197, 14, 210, 0.9); }
  .raven .raven-background {
    color: #C3C7D1;
    background-color: transparent;
    border-color: transparent; }
    .raven .raven-background.middle {
      border-bottom-style: none; }
  .raven .powerstrip {
    background-color: transparent;
    border-top-color: transparent; }
  .raven .powerstrip button.image-button {
    border-radius: 50%;
    padding: 5px;
    min-width: 32px;
    min-height: 32px;
    margin-bottom: 3px;
    background: #c74ded;
    color: #fefefe;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.06), 0 1px 2px rgba(0, 0, 0, 0.2), inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1);
    border: none;
    font-size: 100%; }
    .raven .powerstrip button.image-button:hover {
      background: rgba(199, 77, 237, 0.85);
      color: #fefefe; }
    .raven .powerstrip button.image-button:active {
      background: #c74ded;
      color: #fefefe; }
    .raven .powerstrip button.image-button:first-child {
      background: linear-gradient(to right, #654ea3 0%, #eaafc8 100%); }
      .raven .powerstrip button.image-button:first-child:hover {
        background: rgba(197, 14, 210, 0.85); }
      .raven .powerstrip button.image-button:first-child:active {
        background: #c50ed2; }
    .raven .powerstrip button.image-button:last-child {
      background: linear-gradient(to right, #FF416C, #FF4B2B); }
      .raven .powerstrip button.image-button:last-child:hover {
        background: rgba(237, 37, 78, 0.85); }
      .raven .powerstrip button.image-button:last-child:active {
        background: #ed254e; }
  .raven .option-subtitle {
    font-size: 13px; }

calendar.raven-calendar {
  padding: 6px;
  color: #C3C7D1;
  background: transparent;
  border-color: transparent; }
  calendar.raven-calendar:indeterminate {
    color: alpha(currentColor,0.3); }
  calendar.raven-calendar:selected {
    background: transparent;
    color: #b30dbf;
    font-weight: bold; }
  calendar.raven-calendar:backdrop {
    background-color: transparent; }
  calendar.raven-calendar.header {
    color: #C3C7D1;
    border: none;
    border-radius: 0;
    background-color: transparent; }
  calendar.raven-calendar button, calendar.raven-calendar button:focus {
    color: alpha(currentColor,0.5);
    background-color: transparent; }
    calendar.raven-calendar button:hover, calendar.raven-calendar button:focus:hover {
      color: #C3C7D1;
      background-color: transparent; }

.raven-mpris {
  color: #C3C7D1;
  background-color: rgba(3, 3, 5, 0.9);
  border: solid rgba(255, 255, 255, 0.1);
  border-width: 1px 0;
  border-bottom-color: rgba(0, 0, 0, 0.1); }
  .raven-mpris button.image-button {
    padding: 10px;
    background-color: #181b28;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.06), 0 1px 2px rgba(0, 0, 0, 0.2), inset 0px 1px 0px 0px rgba(255, 255, 255, 0.1); }
    .raven-mpris button.image-button:hover {
      background-color: #c50ed2; }
    .raven-mpris button.image-button:active {
      background-color: #af0cba; }
    .raven-mpris button.image-button:first-child {
      margin-right: 4px; }
    .raven-mpris button.image-button:last-child {
      margin-left: 4px; }
    .raven-mpris button.image-button:last-child, .raven-mpris button.image-button:first-child {
      padding: 4px;
      margin-top: 6px;
      margin-bottom: 6px; }

.budgie-notification-window, .budgie-osd-window, .budgie-switcher-window {
  background: none;
  border-radius: 1px; }
  .budgie-notification-window button, .budgie-osd-window button, .budgie-switcher-window button {
    background-color: #c50ed2;
    color: #fefefe;
    border: none; }
    .budgie-notification-window button:hover, .budgie-osd-window button:hover, .budgie-switcher-window button:hover {
      background-color: #af0cba;
      border: none; }
    .budgie-notification-window button:active, .budgie-osd-window button:active, .budgie-switcher-window button:active, .budgie-notification-window button:checked, .budgie-osd-window button:checked, .budgie-switcher-window button:checked {
      background-color: #af0cba; }

.budgie-notification.background, .background.budgie-osd, .background.budgie-switcher {
  border-radius: 1px; }
.budgie-notification .notification-title, .budgie-osd .notification-title, .budgie-switcher .notification-title {
  font-size: 110%;
  color: #C3C7D1; }
.budgie-notification .notification-body, .budgie-osd .notification-body, .budgie-switcher .notification-body {
  color: rgba(195, 199, 209, 0.7); }
.budgie-notification button, .budgie-osd button, .budgie-switcher button {
  background-color: transparent;
  color: #fefefe; }
  .budgie-notification button:hover, .budgie-osd button:hover, .budgie-switcher button:hover {
    background-color: transparent;
    color: #ed254e;
    box-shadow: none; }
  .budgie-notification button:active, .budgie-osd button:active, .budgie-switcher button:active, .budgie-notification button:checked, .budgie-osd button:checked, .budgie-switcher button:checked {
    background-color: transparent;
    color: #e6133e; }

.drop-shadow, .budgie-session-dialog.background, .background.budgie-polkit-dialog, .background.budgie-run-dialog {
  color: #C3C7D1;
  background-color: rgba(22, 25, 37, 0.95);
  box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.2);
  border-radius: 2px; }

.budgie-switcher-window flowbox {
  color: #C3C7D1; }
.budgie-switcher-window flowboxchild {
  padding: 3px;
  margin: 3px;
  color: #C3C7D1; }
  .budgie-switcher-window flowboxchild:hover {
    background-color: transparent; }
  .budgie-switcher-window flowboxchild:active {
    color: #C3C7D1; }
  .budgie-switcher-window flowboxchild:selected {
    color: #fefefe;
    background-color: rgba(197, 14, 210, 0.5); }
    .budgie-switcher-window flowboxchild:selected:active {
      color: #fefefe; }
    .budgie-switcher-window flowboxchild:selected:hover {
      background-color: #b10dbd; }
    .budgie-switcher-window flowboxchild:selected:disabled {
      color: rgba(254, 254, 254, 0.7);
      background-color: rgba(197, 14, 210, 0.7); }
      .budgie-switcher-window flowboxchild:selected:disabled label {
        color: rgba(254, 254, 254, 0.7); }

.budgie-session-dialog, .budgie-polkit-dialog, .budgie-run-dialog {
  color: #C3C7D1;
  background-color: rgba(0, 0, 0, 0.95); }
  .budgie-session-dialog label:backdrop, .budgie-polkit-dialog label:backdrop, .budgie-run-dialog label:backdrop {
    color: rgba(195, 199, 209, 0.8); }
  .budgie-session-dialog .dialog-title, .budgie-polkit-dialog .dialog-title, .budgie-run-dialog .dialog-title {
    font-size: 120%; }
  .budgie-session-dialog .linked.horizontal > button, .budgie-polkit-dialog .linked.horizontal > button, .budgie-run-dialog .linked.horizontal > button {
    margin-bottom: 0;
    min-height: 32px;
    border-bottom: none;
    border-color: black;
    border-radius: 0;
    color: #fff;
    background-color: transparent;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.06), inset 0 1px 2px rgba(0, 0, 0, 0.2); }
    .budgie-session-dialog .linked.horizontal > button label, .budgie-polkit-dialog .linked.horizontal > button label, .budgie-run-dialog .linked.horizontal > button label {
      font-weight: 700; }
    .budgie-session-dialog .linked.horizontal > button:first-child, .budgie-polkit-dialog .linked.horizontal > button:first-child, .budgie-run-dialog .linked.horizontal > button:first-child {
      border-left: none;
      border-bottom-left-radius: 2px; }
    .budgie-session-dialog .linked.horizontal > button:last-child, .budgie-polkit-dialog .linked.horizontal > button:last-child, .budgie-run-dialog .linked.horizontal > button:last-child {
      border-right: none;
      border-bottom-right-radius: 2px; }
    .budgie-session-dialog .linked.horizontal > button:hover, .budgie-polkit-dialog .linked.horizontal > button:hover, .budgie-run-dialog .linked.horizontal > button:hover {
      background-color: rgba(197, 14, 210, 0.9); }
      .budgie-session-dialog .linked.horizontal > button:hover:backdrop label, .budgie-polkit-dialog .linked.horizontal > button:hover:backdrop label, .budgie-run-dialog .linked.horizontal > button:hover:backdrop label {
        color: rgba(255, 255, 255, 0.5); }
    .budgie-session-dialog .linked.horizontal > button.suggested-action, .budgie-polkit-dialog .linked.horizontal > button.suggested-action, .budgie-run-dialog .linked.horizontal > button.suggested-action {
      background-color: rgba(197, 14, 210, 0.9); }
      .budgie-session-dialog .linked.horizontal > button.suggested-action:hover, .budgie-polkit-dialog .linked.horizontal > button.suggested-action:hover, .budgie-run-dialog .linked.horizontal > button.suggested-action:hover {
        background-color: rgba(219, 16, 234, 0.9); }
      .budgie-session-dialog .linked.horizontal > button.suggested-action:active, .budgie-polkit-dialog .linked.horizontal > button.suggested-action:active, .budgie-run-dialog .linked.horizontal > button.suggested-action:active, .budgie-session-dialog .linked.horizontal > button.suggested-action:checked, .budgie-polkit-dialog .linked.horizontal > button.suggested-action:checked, .budgie-run-dialog .linked.horizontal > button.suggested-action:checked {
        background-color: rgba(219, 16, 234, 0.9); }
    .budgie-session-dialog .linked.horizontal > button.destructive-action, .budgie-polkit-dialog .linked.horizontal > button.destructive-action, .budgie-run-dialog .linked.horizontal > button.destructive-action {
      background-color: rgba(206, 17, 56, 0.9); }
      .budgie-session-dialog .linked.horizontal > button.destructive-action:hover, .budgie-polkit-dialog .linked.horizontal > button.destructive-action:hover, .budgie-run-dialog .linked.horizontal > button.destructive-action:hover {
        background-color: rgba(230, 19, 62, 0.9); }
      .budgie-session-dialog .linked.horizontal > button.destructive-action:active, .budgie-polkit-dialog .linked.horizontal > button.destructive-action:active, .budgie-run-dialog .linked.horizontal > button.destructive-action:active, .budgie-session-dialog .linked.horizontal > button.destructive-action:checked, .budgie-polkit-dialog .linked.horizontal > button.destructive-action:checked, .budgie-run-dialog .linked.horizontal > button.destructive-action:checked {
        background-color: rgba(230, 19, 62, 0.9); }
  .budgie-session-dialog entry, .budgie-polkit-dialog entry, .budgie-run-dialog entry {
    background-color: #505359;
    color: #C3C7D1; }
    .budgie-session-dialog entry:focus, .budgie-polkit-dialog entry:focus, .budgie-run-dialog entry:focus {
      background-color: #505359; }
    .budgie-session-dialog entry:backdrop, .budgie-polkit-dialog entry:backdrop, .budgie-run-dialog entry:backdrop {
      background-color: #505359; }

.budgie-polkit-dialog .message {
  color: rgba(195, 199, 209, 0.7); }
.budgie-polkit-dialog .failure {
  color: #ed254e; }

.budgie-run-dialog entry.search, .budgie-run-dialog entry.search:focus {
  font-size: 120%;
  padding: 8px 5px;
  border: none;
  box-shadow: none; }
  .budgie-run-dialog entry.search image, .budgie-run-dialog entry.search:focus image {
    color: #C3C7D1; }
    .budgie-run-dialog entry.search image:dir(ltr), .budgie-run-dialog entry.search:focus image:dir(ltr) {
      padding-left: 8px;
      padding-right: 12px; }
    .budgie-run-dialog entry.search image:dir(rtl), .budgie-run-dialog entry.search:focus image:dir(rtl) {
      padding-left: 12px;
      padding-right: 8px; }
.budgie-run-dialog list row:selected .dim-label, .budgie-run-dialog list row:selected label.separator, .budgie-run-dialog list row:selected .titlebar .subtitle, .titlebar .budgie-run-dialog list row:selected .subtitle,
.budgie-run-dialog list row:selected headerbar .subtitle,
headerbar .budgie-run-dialog list row:selected .subtitle {
  opacity: 1; }
.budgie-run-dialog scrolledwindow {
  border-top: 1px solid rgba(0, 0, 0, 0); }

.budgie-menubar menu {
  margin: 4px;
  padding: 5px;
  border-radius: 0;
  background-color: rgba(0, 0, 0, 0.95); }
  .budgie-menubar menu menuitem:hover {
    background-color: #c50ed2;
    color: #fefefe; }
.budgie-menubar arrow {
  border: none;
  min-width: 16px;
  min-height: 16px; }
  .budgie-menubar arrow.top {
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
    border-bottom: 1px solid rgba(33, 35, 42, 0.928); }
  .budgie-menubar arrow.bottom {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
    border-top: 1px solid rgba(33, 35, 42, 0.928); }
.budgie-menubar menuitem accelerator {
  color: rgba(195, 199, 209, 0.35); }
.budgie-menubar menuitem check, .budgie-menubar menuitem radio {
  min-height: 16px;
  min-width: 16px; }

window.background.budgie-settings-window.csd > box.horizontal > stack > scrolledwindow buttonbox.inline-toolbar {
  border-style: none none solid; }

.workspace-switcher .workspace-layout {
  border: 0 solid rgba(0, 0, 0, 0.95); }
  .top .workspace-switcher .workspace-layout:dir(ltr), .bottom .workspace-switcher .workspace-layout:dir(ltr) {
    border-left-width: 1px; }
  .top .workspace-switcher .workspace-layout:dir(rtl), .bottom .workspace-switcher .workspace-layout:dir(rtl) {
    border-right-width: 1px; }
  .left .workspace-switcher .workspace-layout, .right .workspace-switcher .workspace-layout {
    border-top-width: 1px; }
.workspace-switcher .workspace-item, .workspace-switcher .workspace-add-button {
  border: 0 solid rgba(19, 22, 32, 0.95); }
  .top .workspace-switcher .workspace-item:dir(ltr), .bottom .workspace-switcher .workspace-item:dir(ltr),
  .top .workspace-switcher .workspace-add-button:dir(ltr), .bottom .workspace-switcher .workspace-add-button:dir(ltr) {
    border-right-width: 1px; }
  .top .workspace-switcher .workspace-item:dir(rtl), .bottom .workspace-switcher .workspace-item:dir(rtl),
  .top .workspace-switcher .workspace-add-button:dir(rtl), .bottom .workspace-switcher .workspace-add-button:dir(rtl) {
    border-left-width: 1px; }
  .left .workspace-switcher .workspace-item, .right .workspace-switcher .workspace-item, .left .workspace-switcher .workspace-add-button, .right .workspace-switcher .workspace-add-button {
    border-bottom-width: 1px; }
.workspace-switcher .workspace-item.current-workspace {
  background-color: rgba(10, 11, 16, 0.95); }
.workspace-switcher .workspace-add-button {
  border: none;
  background: transparent;
  box-shadow: none; }
  .workspace-switcher .workspace-add-button:hover {
    box-shadow: none; }
  .workspace-switcher .workspace-add-button:active {
    background-image: none; }
  .workspace-switcher .workspace-add-button:active image {
    margin: 1px 0 -1px; }
.budgie-panel .workspace-switcher .workspace-icon-button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 2px; }

/************
 * Nautilus *
 ************/
.nautilus-window .frame *:selected, .nautilus-window .frame *:selected:backdrop {
  background: transparent;
  color: #c50ed2; }
  .nautilus-window .frame *:selected label, .nautilus-window .frame *:selected:backdrop label {
    color: #c50ed2; }
.nautilus-window paned > separator {
  background-image: none; }
.nautilus-window .sidebar {
  background-color: transparent; }
  .nautilus-window .sidebar:backdrop {
    background-color: transparent; }
  .nautilus-window .sidebar .list-row button {
    border: none;
    background-color: rgba(18, 21, 31, 0.95); }
    .nautilus-window .sidebar .list-row button:active {
      background-color: rgba(197, 14, 210, 0.75); }
  .nautilus-window .sidebar .list-row:selected {
    background-color: rgba(197, 14, 210, 0.75); }
    .nautilus-window .sidebar .list-row:selected:hover {
      background-color: rgba(197, 14, 210, 0.9); }
  .nautilus-window .sidebar .list-row:hover {
    background-color: rgba(24, 27, 40, 0.5); }
    .nautilus-window .sidebar .list-row:hover:active {
      background-color: rgba(197, 14, 210, 0.9); }
.nautilus-window.background {
  background-color: rgba(18, 21, 31, 0.95); }
  .nautilus-window.background:backdrop {
    background-color: rgba(18, 21, 31, 0.95); }
.nautilus-window notebook > stack:only-child {
  background-color: #181b28; }
  .nautilus-window notebook > stack:only-child:backdrop {
    background-color: #1a1d2b; }
.nautilus-window searchbar {
  border-top: 1px solid rgba(0, 0, 0, 0.12); }
.nautilus-window .searchbar-container {
  margin-top: -1px; }
.nautilus-window .titlebar .search {
  border: 1px solid transparent;
  border-radius: 10px;
  box-shadow: none;
  margin-top: 10px;
  margin-bottom: 10px; }
.nautilus-window .titlebar .path-bar-box .dim-label, .nautilus-window .titlebar .path-bar-box label.separator, .nautilus-window .titlebar .path-bar-box .subtitle {
  color: transparent; }
.nautilus-window .titlebar .path-bar-box widget > .text-button:last-child,
.nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:active,
.nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:checked,
.nautilus-window .titlebar .path-bar-box button:active, .nautilus-window .titlebar .path-bar-box button:checked {
  border-radius: 23px;
  background: linear-gradient(to right, #c50ed2, #8500f7);
  box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
  color: white; }
  .nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:backdrop, .nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:backdrop label,
  .nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:active:backdrop,
  .nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:active:backdrop label,
  .nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:checked:backdrop,
  .nautilus-window .titlebar .path-bar-box widget > .text-button:last-child:checked:backdrop label,
  .nautilus-window .titlebar .path-bar-box button:active:backdrop,
  .nautilus-window .titlebar .path-bar-box button:active:backdrop label, .nautilus-window .titlebar .path-bar-box button:checked:backdrop, .nautilus-window .titlebar .path-bar-box button:checked:backdrop label {
    color: whitesmoke; }
.nautilus-window .titlebar .linked:not(.path-bar) button:active, .nautilus-window .titlebar .linked:not(.path-bar) button:checked, .nautilus-window .titlebar .linked:not(.path-bar) button:active:backdrop, .nautilus-window .titlebar .linked:not(.path-bar) button:checked:backdrop {
  background: transparent;
  color: #c50ed2;
  box-shadow: none;
  border: none; }
.nautilus-window .linked:not(.vertical) > entry {
  border-radius: 10px;
  margin-right: 5px; }
  .nautilus-window .linked:not(.vertical) > entry:focus {
    border-color: rgba(197, 14, 210, 0.6); }

.nautilus-circular-button {
  border-radius: 20px; }

.disk-space-display {
  border: 2px solid; }
  .disk-space-display .unknown {
    background-color: #888a85;
    border-color: #555653; }
  .disk-space-display .used {
    background-color: #9FB0B9;
    border-color: #667f8c; }
  .disk-space-display .free {
    background-color: #D8D8D8;
    border-color: #a5a5a5; }

.nautilus-desktop {
  color: #C3C7D1; }
  .nautilus-desktop .nautilus-canvas-item {
    border-radius: 5px;
    color: #fefefe;
    text-shadow: 1px 1px rgba(0, 0, 0, 0.6); }
    .nautilus-desktop .nautilus-canvas-item:active {
      color: #C3C7D1;
      text-shadow: none; }
    .nautilus-desktop .nautilus-canvas-item:hover {
      color: #C3C7D1;
      text-shadow: none; }
    .nautilus-desktop .nautilus-canvas-item:selected {
      color: #fefefe;
      text-shadow: none; }
    .nautilus-desktop .nautilus-canvas-item .dim-label:selected, .nautilus-desktop .nautilus-canvas-item label.separator:selected, .nautilus-desktop .nautilus-canvas-item .titlebar .subtitle:selected, .titlebar .nautilus-desktop .nautilus-canvas-item .subtitle:selected,
    .nautilus-desktop .nautilus-canvas-item headerbar .subtitle:selected,
    headerbar .nautilus-desktop .nautilus-canvas-item .subtitle:selected {
      color: #fefefe; }
  .nautilus-desktop .nautilus-list .dim-label:selected, .nautilus-desktop .nautilus-list label.separator:selected, .nautilus-desktop .nautilus-list .titlebar .subtitle:selected, .titlebar .nautilus-desktop .nautilus-list .subtitle:selected,
  .nautilus-desktop .nautilus-list headerbar .subtitle:selected,
  headerbar .nautilus-desktop .nautilus-list .subtitle:selected {
    color: #fefefe; }

/*********
 * Gedit *
 *********/
.gedit-search-slider {
  padding: 4px;
  border-radius: 0 0 3px 3px;
  border: 0;
  background-color: #161925; }

/*********
* Gnucash *
*********/
#gnc-id-main-window entry.gnc-class-register-foreground {
  background: transparent;
  border: none;
  box-shadow: none; }
#gnc-id-main-window .arrow.button.toggle {
  transition: none;
  box-shadow: none; }
  #gnc-id-main-window .arrow.button.toggle:hover {
    border-color: #c50ed2; }

.xfce4-panel.panel {
  background-color: #181b28;
  text-shadow: none;
  -gtk-icon-shadow: none; }

#tasklist-button {
  color: rgba(255, 255, 255, 0.8);
  border-radius: 0;
  border: none;
  background-color: rgba(24, 27, 40, 0); }
  #tasklist-button:hover {
    color: white;
    background-color: rgba(0, 0, 0, 0.17); }
  #tasklist-button:checked {
    color: white;
    background-color: rgba(0, 0, 0, 0.25);
    box-shadow: inset 0 -2px #c50ed2; }

.xfce4-panel.panel button.flat {
  color: white;
  border-radius: 0;
  border: none;
  background-color: rgba(24, 27, 40, 0); }
  .xfce4-panel.panel button.flat:hover {
    border: none;
    background-color: #2b3148; }
  .xfce4-panel.panel button.flat:active, .xfce4-panel.panel button.flat:checked {
    color: #fefefe;
    border-bottom: 2px solid #c50ed2;
    background-color: #212638; }
    .xfce4-panel.panel button.flat:active label, .xfce4-panel.panel button.flat:active image, .xfce4-panel.panel button.flat:checked label, .xfce4-panel.panel button.flat:checked image {
      color: inherit; }

#whiskermenu-window button {
  background-color: transparent;
  border: none;
  border-radius: 0;
  font-weight: normal;
  padding: 2px;
  margin: 1px 0px; }
  #whiskermenu-window button:hover, #whiskermenu-window button:checked {
    background-color: #c50ed2; }

/* thunar */
.thunar toolbar {
  background-color: #0c0e14; }

/* buttons in toolbar */
.thunar toolbar.horizontal button image {
  -gtk-icon-transform: scale(0.72); }

scrolledwindow.sidebar treeview.view {
  background: #12151f;
  padding: 1.5px; }

/* path-bar of thunar */
window.thunar toolbar#location-toolbar > toolitem > widget > widget.linked.path-bar > button.toggle.path-bar-button, .thunar toolbar .path-bar-button {
  margin-top: 7px;
  margin-bottom: 7px; }
  window.thunar toolbar#location-toolbar > toolitem > widget > widget.linked.path-bar > button.toggle.path-bar-button:hover, .thunar toolbar .path-bar-button:hover {
    color: #c50ed2; }
  window.thunar toolbar#location-toolbar > toolitem > widget > widget.linked.path-bar > button.toggle.path-bar-button:checked, .thunar toolbar .path-bar-button:checked {
    border-radius: 23px;
    background: linear-gradient(to right, #c50ed2, #8500f7);
    box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
    color: white; }

window.thunar toolbar#location-toolbar > toolitem > widget > widget.linked.path-bar > button.path-bar-button, .thunar toolbar .path-bar-button {
  background: none;
  outline: none;
  border: none;
  box-shadow: none; }

/* thunar sidepane */
window.thunar paned > scrolledwindow treeview.view:hover {
  background: #10131b; }
window.thunar paned > scrolledwindow treeview.view:selected {
  border-radius: 23px;
  background: linear-gradient(to right, #c50ed2, #8500f7);
  box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
  color: white;
  border-radius: 0;
  box-shadow: none; }

window.thunar toolbar#location-toolbar entry {
  border-radius: 10px; }

/********
 * Gala *
 *******/
.gala-notification {
  border-width: 0;
  border-radius: 2px;
  color: white;
  border: 1px solid #181b28;
  background-color: #181b28; }
  .gala-notification .title,
  .gala-notification .label {
    color: #C3C7D1; }

.gala-button {
  padding: 3px;
  color: #181b28;
  border: none;
  border-radius: 50%;
  background-image: linear-gradient(to bottom, #7e7e7e, #3e3e3e);
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.98), inset 0 1px 0 0 rgba(255, 255, 255, 0.93), inset 0 -1px 0 0 rgba(255, 255, 255, 0.99), 0 0 0 1px rgba(0, 0, 0, 0.6), 0 3px 6px rgba(0, 0, 0, 0.84), 0 3px 6px rgba(0, 0, 0, 0.77);
  text-shadow: 0 1px 1px rgba(0, 0, 0, 0.4); }

/**********
 * Notify *
 *********/
.notify {
  /*-notify-shadow: 0px 2px 18px transparentize(black, 0.60);*/
  border-radius: 5px;
  border: 1px solid rgba(0, 0, 0, 0.7);
  background-color: rgba(24, 27, 40, 0.05); }

/***************
 * SwitchBoard *
 ***************/
.category-label {
  font-weight: bold;
  color: #C3C7D1; }

/*************
 * Slingshot *
 ************/
.button.app {
  border: none;
  border-radius: 0;
  box-shadow: none;
  background-image: none; }
  .button.app .app:hover {
    border-radius: 8px;
    border: none;
    background-color: rgba(197, 14, 210, 0.3);
    color: white; }
  .button.app .app:focus {
    /*background-color: transparentize(black, 0.20);*/ }

.search-item {
  border-radius: 0;
  border: none;
  color: #C3C7D1;
  background: none; }
  .search-item:hover, .search-item:focus {
    border-radius: 0;
    background-color: rgba(197, 14, 210, 0.3);
    color: #fefefe; }

.search-entry-large,
.search-entry-large:focus {
  border: none;
  font-size: 18px;
  font-weight: 300;
  background-image: none;
  background: none;
  box-shadow: none;
  border-radius: 0; }

.search-category-header {
  font-weight: bold;
  color: #C3C7D1; }

/*********
 * Panel *
 ********/
.panel {
  background-color: transparent;
  transition: all 100ms ease-in-out; }
  .panel.maximized {
    background-color: #181b28; }
  .panel.translucent {
    background-color: rgba(24, 27, 40, 0.5); }
  .panel.color-light.translucent {
    background-color: rgba(255, 255, 255, 0.85); }

menubar.panel,
.panel menubar {
  box-shadow: none;
  border: none; }

.composited-indicator > revealer,
.composited-indicator > revealer image,
.composited-indicator > revealer label,
.composited-indicator > revealer spinner {
  color: #fff;
  font-weight: bold;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 1px 2px rgba(0, 0, 0, 0.5);
  transition: all 200ms ease-in-out;
  -gtk-icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 1px 2px rgba(0, 0, 0, 0.5); }
.composited-indicator > revealer image:first-child + label {
  margin-left: 5px; }

.panel.color-light .composited-indicator > revealer,
.panel.color-light .composited-indicator > revealer image,
.panel.color-light .composited-indicator > revealer label,
.panel.color-light .composited-indicator > revealer spinner {
  color: rgba(0, 0, 0, 0.6);
  text-shadow: 0 1px rgba(255, 255, 255, 0.1);
  -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.1); }

/**************
 * Calculator *
 **************/
PantheonCalculatorMainWindow {
  border-radius: 0 0 4px 4px; }
  PantheonCalculatorMainWindow .window-frame {
    border-radius: 3px; }

/*********
 * Cards *
 *********/
.deck {
  background-color: #07080b; }

.card {
  background-color: #181b28;
  border: none;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05), 0 3px 3px rgba(0, 0, 0, 0.2);
  transition: all 150ms ease-in-out; }

.card.collapsed {
  background-color: #0e1018;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05), 0 1px 2px rgba(0, 0, 0, 0.2); }

/*********
 * Noise *
 *********/
NoiseLibraryWindow {
  border-radius: 0 0 4px 4px; }
  NoiseLibraryWindow .action-bar {
    border-radius: 0 0 4px 4px; }
  NoiseLibraryWindow .window-frame {
    border-radius: 3px; }

/********
 * Snap *
 ********/
SnapMainWindow .take-button,
SnapSnapWindow .take-button {
  border-radius: 0; }

/*******************
 * Photos/Shotwell *
 *******************/
DirectWindow .the-button-in-the-combobox,
LibraryWindow .the-button-in-the-combobox {
  background: none; }

.checkerboard-layout {
  background-color: #161925;
  background-image: linear-gradient(45deg, rgba(0, 0, 0, 0.1) 25%, transparent 25%, transparent 75%, rgba(0, 0, 0, 0.1) 75%, rgba(0, 0, 0, 0.1)), linear-gradient(45deg, rgba(0, 0, 0, 0.1) 25%, transparent 25%, transparent 75%, rgba(0, 0, 0, 0.1) 75%, rgba(0, 0, 0, 0.1));
  background-size: 24px 24px;
  background-position: 0 0, 12px 12px; }

.checkboard-layout .item {
  background-color: #C3C7D1; }

/*********
* Avatar *
*********/
.avatar {
  border: 1px solid rgba(0, 0, 0, 0.23);
  border-radius: 50%;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.05), inset 0 1px 0 0 rgba(255, 255, 255, 0.45), inset 0 -1px 0 0 rgba(255, 255, 255, 0.15), 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.23); }

/************
* Level bar *
*************/
.source-list.view.level-bar, iconview.source-list.level-bar, .source-list.view.level-bar:selected, iconview.source-list.level-bar:selected, .source-list.view.level-bar:selected:focus, iconview.source-list.level-bar:selected:focus {
  background: linear-gradient(#333955, #333955);
  border: 1px solid rgba(0, 0, 0, 0.14);
  box-shadow: 0 1px 0 rgba(0, 0, 0, 0.25);
  border-radius: 2px; }
.source-list.view.level-bar.fill-block, iconview.source-list.level-bar.fill-block {
  border: none; }
  .source-list.view.level-bar.fill-block, iconview.source-list.level-bar.fill-block, .source-list.view.level-bar.fill-block:hover, iconview.source-list.level-bar.fill-block:hover, .source-list.view.level-bar.fill-block:selected, iconview.source-list.level-bar.fill-block:selected, .source-list.view.level-bar.fill-block:selected:focus, iconview.source-list.level-bar.fill-block:selected:focus {
    background: linear-gradient(to right, #00f17d, #00f7d2); }

/**************************
 * Colors in context menu *
**************************/
checkbutton.color-button {
  border: 1px solid #090a0f;
  border-radius: 100px;
  background-clip: border-box;
  padding: 0;
  margin: 2px 1px; }
  checkbutton.color-button > check {
    -gtk-icon-source: none;
    background: none;
    margin-right: 0;
    padding: 2px; }
  checkbutton.color-button.none > check {
    background-color: transparent;
    border-radius: 100px;
    -gtk-icon-source: -gtk-icontheme("close-symbolic"); }

radiobutton.color-button > radio {
  -gtk-icon-source: none;
  margin-right: 0;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 100px;
  background-clip: border-box; }
radiobutton.color-button:active > radio {
  border: 1px solid rgba(0, 0, 0, 0.35); }

.color-button check,
.color-button check:checked,
.color-button radio,
.color-button radio:checked {
  background-image: none;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 50%;
  color: #181b28;
  -gtk-icon-source: -gtk-icontheme("check-active-symbolic"); }
.color-button.red check, .color-button.red radio, .color-button.strawberry check, .color-button.strawberry radio {
  background-color: @STRAWBERRY_300;
  -gtk-icon-shadow: 0 1px 1px @STRAWBERRY_500; }
.color-button.orange check, .color-button.orange radio {
  background-color: @ORANGE_300;
  -gtk-icon-shadow: 0 1px 1px @ORANGE_500; }
.color-button.yellow check, .color-button.yellow radio, .color-button.banana check, .color-button.banana radio {
  background-color: @BANANA_500;
  -gtk-icon-shadow: 0 1px 1px @BANANA_700; }
.color-button.green check, .color-button.green radio, .color-button.lime check, .color-button.lime radio {
  background-color: @LIME_500;
  -gtk-icon-shadow: 0 1px 1px @LIME_700; }
.color-button.blue check, .color-button.blue radio, .color-button.blueberry check, .color-button.blueberry radio {
  background-color: @BLUEBERRY_500;
  -gtk-icon-shadow: 0 1px 1px @BLUEBERRY_700; }
.color-button.purple check, .color-button.purple radio, .color-button.grape check, .color-button.grape radio {
  background-color: @GRAPE_500;
  -gtk-icon-shadow: 0 1px 1px @GRAPE_700; }
.color-button.brown check, .color-button.brown radio, .color-button.cocoa check, .color-button.cocoa radio {
  background-color: @COCOA_300;
  -gtk-icon-shadow: 0 1px 1px @COCOA_500; }
.color-button.mint check, .color-button.mint radio {
  background-color: @MINT_500;
  -gtk-icon-shadow: 0 1px 1px @MINT_700; }
.color-button.pink check, .color-button.pink radio, .color-button.bubblegum check, .color-button.bubblegum radio {
  background-color: @BUBBLEGUM_500;
  -gtk-icon-shadow: 0 1px 1px @BUBBLEGUM_700; }
.color-button.slate check, .color-button.slate radio {
  background-color: @SLATE_300;
  -gtk-icon-shadow: 0 1px 1px @SLATE_500; }
.color-button.auto radio {
  background-image: url("assets/color-button-auto.png");
  background-position: -1px -1px;
  background-repeat: no-repeat;
  background-size: calc(100% + 2px); }

/********
* Unity *
*********/
/* Unity window border color */
/* Unity window text color */
/* Backdrop Unity window text color */
/* Unity panel color #454D50 */
UnityDecoration {
  background-color: #eeeeee;
  color: #31363D; }
  UnityDecoration .top {
    padding: 0 5px 0 5px;
    border-radius: 4px 4px 0px 0px;
    box-shadow: none;
    border: 1px solid #eeeeee;
    border-bottom-width: 0;
    background-color: #eeeeee;
    color: #31363D;
    border-top: 1px solid rgba(255, 255, 255, 0.1); }
    UnityDecoration .top:backdrop {
      border-bottom-width: 0;
      color: #1a1d21;
      border-top: 1px solid rgba(255, 255, 255, 0.1); }
    UnityDecoration .top .menuitem {
      color: #31363D; }
      UnityDecoration .top .menuitem:backdrop {
        color: #1a1d21; }

UnityDecoration.left,
UnityDecoration.right {
  background-repeat: repeat-x;
  background-color: #ececec;
  background-size: 1px 120px;
  background-clip: border-box;
  background-image: linear-gradient(to bottom, #eeeeee, #ececec); }

UnityDecoration.bottom {
  background-size: 1px;
  background-repeat: repeat-x;
  background-color: #ececec; }

UnityDecoration.left:backdrop,
UnityDecoration.right:backdrop,
UnityDecoration.bottom:backdrop {
  background-size: 1px;
  background-repeat: repeat-x; }

/**************
* Unity Panel *
***************/
UnityPanelWidget,
.unity-panel {
  background-color: #d5d5d5;
  color: #31363D; }

UnityPanelWidget:backdrop,
.unity-panel:backdrop {
  color: #1a1d21; }

.unity-panel.menuitem,
.unity-panel .menuitem {
  border-width: 0 1px;
  color: #31363D; }

.unity-panel.menubar,
.unity-panel .menubar {
  color: #31363D; }

.unity-panel.menu.menubar,
.unity-panel .menu .menubar {
  background-color: #d5d5d5;
  color: #31363D; }

.unity-panel.menubar:backdrop,
.unity-panel .menubar *:backdrop {
  color: #6d707b; }

.unity-panel.menubar.menuitem,
.unity-panel.menubar .menuitem {
  padding: 3px 5px;
  border-width: 1px;
  border-style: solid;
  border: none;
  background: none;
  color: #31363D;
  box-shadow: none; }

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem:hover {
  border-radius: 0;
  background-color: #ebebeb;
  color: #31363D;
  box-shadow: none; }

.unity-panel.menubar .menuitem *:hover {
  color: white;
  box-shadow: none; }

.unity-panel.menubar .menuitem.separator,
.unity-panel.menubar.menuitem.separator {
  border: none;
  color: #090a0f; }

/* Force Quit */
SheetStyleDialog.unity-force-quit {
  background-color: #181b28; }

@keyframes playbackmenuitem_spinner {
  to {
    -gtk-icon-transform: rotate(1turn); } }
.menu IdoPlaybackMenuItem.menuitem:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: playbackmenuitem_spinner 1s infinite linear;
  color: #c50ed2; }

MsdOsdWindow.background.osd {
  border-radius: 2px;
  border: 1px solid #090a0f; }
  MsdOsdWindow.background.osd .progressbar {
    background-color: #c50ed2;
    border: none;
    border-color: #c50ed2;
    border-radius: 5px; }
  MsdOsdWindow.background.osd .trough {
    background-color: rgba(7, 8, 11, 0.98);
    border: none;
    border-radius: 5px; }

/***********************
 * App-Specific Styles *
 ***********************/
/*********
 * Geary *
 *********/
.geary-titlebar-left .separator,
.geary-titlebar-right .separator {
  opacity: 0; }

ConversationListView .view:active, ConversationListView iconview:active, ConversationListView .view:selected, ConversationListView iconview:selected {
  background-color: #c50ed2;
  color: #fefefe; }
  ConversationListView .view:active:backdrop, ConversationListView iconview:active:backdrop, ConversationListView .view:selected:backdrop, ConversationListView iconview:selected:backdrop {
    background-color: rgba(197, 14, 210, 0.6);
    color: rgba(254, 254, 254, 0.5); }
ConversationListView .view .cell, ConversationListView iconview .cell {
  border: solid rgba(0, 0, 0, 0.2);
  border-width: 0 0 1px 0; }
  ConversationListView .view .cell:selected, ConversationListView iconview .cell:selected {
    color: #fefefe;
    border: 0px solid #980ba2; }

/***********
 * LightDm *
 ***********/
#panel_window {
  background-color: #181b28;
  color: white;
  font-weight: bold;
  box-shadow: inset 0 -1px #0b0c12; }
  #panel_window .menubar,
  #panel_window .menubar > .menuitem
  menubar,
  #panel_window menubar > menuitem {
    background-color: transparent;
    color: white;
    font-weight: bold; }
  #panel_window .menubar .menuitem:disabled,
  #panel_window menubar menuitem:disabled {
    color: rgba(255, 255, 255, 0.5); }
    #panel_window .menubar .menuitem:disabled GtkLabel,
    #panel_window menubar menuitem:disabled GtkLabel {
      color: inherit; }
    #panel_window .menubar .menuitem:disabled label,
    #panel_window menubar menuitem:disabled label {
      color: inherit; }
  #panel_window .menubar .menu > .menuitem,
  #panel_window menubar menu > menuitem {
    font-weight: normal; }

#login_window,
#shutdown_dialog,
#restart_dialog {
  font-weight: normal;
  border-style: none;
  background-color: transparent;
  color: #C3C7D1; }

#content_frame {
  padding-bottom: 14px;
  background-color: #161925;
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 1px 1px 0 1px; }

#content_frame button {
  font-weight: normal;
  color: #C3C7D1;
  background-color: #202435;
  text-shadow: none; }
  #content_frame button:hover {
    color: #C3C7D1;
    outline-color: rgba(195, 199, 209, 0.3);
    background-color: #181b28;
    text-shadow: none; }
  #content_frame button:active, #content_frame button:checked {
    color: #C3C7D1;
    outline-color: rgba(195, 199, 209, 0.3);
    background-color: #c50ed2;
    text-shadow: none; }
  #content_frame button:disabled {
    color: #a1a5b0;
    outline-color: rgba(195, 199, 209, 0.3);
    background-color: #171a26;
    text-shadow: none; }

#buttonbox_frame {
  padding-top: 20px;
  padding-bottom: 0px;
  border-style: none;
  background-color: #0c0e14;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  border: solid rgba(0, 0, 0, 0.1);
  border-width: 0 1px 1px 1px; }

#buttonbox_frame button {
  color: #fefefe;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: rgba(16, 19, 27, 0.98);
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  outline-color: rgba(254, 254, 254, 0.3); }
  #buttonbox_frame button:hover {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(39, 44, 66, 0.98), rgba(39, 44, 66, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    outline-color: rgba(254, 254, 254, 0.3); }
  #buttonbox_frame button:active, #buttonbox_frame button:checked {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(28, 31, 47, 0.98), rgba(28, 31, 47, 0.98));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: none;
    -gtk-icon-shadow: none;
    outline-color: rgba(254, 254, 254, 0.3); }
  #buttonbox_frame button:disabled {
    color: #87898d;
    border-color: rgba(0, 0, 0, 0.7);
    background-image: linear-gradient(to bottom, rgba(40, 43, 50, 0.5), rgba(40, 43, 50, 0.5));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }

#login_window #user_combobox {
  color: #C3C7D1;
  font-size: 13px; }
  #login_window #user_combobox .menu,
  #login_window #user_combobox menu {
    font-weight: normal; }

#user_image {
  padding: 3px;
  border-radius: 2px; }

#greeter_infobar {
  border-bottom-width: 0;
  font-weight: bold; }

.nemo-window .places-treeview .view.cell:hover, .nemo-window .places-treeview iconview.cell:hover,
.nemo-window .places-treeview iconview.cell:hover {
  background: rgba(16, 19, 27, 0.7); }
.nemo-window .places-treeview .view.cell:selected, .nemo-window .places-treeview iconview.cell:selected,
.nemo-window .places-treeview iconview.cell:selected {
  background: #c50ed2; }
.nemo-window .sidebar {
  color: #98abb2;
  background-color: #161925; }
  .nemo-window .sidebar .view, .nemo-window .sidebar iconview, .nemo-window .sidebar .iconview, .nemo-window .sidebar row {
    background-color: transparent; }
.nemo-window .nemo-window-pane widget.entry {
  background-clip: padding-box;
  min-height: 28px;
  padding: 5px;
  color: #C3C7D1;
  border: 1px solid #090a0f;
  border-radius: 3px;
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.9), inset 1px 0 rgba(0, 0, 0, 0.96), inset -1px 0 rgba(0, 0, 0, 0.96), inset 0 -1px rgba(0, 0, 0, 0.98), 0 1px rgba(255, 255, 255, 0.6); }
  .nemo-window .nemo-window-pane widget.entry:selected {
    background-color: #c50ed2;
    color: #fefefe; }
.nemo-window toolbar.primary-toolbar {
  margin-bottom: -1px;
  background: #0c0e14; }
  .nemo-window toolbar.primary-toolbar button {
    color: #8b8b8b;
    text-shadow: none;
    box-shadow: none;
    background: transparent;
    border: none;
    margin-top: 5px;
    margin-bottom: 5px;
    min-height: 24px; }
    .nemo-window toolbar.primary-toolbar button:hover {
      background: transparent;
      color: #c50ed2; }
    .nemo-window toolbar.primary-toolbar button:selected, .nemo-window toolbar.primary-toolbar button:active, .nemo-window toolbar.primary-toolbar button:checked {
      border-radius: 23px;
      background: linear-gradient(to right, #c50ed2, #8500f7);
      box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
      color: white; }
.nemo-window .nemo-inactive-pane .view, .nemo-window .nemo-inactive-pane iconview,
.nemo-window .nemo-inactive-pane iconview {
  background-color: #141722; }

.caja-notebook .frame {
  border-width: 0 0 1px; }
.caja-notebook .entry {
  background: #161925;
  color: #C3C7D1;
  border-color: #090a0f; }
  .caja-notebook .entry:selected {
    background: #c50ed2;
    color: #fefefe; }

/**************
* Caja sidebar *
**************/
.caja-side-pane {
  background: #0c0e14; }
  .caja-side-pane .frame {
    border-width: 1px 0 0; }
  .caja-side-pane treeview.view,
  .caja-side-pane textview.view text,
  .caja-side-pane viewport.frame,
  .caja-side-pane widget .vertical {
    background: #161925;
    padding: 3px 2px;
    color: #98abb2; }
    .caja-side-pane treeview.view:hover,
    .caja-side-pane textview.view text:hover,
    .caja-side-pane viewport.frame:hover,
    .caja-side-pane widget .vertical:hover {
      background-color: rgba(18, 21, 31, 0.95); }
    .caja-side-pane treeview.view:selected,
    .caja-side-pane textview.view text:selected,
    .caja-side-pane viewport.frame:selected,
    .caja-side-pane widget .vertical:selected {
      color: #fefefe;
      background: #c50ed2; }

/**************
* Caja pathbar *
**************/
.caja-navigation-window paned, .caja-navigation-window .primary-toolbar {
  background: #0c0e14; }

.caja-navigation-window .primary-toolbar button, .caja-navigation-window .primary-toolbar button:backdrop,
.caja-navigation-window .vertical button.image-button.toggle:not(.text-button),
.caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop {
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none; }
.caja-navigation-window .primary-toolbar button:hover, .caja-navigation-window .primary-toolbar button:active, .caja-navigation-window .primary-toolbar button:backdrop:active, .caja-navigation-window .primary-toolbar button:backdrop:checked,
.caja-navigation-window .vertical button.image-button.toggle:not(.text-button):hover,
.caja-navigation-window .vertical button.image-button.toggle:not(.text-button):active,
.caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop:active,
.caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop:checked {
  background: #c50ed2;
  box-shadow: none; }
  .caja-navigation-window .primary-toolbar button:hover, .caja-navigation-window .primary-toolbar button:hover label, .caja-navigation-window .primary-toolbar button:active, .caja-navigation-window .primary-toolbar button:active label, .caja-navigation-window .primary-toolbar button:backdrop:active, .caja-navigation-window .primary-toolbar button:backdrop:active label, .caja-navigation-window .primary-toolbar button:backdrop:checked, .caja-navigation-window .primary-toolbar button:backdrop:checked label,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):hover,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):hover label,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):active,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):active label,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop:active,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop:active label,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop:checked,
  .caja-navigation-window .vertical button.image-button.toggle:not(.text-button):backdrop:checked label {
    color: #fefefe; }

.caja-pathbar button {
  color: #8b8b8b;
  text-shadow: none;
  box-shadow: none;
  background: transparent;
  border: none;
  margin-top: 7px;
  margin-bottom: 7px; }
  .caja-pathbar button:hover {
    color: #c50ed2; }
  .caja-pathbar button:checked {
    border-radius: 23px;
    background: linear-gradient(to right, #c50ed2, #8500f7);
    box-shadow: 0px 0px 5px rgba(197, 14, 210, 0.98);
    color: white; }
  .caja-pathbar button:backdrop:disabled {
    color: rgba(195, 199, 209, 0.2);
    background-color: transparent;
    border-radius: 0;
    text-shadow: none;
    box-shadow: none; }

/*# sourceMappingURL=gtk-dark.css.map */
